(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     48468,       1345]
NotebookOptionsPosition[     42422,       1151]
NotebookOutlinePosition[     43791,       1196]
CellTagsIndexPosition[     43495,       1186]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["EOS for pure fluids and fluid mixtures", "Title"],

Cell[TextData[{
 "The package ",
 StyleBox["EOSCG.m",
  FontWeight->"Bold"],
 " implements the equation of state for pure fluids and fluid mixtures (EOS) \
according to the following two  publications\n\n",
 "Churakov and M. Gottschalk (2003) Perturbation theory based equation of \
state for polar molecular fluids I. Pure fluids\n\tGeochimica et Cosmochimica \
Acta 67, 2397-2414.\nChurakov and M. Gottschalk (2003) Perturbation theory \
based equation of state for polar molecular fluids II. Fluid mixtures\n\t\
Geochimica et Cosmochimica Acta 67, 2415-2424.\n\t",
 "\nThe  ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " source code for the EOS is located in the file ",
 StyleBox["EOSCG_original",
  FontWeight->"Bold"],
 ". Building the package ",
 StyleBox["EOSCG.m",
  FontWeight->"Bold"],
 " (instructions to modify the package are located in the file ",
 StyleBox["make_package",
  FontWeight->"Bold"],
 ") involves a file in InputForm with the name  ",
 StyleBox["EOSCG",
  FontWeight->"Bold"],
 " which is less readable than ",
 StyleBox["EOSCG_original",
  FontWeight->"Bold"],
 ", however."
}], "Text",
 FontFamily->"Times",
 FontSize->14,
 FontWeight->"Plain",
 FontVariations->{"CompatibilityType"->0}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Contact", "Subtitle"],

Cell[TextData[StyleBox["M. Gottschalk\nGeoForschungsZentrum\nTelegrafenberg\n\
14473 Potsdam\nGermany\n\nTel. +49 331 2881418\nFax  +49 331 2881402\nemail \
gottschalk@gfz-potsdam.de",
 FontSize->14]], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Disclaimer", "Subtitle"],

Cell["\<\
This software is written by M. Gottschalk and is provided to the scientific \
community. It is not intented to be used in any commercial context. The \
package implements the EOS as described in the appendix of the two \
publications mentioned above. The author does not take any responsibility for \
the calculated results. \
\>", "Text",
 FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["Installation", "Subtitle"],

Cell[TextData[{
 "The package has been tested for Mathematica 4.2 and 5.0 under MacOS X 10.2. \
Move the folder ",
 StyleBox["Fluids",
  FontWeight->"Bold"],
 " into the respective Mathematic/AddOns/Applications folder (e.g. ",
 StyleBox["Mathematica",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox[" 4.x/AddOns/Applications, ",
  FontWeight->"Bold"],
 "MacOS X users have to use the Crtl key and choose the Show Package Contents \
option to open the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " 4.x folder). The functioning of the package ",
 StyleBox["EOSCG.m",
  FontWeight->"Bold"],
 " should not depend on the operating system used. The package should also \
work with older versions of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ". This has not been tested, however. "
}], "Text",
 FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["MacOS X users", "Subtitle"],

Cell[TextData[{
 "MacOS X users benefit from a program with the name ",
 StyleBox["aeos",
  FontWeight->"Bold"],
 " which is a seperate compiled program calculating the Helmholtz free energy \
of the fluid. This program is called from the package",
 StyleBox[" EOSCG.m",
  FontWeight->"Bold"],
 " and replaces the time consuming calculations of the Helmholtz free energy. \
This increases the speed of the calculations by a factor of 50-100. Fast \
calculations are used by default. Slow calculations using only Mathematica \
code can be forced choosing the option ",
 StyleBox["\"slow\"",
  FontWeight->"Bold"],
 " in all functions."
}], "Text",
 FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["Starting calculations", "Subtitle"],

Cell["The package is loaded by the command:", "Text",
 FontSize->14],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<Fluids`EOSCG`\>\"", "]"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Calculations
\
\>", "Subtitle"],

Cell[CellGroupData[{

Cell["\<\
available species
\
\>", "Subsubtitle",
 FontSize->14],

Cell[BoxData[
 RowBox[{"?", "EOSCGSpecies"}]], "Input"],

Cell[BoxData[
 StyleBox["\<\"The following species are available: N2O, NO, H2S, SO2, COS, \
CO, PH3, HCN, CCl2O (phosgene), CH4O (methanol), C2H6O (ethanol), C3H8O \
(n-propanol), C3H8O (2-propanol), C4H10O (n-butanol), C4H10O (2-butanol), \
C4H10O (2-methyl-1-propanol), C4H10O (2-methyl-2-propanol), C6H6O (phenol), \
C3H6O (acetone), C4H8O (2-butaone), C5H10O (2-pentanone), C5H10O \
(3-pentanone), C5H10O (3-methyl-2-butanone), CH2O (formaldehyde), C2H4O \
(aceteldehyde), C3H6O (propionaldehyde), C2H4O2 (acetic acid), C2H4O2 (methyl \
Formate), C3H6O2 (ethyl formate), C4H8O2 (n-propyl formate), C3H6O2 (Mmethyl \
acetate), C4H8O2 (ethyl acetate), C2H6O (dimethyl ether), C3H8O (methyl ethyl \
ether), C4H10O (diethyl ether), C2H4O (ethylene ether), C4H8O \
(tetrahydrofuran), CH5N (methylamine), C2H7N (dimethylainine), C3H9N \
(trimethylamine), C2H7N (ethylamine), C4H11N (diethylamine), C6H15N \
(trimetylamine), CH3NO2 (nitromethane), C2H3N (acetonitrile), C3H3N \
(acrylonitrile), C5H5N (pyridine), CH4S (methyl mercaptan), C2H6S (dimethyl \
sulphide), C2H6S (ethyl mercaptan), CH3F (fluoromethane), CH2F2 \
(difluoromethane), CHF3 (trifluoromethane), C2H5F (fluoroethane), C2H4F2 \
(1,1-difluoroethane), C2H3F3 (1,1,1-trifluoroethane), CH3CI (chloromethane), \
CHCI3 (trichloromethane), C2H4Cl2 (l,l-dicliloroethane), C6H5CI \
(chlorobenzene), C2H5Br (bromoethane), HBr, HF, NO2, HCl, HI, C3H6 (propene), \
C4H8 (Isobutene), SiClF3, SiCl2F2, SiCl3F, He, Ne, Ar, Kr, Xe, F2, Br2, I2, \
Cl2, O2, S, N2, H2, CS2, CH4, C2H6 (ethane), C3H8 (propane), C2H4 (ethylene), \
C4H10 (butane), BF3, BCl3, SiF4, SiH4, SiCl4, H2O, CO2, NH3\"\>", 
  "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.445235652233035*^9},
 CellTags->"Info3445239251-1572335"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Gibbs free energy", "Subsubtitle",
 FontSize->14],

Cell["\<\
The function GEOSCG calculates the Gibbs free energy of a fluid.\
\>", "Text",
 FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "GEOSCG"}]], "Input"],

Cell[BoxData[
 StyleBox["\<\"GEOSCG[p,t,sp,x, options] calculates the molar Gibbs free \
energy according to Churakov & Gottschalk (2003) using the pressure \
p[MPa],the temperature t[K], sp the list of species names of species as \
strings and x the list of their mole fractions. GEOSCG returns a list of two \
elements containing the molar density [MPa*mol/J] and its Gibbs free energy \
[J/mol] for the liquid and the vapor phase, respectively. The first element \
contains the results for the stable phase, the second the result for a \
possible metastable phase. A result of {0,0} in the second element signals a \
single solution for the molar density and therefore supercritical conditions. \
GEOSCG does not include the temperature dependent term involving the heat \
capacities of the fluid at standard conditions ( (G at t and 0.1 MPa) - (G at \
273.15 and 0.1 MPa), ideal gas). Optional parameters are Speed (either -> \
slow (internal Mathematica) or -> fast (external Fortran routine which is \
only available for MacOS X) and NewSpecies -> {{name1,\[Epsilon]1,\[Sigma]1,\
\[Mu]1,\[Alpha]1,molecularweight1}, {name2,\[Epsilon]2,\[Sigma]2,\[Mu]2,\
\[Alpha]2,molecularweight2}, ...} for external species (default NewSpecies -> \
{}).\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.4452356526303167`*^9},
 CellTags->"Info3445239252-1367318"]
}, Open  ]],

Cell["Boiling of water at 0.1 MPa:", "Text",
 FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sp", "=", " ", 
   RowBox[{"{", "\"\<H2O\>\"", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"x", "=", 
   RowBox[{"{", "1.", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"p", "=", ".1"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"t", "=", " ", 
   RowBox[{"99.1", "+", "273.15"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g", "=", 
   RowBox[{"GEOSCG", "[", 
    RowBox[{"p", ",", "t", ",", "sp", ",", "x"}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", "\"\<liquid stable\>\"", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<liquid density: \>\"", ",", 
   RowBox[{"g", "\[LeftDoubleBracket]", 
    RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
   "\"\< MPa*mol/J at \>\"", ",", "p", ",", "\"\< MPa and \>\"", ",", " ", 
   "t", ",", "\"\< K\>\""}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<liquid G      : \>\"", ",", 
   RowBox[{"g", "\[LeftDoubleBracket]", 
    RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
   "\"\< J/mol at \>\"", ",", "p", ",", "\"\< MPa and \>\"", ",", " ", "t", 
   ",", "\"\< K\>\""}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<vapor density : \>\"", ",", 
   RowBox[{"g", "\[LeftDoubleBracket]", 
    RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
   "\"\< MPa*mol/J at \>\"", ",", "p", ",", "\"\< MPa and \>\"", ",", " ", 
   "t", ",", "\"\< K\>\""}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<vapor G       : \>\"", ",", 
    RowBox[{"g", "\[LeftDoubleBracket]", 
     RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
    "\"\< J/mol at \>\"", ",", "p", ",", "\"\< MPa and \>\"", ",", " ", "t", 
    ",", "\"\< K\>\""}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"t", "=", " ", 
   RowBox[{"99.2", "+", "273.15"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g", "=", 
   RowBox[{"GEOSCG", "[", 
    RowBox[{"p", ",", "t", ",", "sp", ",", "x"}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", "\"\<vapor stable\>\"", "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<liquid density: \>\"", ",", 
   RowBox[{"g", "\[LeftDoubleBracket]", 
    RowBox[{"2", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
   "\"\< MPa*mol/J at \>\"", ",", "p", ",", "\"\< MPa and \>\"", ",", " ", 
   "t", ",", "\"\< K\>\""}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<liquid G      : \>\"", ",", 
   RowBox[{"g", "\[LeftDoubleBracket]", 
    RowBox[{"2", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
   "\"\< J/mol at \>\"", ",", "p", ",", "\"\< MPa and \>\"", ",", " ", "t", 
   ",", "\"\< K\>\""}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<vapor density : \>\"", ",", 
   RowBox[{"g", "\[LeftDoubleBracket]", 
    RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
   "\"\< MPa*mol/J at \>\"", ",", "p", ",", "\"\< MPa and \>\"", ",", " ", 
   "t", ",", "\"\< K\>\""}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<vapor G       : \>\"", ",", 
    RowBox[{"g", "\[LeftDoubleBracket]", 
     RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
    "\"\< J/mol at \>\"", ",", "p", ",", "\"\< MPa and \>\"", ",", " ", "t", 
    ",", "\"\< K\>\""}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.055508191998901134`", ",", "3061.7043106475944`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.00003266145165460039`", ",", "3061.823708823415`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.445235652836561*^9}],

Cell[BoxData["\<\"liquid stable\"\>"], "Print",
 CellChangeTimes->{3.4452356528657303`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"liquid density: \"\>", "\[InvisibleSpace]", 
   "0.055508191998901134`", "\[InvisibleSpace]", "\<\" MPa*mol/J at \"\>", 
   "\[InvisibleSpace]", "0.1`", "\[InvisibleSpace]", "\<\" MPa and \"\>", 
   "\[InvisibleSpace]", "372.25`", "\[InvisibleSpace]", "\<\" K\"\>"}],
  SequenceForm[
  "liquid density: ", 0.055508191998901134`, " MPa*mol/J at ", 0.1, 
   " MPa and ", 372.25, " K"],
  Editable->False]], "Print",
 CellChangeTimes->{3.445235652898341*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"liquid G      : \"\>", "\[InvisibleSpace]", 
   "3061.7043106475944`", "\[InvisibleSpace]", "\<\" J/mol at \"\>", 
   "\[InvisibleSpace]", "0.1`", "\[InvisibleSpace]", "\<\" MPa and \"\>", 
   "\[InvisibleSpace]", "372.25`", "\[InvisibleSpace]", "\<\" K\"\>"}],
  SequenceForm[
  "liquid G      : ", 3061.7043106475944`, " J/mol at ", 0.1, " MPa and ", 
   372.25, " K"],
  Editable->False]], "Print",
 CellChangeTimes->{3.445235652931308*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"vapor density : \"\>", "\[InvisibleSpace]", 
   "0.00003266145165460039`", "\[InvisibleSpace]", "\<\" MPa*mol/J at \"\>", 
   "\[InvisibleSpace]", "0.1`", "\[InvisibleSpace]", "\<\" MPa and \"\>", 
   "\[InvisibleSpace]", "372.25`", "\[InvisibleSpace]", "\<\" K\"\>"}],
  SequenceForm[
  "vapor density : ", 0.00003266145165460039, " MPa*mol/J at ", 0.1, 
   " MPa and ", 372.25, " K"],
  Editable->False]], "Print",
 CellChangeTimes->{3.445235652966754*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"vapor G       : \"\>", "\[InvisibleSpace]", 
   "3061.823708823415`", "\[InvisibleSpace]", "\<\" J/mol at \"\>", 
   "\[InvisibleSpace]", "0.1`", "\[InvisibleSpace]", "\<\" MPa and \"\>", 
   "\[InvisibleSpace]", "372.25`", "\[InvisibleSpace]", "\<\" K\"\>"}],
  SequenceForm[
  "vapor G       : ", 3061.823708823415, " J/mol at ", 0.1, " MPa and ", 
   372.25, " K"],
  Editable->False]], "Print",
 CellChangeTimes->{3.445235652997932*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.00003265233673477638`", ",", "3062.6781534737706`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"0.05550814753829597`", ",", "3073.4925336462607`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.4452356530471478`*^9}],

Cell[BoxData["\<\"vapor stable\"\>"], "Print",
 CellChangeTimes->{3.445235653078382*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"liquid density: \"\>", "\[InvisibleSpace]", 
   "0.05550814753829597`", "\[InvisibleSpace]", "\<\" MPa*mol/J at \"\>", 
   "\[InvisibleSpace]", "0.1`", "\[InvisibleSpace]", "\<\" MPa and \"\>", 
   "\[InvisibleSpace]", "372.34999999999997`", 
   "\[InvisibleSpace]", "\<\" K\"\>"}],
  SequenceForm[
  "liquid density: ", 0.05550814753829597, " MPa*mol/J at ", 0.1, " MPa and ",
    372.34999999999997`, " K"],
  Editable->False]], "Print",
 CellChangeTimes->{3.445235653117167*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"liquid G      : \"\>", "\[InvisibleSpace]", 
   "3073.4925336462607`", "\[InvisibleSpace]", "\<\" J/mol at \"\>", 
   "\[InvisibleSpace]", "0.1`", "\[InvisibleSpace]", "\<\" MPa and \"\>", 
   "\[InvisibleSpace]", "372.34999999999997`", 
   "\[InvisibleSpace]", "\<\" K\"\>"}],
  SequenceForm[
  "liquid G      : ", 3073.4925336462607`, " J/mol at ", 0.1, " MPa and ", 
   372.34999999999997`, " K"],
  Editable->False]], "Print",
 CellChangeTimes->{3.445235653148657*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"vapor density : \"\>", "\[InvisibleSpace]", 
   "0.00003265233673477638`", "\[InvisibleSpace]", "\<\" MPa*mol/J at \"\>", 
   "\[InvisibleSpace]", "0.1`", "\[InvisibleSpace]", "\<\" MPa and \"\>", 
   "\[InvisibleSpace]", "372.34999999999997`", 
   "\[InvisibleSpace]", "\<\" K\"\>"}],
  SequenceForm[
  "vapor density : ", 0.00003265233673477638, " MPa*mol/J at ", 0.1, 
   " MPa and ", 372.34999999999997`, " K"],
  Editable->False]], "Print",
 CellChangeTimes->{3.4452356531838284`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"vapor G       : \"\>", "\[InvisibleSpace]", 
   "3062.6781534737706`", "\[InvisibleSpace]", "\<\" J/mol at \"\>", 
   "\[InvisibleSpace]", "0.1`", "\[InvisibleSpace]", "\<\" MPa and \"\>", 
   "\[InvisibleSpace]", "372.34999999999997`", 
   "\[InvisibleSpace]", "\<\" K\"\>"}],
  SequenceForm[
  "vapor G       : ", 3062.6781534737706`, " J/mol at ", 0.1, " MPa and ", 
   372.34999999999997`, " K"],
  Editable->False]], "Print",
 CellChangeTimes->{3.4452356532163763`*^9}]
}, Open  ]],

Cell["\<\
The EOS underestimates the boiling temperature at 0.1 MPa by approximately \
0.85 K.\
\>", "Text",
 FontSize->14],

Cell["At supercritical conditions:", "Text",
 FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sp", "=", " ", 
   RowBox[{"{", "\"\<H2O\>\"", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"x", "=", 
   RowBox[{"{", "1.", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p", "=", "1000."}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"t", "=", " ", 
    RowBox[{"500", "+", "273.15"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g", "=", 
   RowBox[{"GEOSCG", "[", 
    RowBox[{"p", ",", "t", ",", "sp", ",", "x"}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", "\"\<supercritical fluid\>\"", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<fluid density: \>\"", ",", 
   RowBox[{"g", "\[LeftDoubleBracket]", 
    RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
   "\"\< MPa*mol/J at \>\"", ",", "p", ",", "\"\< MPa and \>\"", ",", " ", 
   "t", ",", "\"\< K\>\""}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<fluid G      : \>\"", ",", 
   RowBox[{"g", "\[LeftDoubleBracket]", 
    RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
   "\"\< J/mol at \>\"", ",", "p", ",", "\"\< MPa and \>\"", ",", " ", "t", 
   ",", "\"\< K\>\""}], "]"}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.05579607224206206`", ",", "65092.83760616924`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.445235653326901*^9}],

Cell[BoxData["\<\"supercritical fluid\"\>"], "Print",
 CellChangeTimes->{3.445235653359788*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"fluid density: \"\>", "\[InvisibleSpace]", 
   "0.05579607224206206`", "\[InvisibleSpace]", "\<\" MPa*mol/J at \"\>", 
   "\[InvisibleSpace]", "1000.`", "\[InvisibleSpace]", "\<\" MPa and \"\>", 
   "\[InvisibleSpace]", "773.15`", "\[InvisibleSpace]", "\<\" K\"\>"}],
  SequenceForm[
  "fluid density: ", 0.05579607224206206, " MPa*mol/J at ", 1000., 
   " MPa and ", 773.15, " K"],
  Editable->False]], "Print",
 CellChangeTimes->{3.445235653395001*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"fluid G      : \"\>", "\[InvisibleSpace]", 
   "65092.83760616924`", "\[InvisibleSpace]", "\<\" J/mol at \"\>", 
   "\[InvisibleSpace]", "1000.`", "\[InvisibleSpace]", "\<\" MPa and \"\>", 
   "\[InvisibleSpace]", "773.15`", "\[InvisibleSpace]", "\<\" K\"\>"}],
  SequenceForm[
  "fluid G      : ", 65092.83760616924, " J/mol at ", 1000., " MPa and ", 
   773.15, " K"],
  Editable->False]], "Print",
 CellChangeTimes->{3.445235653433008*^9}]
}, Open  ]],

Cell["For MacOS X users only:", "Text",
 FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sp", "=", " ", 
   RowBox[{"{", "\"\<H2O\>\"", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"x", "=", 
   RowBox[{"{", "1.", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p", "=", "1000."}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"t", "=", " ", 
    RowBox[{"500", "+", "273.15"}]}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"fast", " ", "is", " ", "default"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Timing", "[", 
   RowBox[{"GEOSCG", "[", 
    RowBox[{"p", ",", "t", ",", "sp", ",", "x", ",", 
     RowBox[{"Speed", "->", "\"\<fast\>\""}]}], "]"}], "]"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"slow", " ", "is", " ", "really", " ", "slow"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"Timing", "[", 
  RowBox[{"GEOSCG", "[", 
   RowBox[{"p", ",", "t", ",", "sp", ",", "x", ",", 
    RowBox[{"Speed", "->", "\"\<slow\>\""}]}], "]"}], "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.017442000000000013`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.05579607224206206`", ",", "65092.83760616924`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.406003101926435*^9, 3.4060031149962597`*^9}, 
   3.44523565351857*^9, 3.445235842681559*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1.5575970000000001`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.055796171340753986`", ",", "65092.81488881777`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.406003101926435*^9, 3.4060031149962597`*^9}, 
   3.44523565351857*^9, 3.445235844236164*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Fugacity", "Subsubtitle",
 FontSize->14],

Cell["The function FEOSCG calculates the fugacities of a fluid.", "Text",
 FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "FEOSCG"}]], "Input"],

Cell[BoxData[
 StyleBox["\<\"FEOSCG[p,t,sp,x, options] calculates the normalized fugacities \
for the stable phase ( (f at p) / (0.1 MPa) ) according to Churakov & \
Gottschalk (2003) using the pressure p[MPa],the temperature t[K], sp the list \
of species names as strings and x the list of their mole fractions. For fluid \
mixtures the function returns a list of fugacities in the same order as x. \
This list does not include the configurational term but only ( (f at p) / \
(0.1 MPa) ). To get the complete term, the result of  FEOSCG must be \
multiplied by x. Optional parameters are Speed (either -> slow (internal \
Mathematica) or -> fast (external Fortran routine which is only available for \
MacOS X) and NewSpecies -> \
{{name1,\[Epsilon]1,\[Sigma]1,\[Mu]1,\[Alpha]1,molecularweight1}, {name2,\
\[Epsilon]2,\[Sigma]2,\[Mu]2,\[Alpha]2,molecularweight2}, ...} for external \
species (default NewSpecies -> {}).\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.445235655313573*^9},
 CellTags->"Info3445239255-5177067"]
}, Open  ]],

Cell["Fugacity of pure H2O:", "Text",
 FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sp", "=", " ", 
   RowBox[{"{", "\"\<H2O\>\"", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"x", "=", 
   RowBox[{"{", "1.", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p", "=", "100."}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"t", "=", " ", 
    RowBox[{"500", "+", "273.15"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"f", "=", 
    RowBox[{"FEOSCG", "[", 
     RowBox[{"p", ",", "t", ",", "sp", ",", "x"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", "\"\<fugacity of a pure fluid\>\"", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<fluid fugacity of \>\"", ",", 
   RowBox[{"sp", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
   "\"\<: \>\"", ",", "f"}], "]"}]}], "Input"],

Cell[BoxData["\<\"fugacity of a pure fluid\"\>"], "Print",
 CellChangeTimes->{3.4452356554964533`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"fluid fugacity of \"\>", "\[InvisibleSpace]", "\<\"H2O\"\>", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   "452.1573725514433`"}],
  SequenceForm["fluid fugacity of ", "H2O", ": ", 452.1573725514433],
  Editable->False]], "Print",
 CellChangeTimes->{3.445235655524508*^9}]
}, Open  ]],

Cell["Fugacity of H2O and CO2 mixtures:", "Text",
 FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sp", "=", " ", 
   RowBox[{"{", 
    RowBox[{"\"\<H2O\>\"", ",", "\"\<CO2\>\""}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"x", "=", 
   RowBox[{"{", 
    RowBox[{"0.6", ",", "0.4"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p", "=", "100."}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"t", "=", " ", 
    RowBox[{"500", "+", "273.15"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"f", "=", 
  RowBox[{"FEOSCG", "[", 
   RowBox[{"p", ",", "t", ",", "sp", ",", "x"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"f", "=", 
   RowBox[{"f", " ", "x"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", "\"\<fugacity of a fluid mixture\>\"", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<fluid fugacity of \>\"", ",", 
   RowBox[{"sp", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
   "\"\<: \>\"", ",", 
   RowBox[{"f", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<fluid fugacity of \>\"", ",", 
   RowBox[{"sp", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], ",", 
   "\"\<: \>\"", ",", 
   RowBox[{"f", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
  "]"}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"551.1806798984511`", ",", "1597.2605976087364`"}], "}"}]], "Output",\

 CellChangeTimes->{3.44523565577971*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"330.70840793907064`", ",", "638.9042390434946`"}], "}"}]], "Output",\

 CellChangeTimes->{3.445235655800065*^9}],

Cell[BoxData["\<\"fugacity of a fluid mixture\"\>"], "Print",
 CellChangeTimes->{3.445235655836776*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"fluid fugacity of \"\>", "\[InvisibleSpace]", "\<\"H2O\"\>", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   "330.70840793907064`"}],
  SequenceForm["fluid fugacity of ", "H2O", ": ", 330.70840793907064`],
  Editable->False]], "Print",
 CellChangeTimes->{3.445235655869863*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"fluid fugacity of \"\>", "\[InvisibleSpace]", "\<\"CO2\"\>", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   "638.9042390434946`"}],
  SequenceForm["fluid fugacity of ", "CO2", ": ", 638.9042390434946],
  Editable->False]], "Print",
 CellChangeTimes->{3.44523565590456*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Helmholtz free energy", "Subsubtitle",
 FontSize->14],

Cell["\<\
The function AEOSCG calculates the Helmholtz free energy of a fluid.\
\>", "Text",
 FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "AEOSCG"}]], "Input"],

Cell[BoxData[
 StyleBox["\<\"AEOSCG[\[Rho],t,sp,x, options] calculates the molar Helmholtz \
free energy according to Churakov & Gottschalk (2003) using the molar density \
\[Rho][MPa*mol/J],the temperature t[K], sp the list of species names as \
strings and x the list of their mole fractions. AEOSCG returns a list \
containing the Helmoltz free energy values {Aideal, Aresidual and Aideal + \
Aresidual} [J/mol], respectively. AEOSCG does not include the temperature \
dependent term involving the heat capacities of the fluid at standard \
conditions ( (A at t and (R t)/(0.1 MPa) - (A at 273.15 and (R 273.15)/(0.1 \
MPa), ideal gas). Optional parameters are Speed (either -> slow (internal \
Mathematica) or -> fast (external Fortran routine which is only available for \
MacOS X) and NewSpecies -> \
{{name1,\[Epsilon]1,\[Sigma]1,\[Mu]1,\[Alpha]1,molecularweight1}, {name2,\
\[Epsilon]2,\[Sigma]2,\[Mu]2,\[Alpha]2,molecularweight2}, ...} for external \
species (default NewSpecies -> {}).\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.4452356560887003`*^9},
 CellTags->"Info3445239255-2195668"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sp", "=", " ", 
   RowBox[{"{", "\"\<H2O\>\"", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"x", "=", 
   RowBox[{"{", "1.", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Rho]", "=", "0.05"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"t", "=", " ", 
   RowBox[{"500", "+", "273.15"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a", "=", 
   RowBox[{"AEOSCG", "[", 
    RowBox[{"\[Rho]", ",", "t", ",", "sp", ",", "x"}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<A: \>\"", ",", 
    RowBox[{"a", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], ",", 
    "\"\< J/mol at \>\"", ",", "\[Rho]", ",", "\"\< MPa*mol/J and \>\"", ",", 
    " ", "t", ",", "\"\< K\>\""}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"51910.8793488363`", ",", 
   RowBox[{"-", "6344.415240327956`"}], ",", "45566.46410850834`", ",", 
   "0.`"}], "}"}]], "Output",
 CellChangeTimes->{3.445235656282733*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"A: \"\>", "\[InvisibleSpace]", "45566.46410850834`", 
   "\[InvisibleSpace]", "\<\" J/mol at \"\>", "\[InvisibleSpace]", "0.05`", 
   "\[InvisibleSpace]", "\<\" MPa*mol/J and \"\>", "\[InvisibleSpace]", 
   "773.15`", "\[InvisibleSpace]", "\<\" K\"\>"}],
  SequenceForm[
  "A: ", 45566.46410850834, " J/mol at ", 0.05, " MPa*mol/J and ", 773.15, 
   " K"],
  Editable->False]], "Print",
 CellChangeTimes->{3.4452356563164043`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Volume", "Subsubtitle",
 FontSize->14],

Cell["The function VEOSCG calculates the molar volume of a fluid.", "Text",
 FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "VEOSCG"}]], "Input"],

Cell[BoxData[
 StyleBox["\<\"VEOSCG[p,t,sp,x, options] calculates the molar volumes \
according to Churakov & Gottschalk (2003) using the pressure p[MPa],the \
temperature t[K], sp the list of species names as strings and x the list of \
their mole fractions. VEOSCG returns a list of two elements containing the \
molar volume [J/MPa/mol] for liquid and vapor phase, respectively. The first \
element contains the results for the stable phase, the second the result for \
a possible metastable phase. A result of 0 in the second element signals a \
single solution for the molar volume and therefore supercritical conditions. \
Optional parameters are Speed (either -> slow (internal Mathematica) or -> \
fast (external Fortran routine which is only available for MacOS X) and \
NewSpecies -> \
{{name1,\[Epsilon]1,\[Sigma]1,\[Mu]1,\[Alpha]1,molecularweight1}, {name2,\
\[Epsilon]2,\[Sigma]2,\[Mu]2,\[Alpha]2,molecularweight2}, ...} for external \
species (default NewSpecies -> {}).\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.445235656516474*^9},
 CellTags->"Info3445239256-2130474"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sp", "=", " ", 
   RowBox[{"{", "\"\<H2O\>\"", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"x", "=", 
   RowBox[{"{", "1.", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"p", "=", "0.1"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"t", "=", 
   RowBox[{"99.1", "+", "273.15"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"v", "=", 
   RowBox[{"VEOSCG", "[", 
    RowBox[{"p", ",", "t", ",", "sp", ",", "x"}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", "\"\<liquid stable\>\"", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<liquid volume: \>\"", ",", 
   RowBox[{"v", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
   "\"\< J/MPa/mol at \>\"", ",", "p", ",", "\"\< MPa and \>\"", ",", " ", 
   "t", ",", "\"\< K\>\""}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<vapor volume : \>\"", ",", 
    RowBox[{"v", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], ",", 
    "\"\< J/MPa/mol at \>\"", ",", "p", ",", "\"\< MPa and \>\"", ",", " ", 
    "t", ",", "\"\< K\>\""}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"t", "=", " ", 
   RowBox[{"99.2", "+", "273.15"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"v", "=", 
   RowBox[{"VEOSCG", "[", 
    RowBox[{"p", ",", "t", ",", "sp", ",", "x"}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", "\"\<vapor stable\>\"", "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<liquid volume: \>\"", ",", 
   RowBox[{"v", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], ",", 
   "\"\< J/MPa/mol at \>\"", ",", "p", ",", "\"\< MPa and \>\"", ",", " ", 
   "t", ",", "\"\< K\>\""}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<vapor volume : \>\"", ",", 
   RowBox[{"v", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
   "\"\< J/MPa/mol at \>\"", ",", "p", ",", "\"\< MPa and \>\"", ",", " ", 
   "t", ",", "\"\< K\>\""}], "]"}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"18.015358886482854`", ",", "30617.132715812688`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.445235656694269*^9}],

Cell[BoxData["\<\"liquid stable\"\>"], "Print",
 CellChangeTimes->{3.445235656720255*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"liquid volume: \"\>", "\[InvisibleSpace]", 
   "18.015358886482854`", "\[InvisibleSpace]", "\<\" J/MPa/mol at \"\>", 
   "\[InvisibleSpace]", "0.1`", "\[InvisibleSpace]", "\<\" MPa and \"\>", 
   "\[InvisibleSpace]", "372.25`", "\[InvisibleSpace]", "\<\" K\"\>"}],
  SequenceForm[
  "liquid volume: ", 18.015358886482854`, " J/MPa/mol at ", 0.1, " MPa and ", 
   372.25, " K"],
  Editable->False]], "Print",
 CellChangeTimes->{3.445235656756218*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"vapor volume : \"\>", "\[InvisibleSpace]", 
   "30617.132715812688`", "\[InvisibleSpace]", "\<\" J/MPa/mol at \"\>", 
   "\[InvisibleSpace]", "0.1`", "\[InvisibleSpace]", "\<\" MPa and \"\>", 
   "\[InvisibleSpace]", "372.25`", "\[InvisibleSpace]", "\<\" K\"\>"}],
  SequenceForm[
  "vapor volume : ", 30617.132715812688`, " J/MPa/mol at ", 0.1, " MPa and ", 
   372.25, " K"],
  Editable->False]], "Print",
 CellChangeTimes->{3.445235656789318*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"30625.679507186687`", ",", "18.015373316324126`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.445235656823738*^9}],

Cell[BoxData["\<\"vapor stable\"\>"], "Print",
 CellChangeTimes->{3.445235656857592*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"liquid volume: \"\>", "\[InvisibleSpace]", 
   "18.015373316324126`", "\[InvisibleSpace]", "\<\" J/MPa/mol at \"\>", 
   "\[InvisibleSpace]", "0.1`", "\[InvisibleSpace]", "\<\" MPa and \"\>", 
   "\[InvisibleSpace]", "372.34999999999997`", 
   "\[InvisibleSpace]", "\<\" K\"\>"}],
  SequenceForm[
  "liquid volume: ", 18.015373316324126`, " J/MPa/mol at ", 0.1, " MPa and ", 
   372.34999999999997`, " K"],
  Editable->False]], "Print",
 CellChangeTimes->{3.4452356568918037`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"vapor volume : \"\>", "\[InvisibleSpace]", 
   "30625.679507186687`", "\[InvisibleSpace]", "\<\" J/MPa/mol at \"\>", 
   "\[InvisibleSpace]", "0.1`", "\[InvisibleSpace]", "\<\" MPa and \"\>", 
   "\[InvisibleSpace]", "372.34999999999997`", 
   "\[InvisibleSpace]", "\<\" K\"\>"}],
  SequenceForm[
  "vapor volume : ", 30625.679507186687`, " J/MPa/mol at ", 0.1, " MPa and ", 
   372.34999999999997`, " K"],
  Editable->False]], "Print",
 CellChangeTimes->{3.445235656925107*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Density", "Subsubtitle",
 FontSize->14],

Cell["\<\
The function \[Rho]EOSCG calculates the molar density of a fluid.\
\>", "Text",
 FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "\[Rho]EOSCG"}]], "Input"],

Cell[BoxData[
 StyleBox["\<\"\[Rho]EOSCG[p,t,sp,x, options] calculates the molar densities \
according to Churakov & Gottschalk (2003) using the pressure p[MPa],the \
temperature t[K], sp the list of species names as strings and x the list of \
their mole fractions. \[Rho]EOSCG returns a list of two elements containing \
the molar densities [MPa*mol/J] for liquid and vapor phase, respectively. The \
first element contains the results for the stable phase, the second the \
result for a possible metastable phase. A result of 0 in the second element \
signals a single solution for the molar density and therefore supercritical \
conditions. Optional parameters are Speed (either -> slow (internal \
Mathematica) or -> fast (external Fortran routine which is only available for \
MacOS X) and NewSpecies -> \
{{name1,\[Epsilon]1,\[Sigma]1,\[Mu]1,\[Alpha]1,molecularweight1}, {name2,\
\[Epsilon]2,\[Sigma]2,\[Mu]2,\[Alpha]2,molecularweight2}, ...} for external \
species (default NewSpecies -> {}).\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.445235657135322*^9},
 CellTags->"Info3445239257-3453485"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sp", "=", " ", 
   RowBox[{"{", "\"\<H2O\>\"", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"x", "=", 
   RowBox[{"{", "1.", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"p", "=", "0.1"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"t", "=", 
   RowBox[{"99.1", "+", "273.15"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Rho]", "=", 
   RowBox[{"\[Rho]EOSCG", "[", 
    RowBox[{"p", ",", "t", ",", "sp", ",", "x"}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", "\"\<liquid stable\>\"", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<liquid density: \>\"", ",", 
   RowBox[{"\[Rho]", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
   ",", "\"\< MPa*mol/J at \>\"", ",", "p", ",", "\"\< MPa and \>\"", ",", 
   " ", "t", ",", "\"\< K\>\""}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<vapor density : \>\"", ",", 
    RowBox[{"\[Rho]", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
    ",", "\"\< MPa*mol/J at \>\"", ",", "p", ",", "\"\< MPa and \>\"", ",", 
    " ", "t", ",", "\"\< K\>\""}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"t", "=", " ", 
   RowBox[{"99.2", "+", "273.15"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Rho]", "=", 
   RowBox[{"\[Rho]EOSCG", "[", 
    RowBox[{"p", ",", "t", ",", "sp", ",", "x"}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", "\"\<vapor stable\>\"", "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<liquid density: \>\"", ",", 
   RowBox[{"\[Rho]", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
   ",", "\"\< MPa*mol/J at \>\"", ",", "p", ",", "\"\< MPa and \>\"", ",", 
   " ", "t", ",", "\"\< K\>\""}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<vapor density : \>\"", ",", 
   RowBox[{"\[Rho]", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
   ",", "\"\< MPa*mol/J at \>\"", ",", "p", ",", "\"\< MPa and \>\"", ",", 
   " ", "t", ",", "\"\< K\>\""}], "]"}], "\[IndentingNewLine]"}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.055508191998901134`", ",", "0.00003266145165460039`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.445235657362317*^9}],

Cell[BoxData["\<\"liquid stable\"\>"], "Print",
 CellChangeTimes->{3.445235657382741*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"liquid density: \"\>", "\[InvisibleSpace]", 
   "0.055508191998901134`", "\[InvisibleSpace]", "\<\" MPa*mol/J at \"\>", 
   "\[InvisibleSpace]", "0.1`", "\[InvisibleSpace]", "\<\" MPa and \"\>", 
   "\[InvisibleSpace]", "372.25`", "\[InvisibleSpace]", "\<\" K\"\>"}],
  SequenceForm[
  "liquid density: ", 0.055508191998901134`, " MPa*mol/J at ", 0.1, 
   " MPa and ", 372.25, " K"],
  Editable->False]], "Print",
 CellChangeTimes->{3.445235657407364*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"vapor density : \"\>", "\[InvisibleSpace]", 
   "0.00003266145165460039`", "\[InvisibleSpace]", "\<\" MPa*mol/J at \"\>", 
   "\[InvisibleSpace]", "0.1`", "\[InvisibleSpace]", "\<\" MPa and \"\>", 
   "\[InvisibleSpace]", "372.25`", "\[InvisibleSpace]", "\<\" K\"\>"}],
  SequenceForm[
  "vapor density : ", 0.00003266145165460039, " MPa*mol/J at ", 0.1, 
   " MPa and ", 372.25, " K"],
  Editable->False]], "Print",
 CellChangeTimes->{3.4452356574403477`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.00003265233673477638`", ",", "0.05550814753829597`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.445235657473235*^9}],

Cell[BoxData["\<\"vapor stable\"\>"], "Print",
 CellChangeTimes->{3.445235657506681*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"liquid density: \"\>", "\[InvisibleSpace]", 
   "0.05550814753829597`", "\[InvisibleSpace]", "\<\" MPa*mol/J at \"\>", 
   "\[InvisibleSpace]", "0.1`", "\[InvisibleSpace]", "\<\" MPa and \"\>", 
   "\[InvisibleSpace]", "372.34999999999997`", 
   "\[InvisibleSpace]", "\<\" K\"\>"}],
  SequenceForm[
  "liquid density: ", 0.05550814753829597, " MPa*mol/J at ", 0.1, " MPa and ",
    372.34999999999997`, " K"],
  Editable->False]], "Print",
 CellChangeTimes->{3.445235657540359*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"vapor density : \"\>", "\[InvisibleSpace]", 
   "0.00003265233673477638`", "\[InvisibleSpace]", "\<\" MPa*mol/J at \"\>", 
   "\[InvisibleSpace]", "0.1`", "\[InvisibleSpace]", "\<\" MPa and \"\>", 
   "\[InvisibleSpace]", "372.34999999999997`", 
   "\[InvisibleSpace]", "\<\" K\"\>"}],
  SequenceForm[
  "vapor density : ", 0.00003265233673477638, " MPa*mol/J at ", 0.1, 
   " MPa and ", 372.34999999999997`, " K"],
  Editable->False]], "Print",
 CellChangeTimes->{3.445235657574112*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
CellGrouping->Manual,
WindowSize->{890, 895},
WindowMargins->{{Automatic, 438}, {Automatic, 56}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
ShowSelection->True,
FrontEndVersion->"7.0 for Mac OS X x86 (32-bit) (February 18, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Info3445239251-1572335"->{
  Cell[4655, 168, 1756, 25, 256, "Print",
   CellTags->"Info3445239251-1572335"]},
 "Info3445239252-1367318"->{
  Cell[6686, 211, 1363, 19, 186, "Print",
   CellTags->"Info3445239252-1367318"]},
 "Info3445239255-5177067"->{
  Cell[21750, 607, 1039, 15, 132, "Print",
   CellTags->"Info3445239255-5177067"]},
 "Info3445239255-2195668"->{
  Cell[27146, 765, 1114, 16, 150, "Print",
   CellTags->"Info3445239255-2195668"]},
 "Info3445239256-2130474"->{
  Cell[30193, 847, 1101, 16, 150, "Print",
   CellTags->"Info3445239256-2130474"]},
 "Info3445239257-3453485"->{
  Cell[36380, 1006, 1117, 16, 150, "Print",
   CellTags->"Info3445239257-3453485"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Info3445239251-1572335", 42824, 1165},
 {"Info3445239252-1367318", 42936, 1168},
 {"Info3445239255-5177067", 43048, 1171},
 {"Info3445239255-2195668", 43161, 1174},
 {"Info3445239256-2130474", 43274, 1177},
 {"Info3445239257-3453485", 43387, 1180}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 55, 0, 76, "Title"],
Cell[625, 24, 1225, 34, 198, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1887, 63, 27, 0, 46, "Subtitle"],
Cell[1917, 65, 209, 3, 164, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2163, 73, 30, 0, 46, "Subtitle"],
Cell[2196, 75, 364, 7, 62, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2597, 87, 32, 0, 46, "Subtitle"],
Cell[2632, 89, 831, 24, 96, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3500, 118, 33, 0, 46, "Subtitle"],
Cell[3536, 120, 661, 16, 79, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4234, 141, 41, 0, 46, "Subtitle"],
Cell[4278, 143, 68, 1, 28, "Text"],
Cell[4349, 146, 78, 1, 27, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4464, 152, 41, 3, 71, "Subtitle"],
Cell[CellGroupData[{
Cell[4530, 159, 64, 4, 39, "Subsubtitle"],
Cell[4597, 165, 55, 1, 27, "Input"],
Cell[4655, 168, 1756, 25, 256, "Print",
 CellTags->"Info3445239251-1572335"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6448, 198, 55, 1, 24, "Subsubtitle"],
Cell[6506, 201, 103, 3, 28, "Text"],
Cell[CellGroupData[{
Cell[6634, 208, 49, 1, 27, "Input"],
Cell[6686, 211, 1363, 19, 186, "Print",
 CellTags->"Info3445239252-1367318"]
}, Open  ]],
Cell[8064, 233, 59, 1, 28, "Text"],
Cell[CellGroupData[{
Cell[8148, 238, 3570, 81, 358, "Input"],
Cell[11721, 321, 293, 8, 27, "Output"],
Cell[12017, 331, 91, 1, 20, "Print"],
Cell[12111, 334, 504, 10, 20, "Print"],
Cell[12618, 346, 492, 10, 20, "Print"],
Cell[13113, 358, 507, 10, 20, "Print"],
Cell[13623, 370, 489, 10, 20, "Print"],
Cell[14115, 382, 299, 9, 27, "Output"],
Cell[14417, 393, 88, 1, 20, "Print"],
Cell[14508, 396, 530, 11, 20, "Print"],
Cell[15041, 409, 521, 11, 20, "Print"],
Cell[15565, 422, 538, 11, 20, "Print"],
Cell[16106, 435, 523, 11, 20, "Print"]
}, Open  ]],
Cell[16644, 449, 123, 4, 28, "Text"],
Cell[16770, 455, 59, 1, 28, "Text"],
Cell[CellGroupData[{
Cell[16854, 460, 1307, 32, 178, "Input"],
Cell[18164, 494, 249, 7, 27, "Output"],
Cell[18416, 503, 95, 1, 20, "Print"],
Cell[18514, 506, 503, 10, 20, "Print"],
Cell[19020, 518, 491, 10, 20, "Print"]
}, Open  ]],
Cell[19526, 531, 54, 1, 28, "Text"],
Cell[CellGroupData[{
Cell[19605, 536, 1073, 29, 163, "Input"],
Cell[20681, 567, 399, 10, 27, "Output"],
Cell[21083, 579, 404, 11, 27, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[21536, 596, 46, 1, 24, "Subsubtitle"],
Cell[21585, 599, 88, 1, 28, "Text"],
Cell[CellGroupData[{
Cell[21698, 604, 49, 1, 27, "Input"],
Cell[21750, 607, 1039, 15, 132, "Print",
 CellTags->"Info3445239255-5177067"]
}, Open  ]],
Cell[22804, 625, 52, 1, 28, "Text"],
Cell[CellGroupData[{
Cell[22881, 630, 910, 25, 148, "Input"],
Cell[23794, 657, 102, 1, 20, "Print"],
Cell[23899, 660, 339, 7, 20, "Print"]
}, Open  ]],
Cell[24253, 670, 64, 1, 28, "Text"],
Cell[CellGroupData[{
Cell[24342, 675, 1408, 38, 193, "Input"],
Cell[25753, 715, 151, 4, 27, "Output"],
Cell[25907, 721, 152, 4, 27, "Output"],
Cell[26062, 727, 103, 1, 20, "Print"],
Cell[26168, 730, 342, 7, 20, "Print"],
Cell[26513, 739, 338, 7, 20, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[26900, 752, 59, 1, 24, "Subsubtitle"],
Cell[26962, 755, 107, 3, 28, "Text"],
Cell[CellGroupData[{
Cell[27094, 762, 49, 1, 27, "Input"],
Cell[27146, 765, 1114, 16, 150, "Print",
 CellTags->"Info3445239255-2195668"]
}, Open  ]],
Cell[CellGroupData[{
Cell[28297, 786, 938, 25, 163, "Input"],
Cell[29238, 813, 210, 5, 27, "Output"],
Cell[29451, 820, 479, 10, 20, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[29979, 836, 44, 1, 24, "Subsubtitle"],
Cell[30026, 839, 90, 1, 28, "Text"],
Cell[CellGroupData[{
Cell[30141, 844, 49, 1, 27, "Input"],
Cell[30193, 847, 1101, 16, 150, "Print",
 CellTags->"Info3445239256-2130474"]
}, Open  ]],
Cell[CellGroupData[{
Cell[31331, 868, 2205, 51, 283, "Input"],
Cell[33539, 921, 154, 4, 27, "Output"],
Cell[33696, 927, 89, 1, 20, "Print"],
Cell[33788, 930, 498, 10, 20, "Print"],
Cell[34289, 942, 498, 10, 20, "Print"],
Cell[34790, 954, 154, 4, 27, "Output"],
Cell[34947, 960, 88, 1, 20, "Print"],
Cell[35038, 963, 529, 11, 20, "Print"],
Cell[35570, 976, 527, 11, 20, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[36146, 993, 45, 1, 24, "Subsubtitle"],
Cell[36194, 996, 104, 3, 29, "Text"],
Cell[CellGroupData[{
Cell[36323, 1003, 54, 1, 27, "Input"],
Cell[36380, 1006, 1117, 16, 150, "Print",
 CellTags->"Info3445239257-3453485"]
}, Open  ]],
Cell[CellGroupData[{
Cell[37534, 1027, 2249, 51, 283, "Input"],
Cell[39786, 1080, 160, 4, 27, "Output"],
Cell[39949, 1086, 89, 1, 20, "Print"],
Cell[40041, 1089, 504, 10, 20, "Print"],
Cell[40548, 1101, 509, 10, 20, "Print"],
Cell[41060, 1113, 159, 4, 27, "Output"],
Cell[41222, 1119, 88, 1, 20, "Print"],
Cell[41313, 1122, 530, 11, 20, "Print"],
Cell[41846, 1135, 536, 11, 20, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
