(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[      5043,        175]
NotebookOptionsPosition[      4213,        140]
NotebookOutlinePosition[      4628,        158]
CellTagsIndexPosition[      4585,        155]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["EOS for pure fluids and fluid mixtures", "Title"],

Cell[TextData[{
 "The package ",
 StyleBox["EOSCG.m",
  FontWeight->"Bold"],
 " implements the equation of state for pure fluids and fluid mixtures (EOS) \
according to the following two  publications\n\nChurakov and M. Gottschalk \
(2003) Perturbation theory based equation of state for polar molecular fluids \
I. Pure fluids\n\tGeochimica et Cosmochimica Acta 67, 2397-2414.\nChurakov \
and M. Gottschalk (2003) Perturbation theory based equation of state for \
polar molecular fluids II. Fluid mixtures\n\tGeochimica et Cosmochimica Acta \
67, 2415-2424.\n\nThe  ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " source code for the EOS is located in the file ",
 StyleBox["EOSCG_original",
  FontWeight->"Bold"],
 ". Building the package ",
 StyleBox["EOSCG.m",
  FontWeight->"Bold"],
 " (instructions to modify the package are located in the file ",
 StyleBox["make_package",
  FontWeight->"Bold"],
 ") involves a file in InputForm with the name  ",
 StyleBox["EOSCG",
  FontWeight->"Bold"],
 " which is less readable than ",
 StyleBox["EOSCG_original",
  FontWeight->"Bold"],
 ", however."
}], "Text",
 FontFamily->"Times",
 FontSize->14,
 FontWeight->"Plain",
 FontVariations->{"CompatibilityType"->0}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Contact", "Subtitle"],

Cell[TextData[StyleBox["M. Gottschalk\nGeoForschungsZentrum\nTelegrafenberg\n\
14473 Potsdam\nGermany\n\nTel. +49 331 2881418\nFax  +49 331 2881402\nemail \
gottschalk@gfz-potsdam.de",
 FontSize->14]], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Disclaimer", "Subtitle"],

Cell["\<\
This software is written by M. Gottschalk and is provided to the scientific \
community. It is not intented to be used in any commercial context. The \
package implements the EOS as described in the appendix of the two \
publications mentioned above. The author does not take any responsibility for \
the calculated results. \
\>", "Text",
 FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["Installation", "Subtitle"],

Cell[TextData[{
 "The package has been tested for Mathematica 4.2 and 5.0 under MacOS X 10.2. \
Move the folder ",
 StyleBox["Fluids",
  FontWeight->"Bold"],
 " into the respective ",
 "Mathematic/AddOns/Applications ",
 "folder (e.g. ",
 StyleBox["Mathematica",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox[" 4.x/AddOns/Applications, ",
  FontWeight->"Bold"],
 "MacOS X users have to use the Crtl key and choose the Show Package Contents \
option to open the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " 4.x folder). The functioning of the package ",
 StyleBox["EOSCG.m",
  FontWeight->"Bold"],
 " should not depend on the operating system used. The package should also \
work with older versions of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ". This has not been tested, however. "
}], "Text",
 FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["MacOS X users", "Subtitle"],

Cell[TextData[{
 "MacOS X users benefit from a program with the name ",
 StyleBox["aeos",
  FontWeight->"Bold"],
 " which is a seperate compiled program calculating the Helmholtz free energy \
of the fluid. This program is called from the package",
 StyleBox[" EOSCG.m",
  FontWeight->"Bold"],
 " and replaces the time consuming calculations of the Helmholtz free energy. \
This increases the speed of the calculations by a factor of 50-100. Fast \
calculations are used by default. Slow calculations using only Mathematica \
code can be forced choosing the option ",
 StyleBox["\"slow\"",
  FontWeight->"Bold"],
 " in all functions."
}], "Text",
 FontSize->14]
}, Open  ]]
},
CellGrouping->Manual,
WindowSize->{912, 701},
WindowMargins->{{0, Automatic}, {Automatic, 18}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
FrontEndVersion->"7.0 for Mac OS X x86 (32-bit) (February 18, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 55, 0, 76, "Title"],
Cell[625, 24, 1215, 33, 198, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1877, 62, 27, 0, 46, "Subtitle"],
Cell[1907, 64, 209, 3, 164, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2153, 72, 30, 0, 46, "Subtitle"],
Cell[2186, 74, 364, 7, 62, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2587, 86, 32, 0, 46, "Subtitle"],
Cell[2622, 88, 841, 26, 79, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3500, 119, 33, 0, 46, "Subtitle"],
Cell[3536, 121, 661, 16, 94, "Text"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

