(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    192526,       4398]
NotebookOptionsPosition[    191437,       4363]
NotebookOutlinePosition[    191973,       4384]
CellTagsIndexPosition[    191930,       4381]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Version", " ", "1.03", " ", 
    RowBox[{"(", 
     RowBox[{"7.1", ".2005"}], ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"BeginPackage", "[", "\"\<Fluids`EOSCG`\>\"", "]"}], " ", 
   "\[IndentingNewLine]", "\n", "\n", 
   RowBox[{
    RowBox[{"Off", "[", 
     RowBox[{"General", "::", "spell1"}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Off", "[", 
     RowBox[{"General", "::", "spell"}], "]"}], ";"}], "\n", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"EOSCGSpecies", "::", "usage"}], "=", 
    "\"\<The following species are available: N2O, NO, H2S, SO2, COS, CO, \
PH3, HCN, CCl2O (phosgene), CH4O (methanol), C2H6O (ethanol), C3H8O \
(n-propanol), C3H8O (2-propanol), C4H10O (n-butanol), C4H10O (2-butanol), \
C4H10O (2-methyl-1-propanol), C4H10O (2-methyl-2-propanol), C6H6O (phenol), \
C3H6O (acetone), C4H8O (2-butaone), C5H10O (2-pentanone), C5H10O \
(3-pentanone), C5H10O (3-methyl-2-butanone), CH2O (formaldehyde), C2H4O \
(aceteldehyde), C3H6O (propionaldehyde), C2H4O2 (acetic acid), C2H4O2 (methyl \
Formate), C3H6O2 (ethyl formate), C4H8O2 (n-propyl formate), C3H6O2 (Mmethyl \
acetate), C4H8O2 (ethyl acetate), C2H6O (dimethyl ether), C3H8O (methyl ethyl \
ether), C4H10O (diethyl ether), C2H4O (ethylene ether), C4H8O \
(tetrahydrofuran), CH5N (methylamine), C2H7N (dimethylainine), C3H9N \
(trimethylamine), C2H7N (ethylamine), C4H11N (diethylamine), C6H15N \
(trimetylamine), CH3NO2 (nitromethane), C2H3N (acetonitrile), C3H3N \
(acrylonitrile), C5H5N (pyridine), CH4S (methyl mercaptan), C2H6S (dimethyl \
sulphide), C2H6S (ethyl mercaptan), CH3F (fluoromethane), CH2F2 \
(difluoromethane), CHF3 (trifluoromethane), C2H5F (fluoroethane), C2H4F2 \
(1,1-difluoroethane), C2H3F3 (1,1,1-trifluoroethane), CH3CI (chloromethane), \
CHCI3 (trichloromethane), C2H4Cl2 (l,l-dicliloroethane), C6H5CI \
(chlorobenzene), C2H5Br (bromoethane), HBr, HF, NO2, HCl, HI, C3H6 (propene), \
C4H8 (Isobutene), SiClF3, SiCl2F2, SiCl3F, He, Ne, Ar, Kr, Xe, F2, Br2, I2, \
Cl2, O2, S, N2, H2, CS2, CH4, C2H6 (ethane), C3H8 (propane), C2H4 (ethylene), \
C4H10 (butane), BF3, BCl3, SiF4, SiH4, SiCl4, H2O, CO2, NH3\>\""}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FEOSCG", "::", "usage"}], "=", 
    "\"\<FEOSCG[p,t,sp,x, options] calculates the normalized fugacities for \
the stable phase ( (f at p) / (0.1 MPa) ) according to Churakov & Gottschalk \
(2003) using the pressure p[MPa],the temperature t[K], sp the list of species \
names as strings and x the list of their mole fractions. For fluid mixtures \
the function returns a list of fugacities in the same order as x. This list \
does not include the configurational term but only ( (f at p) / (0.1 MPa) ). \
To get the complete term, the result of  FEOSCG must be multiplied by x. \
Optional parameters are Speed (either -> slow (internal Mathematica) or -> \
fast (external Fortran routine which is only available for MacOS X) and \
NewSpecies -> \
{{name1,\[Epsilon]1,\[Sigma]1,\[Mu]1,\[Alpha]1,molecularweight1}, {name2,\
\[Epsilon]2,\[Sigma]2,\[Mu]2,\[Alpha]2,molecularweight2}, ...} for external \
species (default NewSpecies -> {}).\>\""}], "\n", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"AEOSCG", "::", "usage"}], "=", 
    "\"\<AEOSCG[\[Rho],t,sp,x, options] calculates the molar Helmholtz free \
energy according to Churakov & Gottschalk (2003) using the molar density \
\[Rho][MPa*mol/J],the temperature t[K], sp the list of species names as \
strings and x the list of their mole fractions. AEOSCG returns a list \
containing the Helmoltz free energy values {Aideal, Aresidual and Aideal + \
Aresidual} [J/mol], respectively. AEOSCG does not include the temperature \
dependent term involving the heat capacities of the fluid at standard \
conditions ( (A at t and (R t)/(0.1 MPa) - (A at 273.15 and (R 273.15)/(0.1 \
MPa), ideal gas). Optional parameters are Speed (either -> slow (internal \
Mathematica) or -> fast (external Fortran routine which is only available for \
MacOS X) and NewSpecies -> \
{{name1,\[Epsilon]1,\[Sigma]1,\[Mu]1,\[Alpha]1,molecularweight1}, {name2,\
\[Epsilon]2,\[Sigma]2,\[Mu]2,\[Alpha]2,molecularweight2}, ...} for external \
species (default NewSpecies -> {}).\>\""}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"GEOSCG", "::", "usage"}], "=", 
    "\"\<GEOSCG[p,t,sp,x, options] calculates the molar Gibbs free energy \
according to Churakov & Gottschalk (2003) using the pressure p[MPa],the \
temperature t[K], sp the list of species names of species as strings and x \
the list of their mole fractions. GEOSCG returns a list of two elements \
containing the molar density [MPa*mol/J] and its Gibbs free energy [J/mol] \
for the liquid and the vapor phase, respectively. The first element contains \
the results for the stable phase, the second the result for a possible \
metastable phase. A result of {0,0} in the second element signals a single \
solution for the molar density and therefore supercritical conditions. GEOSCG \
does not include the temperature dependent term involving the heat capacities \
of the fluid at standard conditions ( (G at t and 0.1 MPa) - (G at 273.15 and \
0.1 MPa), ideal gas). Optional parameters are Speed (either -> slow (internal \
Mathematica) or -> fast (external Fortran routine which is only available for \
MacOS X) and NewSpecies -> \
{{name1,\[Epsilon]1,\[Sigma]1,\[Mu]1,\[Alpha]1,molecularweight1}, {name2,\
\[Epsilon]2,\[Sigma]2,\[Mu]2,\[Alpha]2,molecularweight2}, ...} for external \
species (default NewSpecies -> {}).\>\""}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Rho]EOSCG", "::", "usage"}], "=", 
    "\"\<\[Rho]EOSCG[p,t,sp,x, options] calculates the molar densities \
according to Churakov & Gottschalk (2003) using the pressure p[MPa],the \
temperature t[K], sp the list of species names as strings and x the list of \
their mole fractions. \[Rho]EOSCG returns a list of two elements containing \
the molar densities [MPa*mol/J] for liquid and vapor phase, respectively. The \
first element contains the results for the stable phase, the second the \
result for a possible metastable phase. A result of 0 in the second element \
signals a single solution for the molar density and therefore supercritical \
conditions. Optional parameters are Speed (either -> slow (internal \
Mathematica) or -> fast (external Fortran routine which is only available for \
MacOS X) and NewSpecies -> \
{{name1,\[Epsilon]1,\[Sigma]1,\[Mu]1,\[Alpha]1,molecularweight1}, {name2,\
\[Epsilon]2,\[Sigma]2,\[Mu]2,\[Alpha]2,molecularweight2}, ...} for external \
species (default NewSpecies -> {}).\>\""}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"VEOSCG", "::", "usage"}], "=", 
    "\"\<VEOSCG[p,t,sp,x, options] calculates the molar volumes according to \
Churakov & Gottschalk (2003) using the pressure p[MPa],the temperature t[K], \
sp the list of species names as strings and x the list of their mole \
fractions. VEOSCG returns a list of two elements containing the molar volume \
[J/MPa/mol] for liquid and vapor phase, respectively. The first element \
contains the results for the stable phase, the second the result for a \
possible metastable phase. A result of 0 in the second element signals a \
single solution for the molar volume and therefore supercritical conditions. \
Optional parameters are Speed (either -> slow (internal Mathematica) or -> \
fast (external Fortran routine which is only available for MacOS X) and \
NewSpecies -> \
{{name1,\[Epsilon]1,\[Sigma]1,\[Mu]1,\[Alpha]1,molecularweight1}, {name2,\
\[Epsilon]2,\[Sigma]2,\[Mu]2,\[Alpha]2,molecularweight2}, ...} for external \
species (default NewSpecies -> {}).\>\""}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"miscgap", "::", "usage"}], "=", " ", 
    "\"\<miscgap[p,t,species,increments, options] calculates the compositions \
of the coexisting phases (liquid and gas) with an InterpolatingFunction using \
the pressure p[MPa],the temperature t[K], sp the list of species names as \
strings and the number of increments (optional, default 25). Optional \
parameters are Speed (either -> slow (internal Mathematica) or -> fast \
(external Fortran routine which is only available for MacOS X) and NewSpecies \
-> {{name1,\[Epsilon]1,\[Sigma]1,\[Mu]1,\[Alpha]1,molecularweight1}, {name2,\
\[Epsilon]2,\[Sigma]2,\[Mu]2,\[Alpha]2,molecularweight2}, ...} for external \
species (default NewSpecies -> {}).\>\""}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"miscgapNewton", "::", "usage"}], "=", " ", 
    "\"\<miscgapNewton[p,t,species,increments,xl,xg, options] calculates the \
compositions of the coexisting phases (liquid and gas) with the Newton method \
using the pressure p[MPa],the temperature t[K], sp the list of species names \
as strings, xl the starting composition of the liquid (optional, default \
.9999) and xg the starting composition of the gas (optional, default .0001). \
Optional parameters are Speed (either -> slow (internal Mathematica) or -> \
fast (external Fortran routine which is only available for MacOS X) and \
NewSpecies -> \
{{name1,\[Epsilon]1,\[Sigma]1,\[Mu]1,\[Alpha]1,molecularweight1}, {name2,\
\[Epsilon]2,\[Sigma]2,\[Mu]2,\[Alpha]2,molecularweight2}, ...} for external \
species (default NewSpecies -> {}).\>\""}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"AEOSCGpara", "::", "usage"}], "=", 
    "\"\<AEOSCGpara[\[Rho],t,pa, options] calculates the molar Helmholtz free \
energy according to Churakov & Gottschalk (2003) using the density \[Rho] \
[J*mol/MPa],the temperature t[K]  and pa the list of the required parameters \
{\[Epsilon]/k,\[Sigma],\[Mu],\[Alpha]}. Units as listet in the tables of the \
paper. Optional parameters are Speed (either -> slow (internal Mathematica) \
or -> fast (external Fortran routine which is only available for MacOS \
X).\>\""}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"GEOSCGpara", "::", "usage"}], "=", 
    "\"\<GEOSCGpara[p,t,pa, options] calculates the molar Gibbs free energy \
according to Churakov & Gottschalk (2003) using the pressure p [MPa],the \
temperature t[K]  and pa the list of the required parameters {\[Epsilon]/k,\
\[Sigma],\[Mu],\[Alpha]}. Units as listet in the tables of the paper. \
Optional parameters are Speed (either -> slow (internal Mathematica) or -> \
fast (external Fortran routine which is only available for MacOS X).\>\""}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"AEOSCGfast", "::", "usage"}], "=", "\"\<\>\""}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "loads", " ", "the", " ", "external", " ", "program", " ", "aeos", " ", 
     "which", " ", "includes", " ", "the", " ", "function", " ", 
     "AEOSCGfast"}], " ", "*)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"If", "[", " ", 
     RowBox[{
      RowBox[{"$OperatingSystem", "==", "\"\<MacOSX\>\""}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"link", "=", 
        RowBox[{"Install", "[", 
         RowBox[{"\"\<Fluids/aeos\>\"", ",", 
          RowBox[{"LinkMode", "\[Rule]", "Launch"}], ",", 
          RowBox[{"LinkProtocol", "\[Rule]", "\"\<Pipes\>\""}]}], "]"}]}], 
       ";", 
       RowBox[{"defaultmodus", "=", "\"\<fast\>\""}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"defaultmodus", "=", "\"\<slow\>\""}]}], " ", "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "sets", " ", "default", " ", "parameter", " ", "for", " ", "functions"}], 
    " ", "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Options", "[", "FEOSCG", "]"}], "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Speed", "->", "defaultmodus"}], ",", 
       RowBox[{"NewSpecies", "\[Rule]", 
        RowBox[{"{", "}"}]}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Options", "[", "AEOSCG", "]"}], "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Speed", "->", "defaultmodus"}], ",", 
       RowBox[{"NewSpecies", "\[Rule]", 
        RowBox[{"{", "}"}]}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Options", "[", "GEOSCG", "]"}], "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Speed", "->", "defaultmodus"}], ",", 
       RowBox[{"NewSpecies", "\[Rule]", 
        RowBox[{"{", "}"}]}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Options", "[", "\[Rho]EOSCG", "]"}], "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Speed", "->", "defaultmodus"}], ",", 
       RowBox[{"NewSpecies", "\[Rule]", 
        RowBox[{"{", "}"}]}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Options", "[", "VEOSCG", "]"}], "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Speed", "->", "defaultmodus"}], ",", 
       RowBox[{"NewSpecies", "\[Rule]", 
        RowBox[{"{", "}"}]}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Options", "[", "AEOSCGpara", "]"}], "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Speed", "->", "defaultmodus"}], ",", 
       RowBox[{"NewSpecies", "\[Rule]", 
        RowBox[{"{", "}"}]}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Options", "[", "GEOSCGpara", "]"}], "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Speed", "->", "defaultmodus"}], ",", 
       RowBox[{"NewSpecies", "\[Rule]", 
        RowBox[{"{", "}"}]}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Options", "[", "PEOSCG", "]"}], "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Speed", "->", "defaultmodus"}], ",", 
       RowBox[{"NewSpecies", "\[Rule]", 
        RowBox[{"{", "}"}]}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Options", "[", "miscgap", "]"}], "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Speed", "->", "defaultmodus"}], ",", 
       RowBox[{"NewSpecies", "\[Rule]", 
        RowBox[{"{", "}"}]}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Options", "[", "miscgapNewton", "]"}], "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Speed", "->", "defaultmodus"}], ",", 
       RowBox[{"NewSpecies", "\[Rule]", 
        RowBox[{"{", "}"}]}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Options", "[", "flist", "]"}], "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Speed", "->", "defaultmodus"}], ",", 
       RowBox[{"NewSpecies", "\[Rule]", 
        RowBox[{"{", "}"}]}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], " ", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"na", "=", 
     RowBox[{"6.02214199", "*", 
      RowBox[{"10", "^", "23"}]}]}], ";", "   ", 
    RowBox[{"(*", " ", 
     RowBox[{"Avogadro\.b4s", " ", "number"}], " ", "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{"k", "=", 
     RowBox[{"1.3806503", "*", 
      RowBox[{"10", "^", 
       RowBox[{"-", "23"}]}]}]}], ";", "      ", 
    RowBox[{"(*", " ", 
     RowBox[{"Boltzmann", " ", "constant"}], " ", "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{"r", "=", 
     RowBox[{"na", " ", "k"}]}], ";", 
    "                                         ", 
    RowBox[{"(*", " ", 
     RowBox[{"gas", " ", "constant"}], " ", "*)"}], "\[IndentingNewLine]", 
    RowBox[{"h", "=", 
     RowBox[{"6.6261", "*", 
      RowBox[{"10", "^", 
       RowBox[{"-", "34"}]}]}]}], ";", "             ", 
    RowBox[{"(*", " ", 
     RowBox[{"Planck", " ", "constant"}], " ", "*)"}], "\[IndentingNewLine]", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"parameters", " ", "according", " ", "to", " ", "Churakov"}], 
        " ", "&"}], " ", "Gottschalk"}], ",", " ", "2002", ",", " ", 
      RowBox[{"if", " ", "not", " ", "otherwise", " ", "indicated"}]}], " ", 
     "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"parameter", "=", "\[IndentingNewLine]", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "\"\<N2O\>\"", ",", "235.7", ",", "3.658", ",", ".161", ",", "0", ",",
          "44.01288"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<NO\>\"", ",", "137", ",", "3.094", ",", ".159", ",", "0", ",", 
         "30.00614"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<H2S\>\"", ",", "277.2", ",", "3.68", ",", ".97", ",", "0", ",", 
         "34.08188"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<SO2\>\"", ",", "302.7", ",", "3.903", ",", "1.633", ",", "0", 
         ",", "64.0648"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<COS\>\"", ",", "286.9", ",", "4.099", ",", ".715", ",", "0", ",",
          "60.0761"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<CO\>\"", ",", "101.2", ",", "3.623", ",", ".11", ",", "0", ",", 
         "28.0101"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<PH3\>\"", ",", "302.7", ",", "3.903", ",", ".55", ",", "0", ",", 
         "33.997581"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<HCN\>\"", ",", "149.7", ",", "3.796", ",", "2.984", ",", "0", 
         ",", "27.02538"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<CCl2O (phosgene)\>\"", ",", "342.3", ",", "4.548", ",", "1.17", 
         ",", "0", ",", "98.9155"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<CH4O (methanol)\>\"", ",", "359", ",", "3.803", ",", ".71", ",", 
         "0", ",", "32.04186"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<C2H6O (ethanol)\>\"", ",", "373.3", ",", "4.299", ",", ".73", 
         ",", "0", ",", "46.06844"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<C3H8O (n-propanol)\>\"", ",", "398.1", ",", "4.691", ",", ".69", 
         ",", "0", ",", "60.09502"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<C3H8O (2-propanol)\>\"", ",", "376.8", ",", "4.699", ",", ".66", 
         ",", "0", ",", "60.09502"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<C4H10O (n-butanol)\>\"", ",", "421.8", ",", "5.047", ",", ".66", 
         ",", "0", ",", "74.1216"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<C4H10O (2-butanol)\>\"", ",", "401.1", ",", "5.037", ",", ".66", 
         ",", "0", ",", "74.1216"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<C4H10O (2-methyl-1-propanol)\>\"", ",", "410.4", ",", "5.041", 
         ",", ".64", ",", "0", ",", "74.1216"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<C4H10O (2-methyl-2-propanol)\>\"", ",", "378.1", ",", "5.061", 
         ",", ".67", ",", "0", ",", "74.1216"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<C6H6O (phenol)\>\"", ",", "524.9", ",", "5079", ",", "1.45", ",",
          "0", ",", "94.11124"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<C3H6O (acetone)\>\"", ",", "326.2", ",", "4.691", ",", "2.88", 
         ",", "0", ",", "58.07914"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<C4H8O (2-butaone)\>\"", ",", "370.4", ",", "5.036", ",", "2.8", 
         ",", "0", ",", "72.10572"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<C5H10O (2-pentanone)\>\"", ",", "402.5", ",", "5.38", ",", 
         "2.72", ",", "0", ",", "86.1323"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<C5H10O (3-pentanone)\>\"", ",", "401.9", ",", "5.345", ",", 
         "2.72", ",", "0", ",", "86.1323"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<C5H10O (3-methyl-2-butanone)\>\"", ",", "393.9", ",", "5.338", 
         ",", "2.77", ",", "0", ",", "86.1323"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<CH2O (formaldehyde)\>\"", ",", "206.5", ",", "3.731", ",", 
         "2.33", ",", "0", ",", "30.02598"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<C2H4O (aceteldehyde)\>\"", ",", "268.3", ",", "4.248", ",", 
         "2.69", ",", "0", ",", "44.05256"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<C3H6O (propionaldehyde)\>\"", ",", "335.5", ",", "4.648", ",", 
         "2.52", ",", "0", ",", "58.07914"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<C2H4O2 (acetic acid)\>\"", ",", "435.6", ",", "4.356", ",", 
         "1.74", ",", "0", ",", "60.0519"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<C2H4O2 (methyl Formate)\>\"", ",", "352.6", ",", "4.374", ",", 
         "1.77", ",", "0", ",", "60.05196"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<C3H6O2 (ethyl formate)\>\"", ",", "371.9", ",", "4.806", ",", 
         ".94", ",", "0", ",", "74.07854"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<C4H8O2 (n-propyl formate)\>\"", ",", "402.9", ",", "5.159", ",", 
         ".7", ",", "0", ",", "88.10512"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<C3H6O2 (methyl acetate)\>\"", ",", "376.3", ",", "4.781", ",", 
         ".67", ",", "0", ",", "74.07854"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<C4H8O2 (ethyl acetate)\>\"", ",", "390.3", ",", "5.153", ",", 
         ".78", ",", "0", ",", "88.10512"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<C2H6O (dimethyl ether)\>\"", ",", "297.1", ",", "4.386", ",", 
         ".3", ",", "0", ",", "46.06844"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<C3H8O (methyl ethyl ether)\>\"", ",", "329.5", ",", "4.793", ",",
          ".23", ",", "0", ",", "60.09502"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<C4H10O (diethyl ether)\>\"", ",", "353.4", ",", "5.166", ",", 
         ".13", ",", "0", ",", "74.1216"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<C2H4O (ethylene ether)\>\"", ",", "324.7", ",", "4.079", ",", 
         "1.89", ",", "0", ",", "44.05256"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<C4H8O (tetrahydrofuran)\>\"", ",", "403.4", ",", "4.856", ",", 
         "1.63", ",", "0", ",", "72.10572"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<CH5N (methylamine)\>\"", ",", "315.1", ",", "3.91", ",", "1.29", 
         ",", "0", ",", "31.05714"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<C2H7N (dimethylainine)\>\"", ",", "329.8", ",", "4.444", ",", 
         "1.03", ",", "0", ",", "45.08372"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<C3H9N (trimethylamine)\>\"", ",", "329.4", ",", "4.918", ",", 
         ".63", ",", "0", ",", "59.1103"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<C2H7N (ethylamine)\>\"", ",", "342.1", ",", "4.431", ",", "1.22",
          ",", "0", ",", "45.08372"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<C4H11N (diethylamine)\>\"", ",", "377.2", ",", "5.212", ",", 
         ".91", ",", "0", ",", "73.13688"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<C6H15N (trimetylamine)\>\"", ",", "407", ",", "5.798", ",", 
         ".83", ",", "0", ",", "101.19004"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<CH3NO2 (nitromethane)\>\"", ",", "290.4", ",", "4.347", ",", 
         "3.57", ",", "0", ",", "61.04006"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<C2H3N (acetonitrile)\>\"", ",", "175.7", ",", "4.284", ",", 
         "3.92", ",", "0", ",", "41.05196"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<C3H3N (acrylonitrile)\>\"", ",", "244.3", ",", "4.606", ",", 
         "3.87", ",", "0", ",", "53.06266"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<C5H5N (pyridine)\>\"", ",", "453.3", ",", "4.956", ",", "2.25", 
         ",", "0", ",", "79.09994"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<CH4S (methyl mercaptan)\>\"", ",", "343.7", ",", "4.19", ",", 
         "1.52", ",", "0", ",", "48.10846"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<C2H6S (dimethyl sulphide)\>\"", ",", "375.1", ",", "4.637", ",", 
         "1.5", ",", "0", ",", "62.13504"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<C2H6S (ethyl mercaptan)\>\"", ",", "371.2", ",", "4.659", ",", 
         "1.56", ",", "0", ",", "62.13504"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<CH3F (fluoromethane)\>\"", ",", "186.7", ",", "3.766", ",", 
         "1.82", ",", "0", ",", "34.0329232"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<CH2F2 (difluoromethane)\>\"", ",", "213", ",", "3.881", ",", 
         "1.96", ",", "0", ",", "52.0233864"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<CHF3 (trifluoromethane)\>\"", ",", "199.6", ",", "4.007", ",", 
         "1.62", ",", "0", ",", "70.0138496"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<C2H5F (fluoroethane)\>\"", ",", "253.3", ",", "4.268", ",", 
         "1.94", ",", "0", ",", "48.0595032"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<C2H4F2 (1,1-difluoroethane)\>\"", ",", "248.5", ",", "4.429", 
         ",", "2.3", ",", "0", ",", "66.0499664"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<C2H3F3 (1,1,1-trifluoroethane)\>\"", ",", "221.2", ",", "4.535", 
         ",", "2.28", ",", "0", ",", "84.0404296"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<CH3Cl (chloromethane)\>\"", ",", "279.8", ",", "4.097", ",", 
         "1.94", ",", "0", ",", "50.48722"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<CHCl3 (trichloromethane)\>\"", ",", "406.5", ",", "4.829", ",", 
         "1.05", ",", "0", ",", "119.37674"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<C2H4Cl2 (l,l-dicliloroethane)\>\"", ",", "381.7", ",", "4.9", 
         ",", "2.06", ",", "0", ",", "98.95856"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<C6H5Cl (chlorobenzene)\>\"", ",", "476.3", ",", "5.319", ",", 
         "1.69", ",", "0", ",", "112.5566"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<C2H5Br (bromoethane)\>\"", ",", "370.2", ",", "4.684", ",", 
         "1.79", ",", "0", ",", "108.9651"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<HBr\>\"", ",", "272.4", ",", "3.705", ",", ".827", ",", "0", ",",
          "80.91194"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<HF\>\"", ",", "237", ",", "3.058", ",", "1.826", ",", "0", ",", 
         "20.0063432"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<NO2\>\"", ",", "328.1", ",", "3.431", ",", ".316", ",", "0", ",",
          "46.00554"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<HCl\>\"", ",", "230.9", ",", "3.455", ",", "1.109", ",", "0", 
         ",", "36.46064"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<HI\>\"", ",", "322.5", ",", "4.05", ",", ".448", ",", "0", ",", 
         "127.91241"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<C3H6 (propene)\>\"", ",", "277.7", ",", "4.49", ",", ".366", ",",
          "0", ",", "42.07974"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<C4H8 (Isobutene)\>\"", ",", "318", ",", "4.927", ",", ".503", 
         ",", "0", ",", "56.10632"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<SiClF3\>\"", ",", "233.5", ",", "4.715", ",", ".686", ",", "0", 
         ",", "120.5334096"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<SiCl2F2\>\"", ",", "280.3", ",", "4.984", ",", ".7329", ",", "0",
          ",", "136.9877064"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<SiCl3F\>\"", ",", "333.8", ",", "5.218", ",", ".49", ",", "0", 
         ",", "153.4420032"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<He\>\"", ",", "3.96", ",", "3.104", ",", "0", ",", ".204956", 
         ",", "4.002602"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Ne\>\"", ",", "33.84", ",", "2.804", ",", "0", ",", ".3956", ",",
          "20.1797"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Ar\>\"", ",", "114.99", ",", "3.402", ",", "0", ",", "1.6411", 
         ",", "39.948"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Kr\>\"", ",", "159.61", ",", "3.628", ",", "0", ",", "2.4844", 
         ",", "83.8"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Xe\>\"", ",", "220.83", ",", "3.957", ",", "0", ",", "4.044", 
         ",", "131.29"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<F2\>\"", ",", "109.86", ",", "3.26", ",", "0", ",", "1.38", ",", 
         "37.9968"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Br2\>\"", ",", "448.17", ",", "4.055", ",", "0", ",", "7.02", 
         ",", "159.808"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<I2\>\"", ",", "624.24", ",", "4.333", ",", "0", ",", "10.", ",", 
         "253.80894"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Cl2\>\"", ",", "317.76", ",", "4.012", ",", "0", ",", "4.61", 
         ",", "70.9054"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<O2\>\"", ",", "117.83", ",", "3.371", ",", "0", ",", "1.5812", 
         ",", "31.9988"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<S\>\"", ",", "1001.52", ",", "4.361", ",", "0", ",", "2.9", ",", 
         "32.066"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<N2\>\"", ",", "96.2", ",", "3.615", ",", "0", ",", "1.7403", ",",
          "28.0135"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<H2\>\"", ",", "25.13", ",", "3.243", ",", "0", ",", ".81", ",", 
         "2.01588"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<CS2\>\"", ",", "420.73", ",", "4.495", ",", "0", ",", "8.74", 
         ",", "76.1427"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<CH4\>\"", ",", "145.22", ",", "3.732", ",", "0", ",", "2.593", 
         ",", "16.0425"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<C2H6 (ethane)\>\"", ",", "232.77", ",", "4.267", ",", "0", ",", 
         "4.47", ",", "30.069"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<C3H8 (propane)\>\"", ",", "281.88", ",", "4.741", ",", "0", ",", 
         "6.29", ",", "44.0956"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<C2H4 (ethylene)\>\"", ",", "215.2", ",", "4.097", ",", "0", ",", 
         "4.252", ",", "28.0532"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<C4H10 (butane)\>\"", ",", "324.04", ",", "5.115", ",", "0", ",", 
         "8.2", ",", "58.1222"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<BF3\>\"", ",", "198.78", ",", "3.923", ",", "0", ",", "3.31", 
         ",", "67.8052"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<BCl3\>\"", ",", "346.8", ",", "5.006", ",", "0", ",", "9.38", 
         ",", "117.168"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<SiF4\>\"", ",", "197.41", ",", "4.444", ",", "0", ",", "5.45", 
         ",", "104.079"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<SiH4\>\"", ",", "205.56", ",", "3.744", ",", "0", ",", "5.44", 
         ",", "32.1173"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<SiCl4\>\"", ",", "387.27", ",", "5.552", ",", "0", ",", "12.", 
         ",", "169.896"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"\"\<H2O\>\"", ",", "192.814", ",", "2.97509", ",", 
         RowBox[{"2.16312", "+", 
          RowBox[{"68.2631", "/", 
           RowBox[{"(", 
            RowBox[{"temp", "+", "13.1904"}], ")"}]}]}], ",", 
         RowBox[{"0.207114", "+", 
          RowBox[{"76.2066", "/", 
           RowBox[{"(", 
            RowBox[{"temp", "+", "100.453"}], ")"}]}]}], ",", "18.0153"}], 
        "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"\"\<CO2\>\"", ",", 
         RowBox[{"192.192", "+", 
          RowBox[{"136.307", "*", 
           RowBox[{"Exp", "[", 
            RowBox[{
             RowBox[{"-", "0.00353196"}], "*", "temp"}], "]"}]}]}], ",", 
         RowBox[{"3.81773", "-", 
          RowBox[{"0.2037820", "*", 
           RowBox[{"Exp", "[", 
            RowBox[{
             RowBox[{"-", "0.00101206"}], "*", "temp"}], "]"}]}]}], ",", "0", 
         ",", "2.65", ",", "44.0095"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<NH3\>\"", ",", "200", ",", "3.294", ",", "1.849", ",", "0", ",", 
         "17.0306"}], "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"FEOSCG", "[", 
      RowBox[{
      "p_", ",", "t_", ",", " ", "sp_", ",", " ", "x_", ",", "opts___"}], 
      "]"}], " ", ":=", "\[IndentingNewLine]", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "p0", ",", "pa", ",", "lsp", ",", "\[CapitalDelta]x", ",", "erg", ",",
          "\[Rho]", ",", "z", ",", "a", ",", "dax", ",", "sdax", ",", "f", 
         ",", "modus", ",", "newsp"}], "}"}], ",", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"modus", "=", 
         RowBox[{
          RowBox[{"Speed", "/.", 
           RowBox[{"{", "opts", "}"}]}], "/.", 
          RowBox[{"Options", "[", "FEOSCG", "]"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"newsp", "=", 
         RowBox[{
          RowBox[{"NewSpecies", "/.", 
           RowBox[{"{", "opts", "}"}]}], "/.", 
          RowBox[{"Options", "[", "FEOSCG", "]"}]}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"p0", " ", "=", " ", "0.1"}], ";", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{"pa", "=", 
         RowBox[{"ParaCG", "[", 
          RowBox[{"t", ",", " ", "sp", ",", " ", "x", ",", "newsp"}], "]"}]}],
         ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"lsp", "=", 
         RowBox[{"Length", "[", "sp", "]"}]}], ";", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{"\[CapitalDelta]x", " ", "=", " ", 
         RowBox[{"Table", "[", " ", 
          RowBox[{
           RowBox[{
            RowBox[{
            "x", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], "/", 
            "10000"}], ",", " ", 
           RowBox[{"{", 
            RowBox[{"i", ",", "lsp"}], "}"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"\[CapitalDelta]x", " ", "=", " ", 
         RowBox[{"DiagonalMatrix", "[", "\[CapitalDelta]x", "]"}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"erg", " ", "=", " ", 
         RowBox[{"PEOSCG", "[", 
          RowBox[{"p", ",", " ", "t", ",", " ", "pa", ",", " ", "x", ",", " ", 
           RowBox[{"Speed", "->", "modus"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"\[Rho]", "=", 
         RowBox[{
          RowBox[{
          "erg", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
          "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"z", "=", 
         RowBox[{
          RowBox[{
          "erg", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
          "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"a", "=", 
         RowBox[{
          RowBox[{
           RowBox[{"AEOSCGint", "[", 
            RowBox[{
            "\[Rho]", ",", " ", "t", ",", " ", "pa", ",", " ", "x", ",", 
             RowBox[{"Speed", "->", "modus"}]}], "]"}], 
           "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], "/", 
          RowBox[{"(", 
           RowBox[{"r", " ", "t"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"lsp", " ", "\[Equal]", " ", "1"}], ",", " ", 
          RowBox[{"Return", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"Exp", "[", 
              RowBox[{"a", " ", "+", " ", "z", " ", "-", " ", "1", "-", " ", 
               RowBox[{"Log", "[", "z", "]"}]}], "]"}], ")"}], " ", 
            RowBox[{"p", "/", "p0"}]}], "]"}]}], "]"}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"dax", " ", "=", " ", 
         RowBox[{"Table", "[", 
          RowBox[{"0", ",", " ", 
           RowBox[{"{", 
            RowBox[{"i", ",", "lsp"}], "}"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Do", "[", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"dax", "[", 
            RowBox[{"[", "i", "]"}], "]"}], " ", "=", " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"AEOSCGint", "[", 
                RowBox[{"\[Rho]", ",", "t", ",", "pa", ",", 
                 RowBox[{"x", "+", " ", 
                  RowBox[{
                  "\[CapitalDelta]x", "\[LeftDoubleBracket]", "i", 
                   "\[RightDoubleBracket]"}]}], ",", 
                 RowBox[{"Speed", "->", "modus"}]}], "]"}], 
               "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], " ", 
              "-", " ", 
              RowBox[{
               RowBox[{"AEOSCGint", "[", 
                RowBox[{"\[Rho]", ",", "t", ",", "pa", ",", 
                 RowBox[{"x", "-", " ", 
                  RowBox[{
                  "\[CapitalDelta]x", "\[LeftDoubleBracket]", "i", 
                   "\[RightDoubleBracket]"}]}], ",", 
                 RowBox[{"Speed", "->", "modus"}]}], "]"}], 
               "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
             ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"2", 
              RowBox[{
               RowBox[{
               "\[CapitalDelta]x", "\[LeftDoubleBracket]", "i", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "i", 
               "\[RightDoubleBracket]"}], " ", "r", " ", "t"}], ")"}]}]}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "lsp"}], "}"}]}], "]"}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"sdax", " ", "=", " ", 
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
            "x", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], " ", 
            
            RowBox[{
            "dax", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]}], 
           ",", " ", 
           RowBox[{"{", 
            RowBox[{"i", ",", "lsp"}], "}"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"f", " ", "=", " ", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"Exp", "[", 
              RowBox[{"a", " ", "+", " ", 
               RowBox[{
               "dax", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
               "  ", "-", " ", "sdax", " ", "+", " ", "z", " ", "-", " ", "1",
                " ", "-", " ", 
               RowBox[{"Log", "[", "z", "]"}]}], "]"}], ")"}], " ", 
            RowBox[{"p", "/", "p0"}]}], ",", " ", 
           RowBox[{"{", 
            RowBox[{"i", ",", "lsp"}], "}"}]}], "]"}]}]}]}], 
      "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"AEOSCG", "[", 
      RowBox[{
      "\[Rho]_", ",", "t_", ",", " ", "sp_", ",", " ", "x_", ",", "opts___"}],
       "]"}], " ", ":=", "\[IndentingNewLine]", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"pa", ",", "modus", ",", "newsp"}], "}"}], ",", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"modus", "=", 
         RowBox[{
          RowBox[{"Speed", "/.", 
           RowBox[{"{", "opts", "}"}]}], "/.", 
          RowBox[{"Options", "[", "AEOSCG", "]"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"newsp", "=", 
         RowBox[{
          RowBox[{"NewSpecies", "/.", 
           RowBox[{"{", "opts", "}"}]}], "/.", 
          RowBox[{"Options", "[", "AEOSCG", "]"}]}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{
          RowBox[{"Print", "[", 
           RowBox[{"{", 
            RowBox[{"modus", ",", "newsp"}], "}"}], "]"}], ";"}], "*)"}], 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"pa", "=", " ", 
         RowBox[{"ParaCG", "[", 
          RowBox[{"t", ",", " ", "sp", ",", " ", "x", ",", "newsp"}], "]"}]}],
         ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"AEOSCGint", "[", 
         RowBox[{
         "\[Rho]", ",", " ", "t", ",", " ", "pa", ",", " ", "x", ",", 
          RowBox[{"Speed", "->", "modus"}]}], "]"}]}]}], 
      "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"AEOSCGpara", "[", 
      RowBox[{"\[Rho]_", ",", "t_", ",", " ", "pa_", ",", "opts___"}], "]"}], 
     " ", ":=", "\[IndentingNewLine]", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"palocal", ",", "modus", ",", "newsp"}], "}"}], ",", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"modus", "=", 
         RowBox[{
          RowBox[{"Speed", "/.", 
           RowBox[{"{", "opts", "}"}]}], "/.", 
          RowBox[{"Options", "[", "AEOSCGpara", "]"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"newsp", "=", 
         RowBox[{
          RowBox[{"NewSpecies", "/.", 
           RowBox[{"{", "opts", "}"}]}], "/.", 
          RowBox[{"Options", "[", "AEOSCGpara", "]"}]}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"palocal", " ", "=", " ", "pa"}], ";", "\[IndentingNewLine]", 
        
        RowBox[{
         RowBox[{
         "palocal", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
         "=", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
           "palocal", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
           "*", "k"}], "}"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
         "palocal", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
         "=", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
           "palocal", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
           "*", " ", 
           SuperscriptBox["10", 
            RowBox[{"-", "10"}]]}], "}"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
         "palocal", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
         "=", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
             "palocal", "\[LeftDoubleBracket]", "3", 
              "\[RightDoubleBracket]"}], "^", "2"}], ")"}], "*", " ", 
           SuperscriptBox["10", 
            RowBox[{"-", "49"}]]}], "}"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
         "palocal", "\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}], 
         "=", 
         RowBox[{"{", " ", 
          RowBox[{
           RowBox[{
           "palocal", "\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}], 
           "*", " ", 
           SuperscriptBox["10", 
            RowBox[{"-", "30"}]]}], "}"}]}], ";", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{"AEOSCGint", "[", 
         RowBox[{"\[Rho]", ",", " ", "t", ",", " ", "palocal", ",", " ", 
          RowBox[{"{", "1.", "}"}], ",", 
          RowBox[{"Speed", "->", "modus"}]}], "]"}]}]}], 
      "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"GEOSCGpara", "[", 
      RowBox[{"p_", ",", "t_", ",", " ", "pa_", ",", "opts___"}], "]"}], " ", 
     ":=", "\[IndentingNewLine]", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "palocal", ",", "erg", ",", "\[Rho]", ",", "modus", ",", "newsp"}], 
        "}"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"modus", "=", 
         RowBox[{
          RowBox[{"Speed", "/.", 
           RowBox[{"{", "opts", "}"}]}], "/.", 
          RowBox[{"Options", "[", "GEOSCGpara", "]"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"newsp", "=", 
         RowBox[{
          RowBox[{"NewSpecies", "/.", 
           RowBox[{"{", "opts", "}"}]}], "/.", 
          RowBox[{"Options", "[", "GEOSCGpara", "]"}]}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"palocal", " ", "=", " ", "pa"}], ";", "\[IndentingNewLine]", 
        
        RowBox[{
         RowBox[{
         "palocal", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
         "=", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
           "palocal", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
           "*", "k"}], "}"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
         "palocal", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
         "=", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
           "palocal", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
           "*", " ", 
           SuperscriptBox["10", 
            RowBox[{"-", "10"}]]}], "}"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
         "palocal", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
         "=", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
             "palocal", "\[LeftDoubleBracket]", "3", 
              "\[RightDoubleBracket]"}], "^", "2"}], ")"}], "*", " ", 
           SuperscriptBox["10", 
            RowBox[{"-", "49"}]]}], "}"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
         "palocal", "\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}], 
         "=", 
         RowBox[{"{", " ", 
          RowBox[{
           RowBox[{
           "palocal", "\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}], 
           "*", " ", 
           SuperscriptBox["10", 
            RowBox[{"-", "30"}]]}], "}"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"erg", " ", "=", " ", 
         RowBox[{"PEOSCG", "[", 
          RowBox[{"p", ",", " ", "t", ",", " ", "palocal", ",", " ", 
           RowBox[{"{", "1.", "}"}], ",", " ", 
           RowBox[{"Speed", "->", "modus"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"\[Rho]", " ", "=", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{
            "erg", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
           RowBox[{
            RowBox[{
            "erg", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], "}"}]}],
         ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
           "\[Rho]", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
           "\[NotEqual]", "0"}], ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{
              "\[Rho]", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], ",", 
              RowBox[{
               RowBox[{
                RowBox[{"AEOSCGint", "[", 
                 RowBox[{
                  RowBox[{
                  "\[Rho]", "\[LeftDoubleBracket]", "1", 
                   "\[RightDoubleBracket]"}], ",", " ", "t", ",", " ", 
                  "palocal", ",", " ", 
                  RowBox[{"{", "1.", "}"}], ",", 
                  RowBox[{"Speed", "->", "modus"}]}], "]"}], 
                "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], "+", 
               RowBox[{"p", "*", 
                RowBox[{"1", "/", 
                 RowBox[{
                 "\[Rho]", "\[LeftDoubleBracket]", "1", 
                  "\[RightDoubleBracket]"}]}]}]}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{
              "\[Rho]", "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], ",", 
              RowBox[{
               RowBox[{
                RowBox[{"AEOSCGint", "[", 
                 RowBox[{
                  RowBox[{
                  "\[Rho]", "\[LeftDoubleBracket]", "2", 
                   "\[RightDoubleBracket]"}], ",", " ", "t", ",", " ", 
                  "palocal", ",", " ", 
                  RowBox[{"{", "1.", "}"}], ",", 
                  RowBox[{"Speed", "->", "modus"}]}], "]"}], 
                "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], "+", 
               RowBox[{"p", "*", 
                RowBox[{"1", "/", 
                 RowBox[{
                 "\[Rho]", "\[LeftDoubleBracket]", "2", 
                  "\[RightDoubleBracket]"}]}]}]}]}], "}"}]}], " ", "}"}], ",",
           "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{
              "\[Rho]", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], ",", 
              RowBox[{
               RowBox[{
                RowBox[{"AEOSCGint", "[", 
                 RowBox[{
                  RowBox[{
                  "\[Rho]", "\[LeftDoubleBracket]", "1", 
                   "\[RightDoubleBracket]"}], ",", " ", "t", ",", " ", 
                  "palocal", ",", " ", 
                  RowBox[{"{", "1.", "}"}], ",", 
                  RowBox[{"Speed", "->", "modus"}]}], "]"}], 
                "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], "+", 
               RowBox[{"p", "*", 
                RowBox[{"1", "/", 
                 RowBox[{
                 "\[Rho]", "\[LeftDoubleBracket]", "1", 
                  "\[RightDoubleBracket]"}]}]}]}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}]}], " ", "}"}]}], "]"}]}]}], 
      "\[IndentingNewLine]", " ", "\[IndentingNewLine]", "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Rho]EOSCG", "[", 
      RowBox[{
      "p_", ",", "t_", ",", " ", "sp_", ",", " ", "x_", ",", "opts___"}], 
      "]"}], " ", ":=", "\[IndentingNewLine]", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"pa", ",", "erg", ",", "\[Rho]", ",", "modus", ",", "newsp"}],
         "}"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"modus", "=", 
         RowBox[{
          RowBox[{"Speed", "/.", 
           RowBox[{"{", "opts", "}"}]}], "/.", 
          RowBox[{"Options", "[", "\[Rho]EOSCG", "]"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"newsp", "=", 
         RowBox[{
          RowBox[{"NewSpecies", "/.", 
           RowBox[{"{", "opts", "}"}]}], "/.", 
          RowBox[{"Options", "[", "\[Rho]EOSCG", "]"}]}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"pa", "=", " ", 
         RowBox[{"ParaCG", "[", 
          RowBox[{"t", ",", " ", "sp", ",", " ", "x", ",", "newsp"}], "]"}]}],
         ";", "\[IndentingNewLine]", 
        RowBox[{"erg", " ", "=", " ", 
         RowBox[{"PEOSCG", "[", 
          RowBox[{"p", ",", " ", "t", ",", " ", "pa", ",", " ", "x", ",", " ", 
           RowBox[{"Speed", "->", "modus"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"\[Rho]", " ", "=", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{
            "erg", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
           RowBox[{
            RowBox[{
            "erg", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
          "}"}]}]}]}], "\[IndentingNewLine]", " ", "\[IndentingNewLine]", 
      "]"}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"GEOSCG", "[", 
      RowBox[{
      "p_", ",", "t_", ",", " ", "sp_", ",", " ", "x_", ",", "opts___"}], 
      "]"}], " ", ":=", "\[IndentingNewLine]", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"pa", ",", "erg", ",", "\[Rho]", ",", "modus", ",", "newsp"}],
         "}"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"modus", "=", 
         RowBox[{
          RowBox[{"Speed", "/.", 
           RowBox[{"{", "opts", "}"}]}], "/.", 
          RowBox[{"Options", "[", "GEOSCG", "]"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"newsp", "=", 
         RowBox[{
          RowBox[{"NewSpecies", "/.", 
           RowBox[{"{", "opts", "}"}]}], "/.", 
          RowBox[{"Options", "[", "GEOSCG", "]"}]}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"pa", "=", " ", 
         RowBox[{"ParaCG", "[", 
          RowBox[{"t", ",", " ", "sp", ",", " ", "x", ",", "newsp"}], "]"}]}],
         ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"erg", " ", "=", " ", 
         RowBox[{"PEOSCG", "[", 
          RowBox[{"p", ",", " ", "t", ",", " ", "pa", ",", " ", "x", ",", 
           RowBox[{"Speed", "->", "modus"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"erg", "\[Equal]", "Null"}], ",", 
          RowBox[{"Return", "[", "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{"\[Rho]", " ", "=", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{
            "erg", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
           RowBox[{
            RowBox[{
            "erg", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
            "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], "}"}]}],
         ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
           "\[Rho]", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
           "\[NotEqual]", "0"}], ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{
              "\[Rho]", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], ",", 
              RowBox[{
               RowBox[{
                RowBox[{"AEOSCGint", "[", 
                 RowBox[{
                  RowBox[{
                  "\[Rho]", "\[LeftDoubleBracket]", "1", 
                   "\[RightDoubleBracket]"}], ",", " ", "t", ",", " ", "pa", 
                  ",", " ", "x", ",", 
                  RowBox[{"Speed", "->", "modus"}]}], "]"}], 
                "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], "+", 
               RowBox[{"p", "*", 
                RowBox[{"1", "/", 
                 RowBox[{
                 "\[Rho]", "\[LeftDoubleBracket]", "1", 
                  "\[RightDoubleBracket]"}]}]}]}]}], "}"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{
              "\[Rho]", "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], ",", 
              RowBox[{
               RowBox[{
                RowBox[{"AEOSCGint", "[", 
                 RowBox[{
                  RowBox[{
                  "\[Rho]", "\[LeftDoubleBracket]", "2", 
                   "\[RightDoubleBracket]"}], ",", " ", "t", ",", " ", "pa", 
                  ",", " ", "x", ",", 
                  RowBox[{"Speed", "->", "modus"}]}], "]"}], 
                "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], "+", 
               RowBox[{"p", "*", 
                RowBox[{"1", "/", 
                 RowBox[{
                 "\[Rho]", "\[LeftDoubleBracket]", "2", 
                  "\[RightDoubleBracket]"}]}]}]}]}], "}"}]}], " ", "}"}], ",",
           "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{
              "\[Rho]", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], ",", 
              RowBox[{
               RowBox[{
                RowBox[{"AEOSCGint", "[", 
                 RowBox[{
                  RowBox[{
                  "\[Rho]", "\[LeftDoubleBracket]", "1", 
                   "\[RightDoubleBracket]"}], ",", " ", "t", ",", " ", "pa", 
                  ",", " ", "x", ",", 
                  RowBox[{"Speed", "->", "modus"}]}], "]"}], 
                "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], "+", 
               RowBox[{"p", "*", 
                RowBox[{"1", "/", 
                 RowBox[{
                 "\[Rho]", "\[LeftDoubleBracket]", "1", 
                  "\[RightDoubleBracket]"}]}]}]}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}]}], " ", "}"}]}], "]"}]}]}], 
      "\[IndentingNewLine]", " ", "\[IndentingNewLine]", "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"VEOSCG", "[", 
      RowBox[{
      "p_", ",", "t_", ",", " ", "sp_", ",", " ", "x_", ",", "opts___"}], 
      "]"}], " ", ":=", "\[IndentingNewLine]", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"pa", ",", "erg", ",", "v", ",", "modus", ",", "newsp"}], 
        "}"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"modus", "=", 
         RowBox[{
          RowBox[{"Speed", "/.", 
           RowBox[{"{", "opts", "}"}]}], "/.", 
          RowBox[{"Options", "[", "VEOSCG", "]"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"newsp", "=", 
         RowBox[{
          RowBox[{"NewSpecies", "/.", 
           RowBox[{"{", "opts", "}"}]}], "/.", 
          RowBox[{"Options", "[", "VEOSCG", "]"}]}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"pa", "=", " ", 
         RowBox[{"ParaCG", "[", 
          RowBox[{"t", ",", " ", "sp", ",", " ", "x", ",", "newsp"}], "]"}]}],
         ";", "\[IndentingNewLine]", 
        RowBox[{"erg", " ", "=", " ", 
         RowBox[{"PEOSCG", "[", 
          RowBox[{"p", ",", " ", "t", ",", " ", "pa", ",", " ", "x", ",", " ", 
           RowBox[{"Speed", "->", "modus"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
           "erg", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
           "\[Equal]", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}]}], ",", 
          RowBox[{"v", " ", "=", " ", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"1", "/", 
              RowBox[{
               RowBox[{
               "erg", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
               "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], ",", 
             "0"}], "}"}]}], ",", 
          RowBox[{"v", " ", "=", " ", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"1", "/", 
              RowBox[{
               RowBox[{
               "erg", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
               "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], ",", 
             
             RowBox[{"1", "/", 
              RowBox[{
               RowBox[{
               "erg", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
               "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}]}], 
            "}"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", "v"}]}], " ", "\[IndentingNewLine]", " ", 
      "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ParaCG", "[", 
      RowBox[{"t_", ",", " ", "sp_", ",", " ", "x_", ",", "newsp_"}], "]"}], 
     " ", ":=", "\[IndentingNewLine]", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "ptk", ",", "ptkex", ",", "i", ",", "pname", ",", "p\[Epsilon]", ",", 
         "p\[Sigma]", ",", "p\[Mu]", ",", "p\[Alpha]", " ", ",", "lsp", ",", 
         " ", "pos", ",", "\[Epsilon]", ",", "\[Sigma]", ",", "\[Mu]", ",", 
         "\[Mu]2", ",", "\[Alpha]", ",", "sx", ",", "pmw", ",", "mw"}], "}"}],
        ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"ptk", "     ", "=", " ", 
         RowBox[{"parameter", " ", "/.", " ", 
          RowBox[{"temp", " ", "\[Rule]", " ", "t"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"ptkex", "=", 
         RowBox[{"newsp", "            ", "/.", " ", 
          RowBox[{"temp", " ", "\[Rule]", " ", "t"}]}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"ptk", "=", 
         RowBox[{"Join", "[", 
          RowBox[{"ptk", ",", "ptkex"}], "]"}]}], ";", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{"pname", " ", "=", " ", 
         RowBox[{
          RowBox[{"Transpose", "[", "ptk", "]"}], "\[LeftDoubleBracket]", "1",
           "\[RightDoubleBracket]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"p\[Epsilon]", "         ", "=", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"Transpose", "[", "ptk", "]"}], "\[LeftDoubleBracket]", 
           "2", "\[RightDoubleBracket]"}], " ", "*", " ", "k"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"p\[Sigma]", "         ", "=", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"Transpose", "[", "ptk", "]"}], "\[LeftDoubleBracket]", 
           "3", "\[RightDoubleBracket]"}], " ", "*", " ", 
          SuperscriptBox["10", 
           RowBox[{"-", "10"}]]}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"p\[Mu]", "         ", "=", " ", 
         RowBox[{
          RowBox[{"Transpose", "[", "ptk", "]"}], "\[LeftDoubleBracket]", "4",
           "\[RightDoubleBracket]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"p\[Alpha]", "         ", "=", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"Transpose", "[", "ptk", "]"}], "\[LeftDoubleBracket]", 
           "5", "\[RightDoubleBracket]"}], " ", "*", 
          SuperscriptBox["10", 
           RowBox[{"-", "30"}]]}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"pmw", "       ", "=", " ", 
         RowBox[{
          RowBox[{"Transpose", "[", "ptk", "]"}], "\[LeftDoubleBracket]", "6",
           "\[RightDoubleBracket]"}]}], ";", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{"lsp", " ", "=", " ", 
         RowBox[{"Length", "[", "sp", "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"lsp", " ", "\[Equal]", " ", "0"}], ",", " ", 
          RowBox[{
          "Return", "[", "\"\<EOSCG error: no species selected\>\"", "]"}]}], 
         "]"}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"pos", " ", "=", " ", 
         RowBox[{"Flatten", "[", 
          RowBox[{"Table", "[", " ", 
           RowBox[{
            RowBox[{"Position", "[", 
             RowBox[{"pname", ",", 
              RowBox[{"sp", "[", 
               RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", " ", 
            RowBox[{"{", 
             RowBox[{"i", ",", "lsp"}], "}"}]}], "]"}], "]"}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"lsp", " ", "=!=", " ", 
           RowBox[{"Length", "[", "pos", "]"}]}], ",", " ", 
          RowBox[{"Return", "[", 
           RowBox[{"{", 
            RowBox[{"0.", ",", "0.", ",", "0.", ",", 
             RowBox[{"\"\<ParaCG error: \>\"", "<>", 
              RowBox[{"ToString", "[", 
               RowBox[{"lsp", " ", "-", " ", 
                RowBox[{"Length", "[", "pos", "]"}]}], "]"}], "<>", " ", 
              "\"\< selected species not avaiable or error in text \
format\>\""}]}], "}"}], "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"lsp", " ", "=!=", " ", 
           RowBox[{"Length", "[", "x", " ", "]"}]}], ",", "        ", 
          RowBox[{"Return", "[", 
           RowBox[{"{", 
            RowBox[{"0.", ",", "0.", ",", "0.", ",", 
             RowBox[{"\"\<ParaCG error: \>\"", "<>", 
              RowBox[{"ToString", "[", 
               RowBox[{"lsp", " ", "-", " ", 
                RowBox[{"Length", "[", "x", "]"}]}], "]"}], "<>", " ", 
              "\"\< selected species does not have a corresponding \
composition\>\""}]}], "}"}], "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{"sx", " ", "=", " ", 
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{"x", "[", 
            RowBox[{"[", "i", "]"}], "]"}], ",", 
           RowBox[{"{", " ", 
            RowBox[{"i", ",", " ", "lsp"}], "}"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"sx", "<", ".9999"}], " ", "||", " ", 
           RowBox[{"sx", " ", ">", " ", "1.0001"}]}], ",", 
          "\[IndentingNewLine]", "  ", 
          RowBox[{"Return", "[", 
           RowBox[{"{", 
            RowBox[{"0.", ",", "0.", ",", "0.", ",", 
             RowBox[{
             "\"\<ParaCG error: sum of all molefractions is unequal to 1 \
(\>\"", "<>", 
              RowBox[{"ToString", "[", "sx", "]"}], "<>", " ", 
              "\"\<)\>\""}]}], "}"}], "]"}]}], "]"}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"\[Epsilon]", " ", "=", " ", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"p\[Epsilon]", "[", 
            RowBox[{"[", 
             RowBox[{
             "pos", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
             "]"}], "]"}], ",", " ", 
           RowBox[{"{", 
            RowBox[{"i", ",", "lsp"}], "}"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"\[Sigma]", " ", "=", " ", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"p\[Sigma]", "[", 
            RowBox[{"[", 
             RowBox[{
             "pos", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
             "]"}], "]"}], ",", " ", 
           RowBox[{"{", 
            RowBox[{"i", ",", "lsp"}], "}"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"\[Mu]", " ", "=", " ", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"p\[Mu]", "[", 
            RowBox[{"[", 
             RowBox[{
             "pos", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
             "]"}], "]"}], ",", " ", 
           RowBox[{"{", 
            RowBox[{"i", ",", "lsp"}], "}"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"\[Mu]2", " ", "=", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Mu]", "^", "2"}], ")"}], "*", 
          SuperscriptBox["10", 
           RowBox[{"-", "49"}]]}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"\[Alpha]", " ", "=", " ", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"p\[Alpha]", "[", 
            RowBox[{"[", 
             RowBox[{
             "pos", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
             "]"}], "]"}], ",", " ", 
           RowBox[{"{", 
            RowBox[{"i", ",", "lsp"}], "}"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"mw", "=", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"pmw", "[", 
            RowBox[{"[", 
             RowBox[{
             "pos", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
             "]"}], "]"}], ",", " ", 
           RowBox[{"{", 
            RowBox[{"i", ",", "lsp"}], "}"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
         "\[Epsilon]", ",", "\[Sigma]", ",", "\[Mu]2", ",", "\[Alpha]", " ", 
          ",", "mw"}], "}"}]}]}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"PEOSCG", "[", 
      RowBox[{"p_", ",", "t_", ",", "pa_", ",", "x_", " ", ",", "opts___"}], 
      "]"}], ":=", "\[IndentingNewLine]", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "i", ",", "j", ",", "f", ",", "f\.b4", ",", "f\.b4\.b4", ",", 
         "f1\.b4", ",", "f2\.b4", ",", "g", ",", "\[Rho]0", ",", "\[Rho]1", 
         ",", "\[Rho]2", ",", "\[Rho]a", ",", "\[Rho]p", ",", "\[Rho]max", 
         ",", "\[Delta]", ",", "\[Rho]", ",", "d\[Rho]", ",", 
         "\[CapitalDelta]\[Rho]", ",", "maxi", ",", "tu", ",", "erg", ",", 
         "m", ",", "facm", ",", "debug", ",", "debugt", ",", "debugp1", ",", 
         "debugp2", ",", "modus", ",", "newsp"}], "}"}], ",", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"modus", "=", 
         RowBox[{
          RowBox[{"Speed", "/.", 
           RowBox[{"{", "opts", "}"}]}], "/.", 
          RowBox[{"Options", "[", "PEOSCG", "]"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"newsp", "=", 
         RowBox[{
          RowBox[{"NewSpecies", "/.", 
           RowBox[{"{", "opts", "}"}]}], "/.", 
          RowBox[{"Options", "[", "PEOSCG", "]"}]}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{"measure", " ", "time", " ", "used"}], " ", "*)"}], 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{"debugt", ",", " ", 
          RowBox[{"tu", " ", "=", " ", 
           RowBox[{"TimeUsed", "[", "]"}]}]}], "]"}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"(*", " ", "debugging", " ", "*)"}], "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{"debug", "     ", "=", "  ", "False"}], ";", "  ", 
        RowBox[{"(*", " ", "general", " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{"debugt", "  ", "=", " ", "False"}], ";", 
        RowBox[{"(*", " ", "timing", " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{"debugp1", "=", "  ", "False"}], ";", "  ", 
        RowBox[{"(*", " ", "plotting", " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{"debugp2", "=", " ", "False"}], ";", 
        RowBox[{"(*", " ", 
         RowBox[{"plotting", " ", "derivatives"}], " ", "*)"}], 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{"constants", " ", "and", " ", "initial", " ", "conditions"}],
          " ", "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"maxi", "=", "500"}], ";", "            ", 
        RowBox[{"(*", " ", 
         RowBox[{"maximum", " ", "iterations"}], " ", "*)"}], 
        "\[IndentingNewLine]", 
        RowBox[{"\[Delta]", "        ", "=", 
         RowBox[{"1", "/", "1000."}]}], ";", 
        RowBox[{"(*", " ", 
         RowBox[{
         "increment", " ", "for", " ", "numerical", " ", "differentiation"}], 
         " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{"\[Rho]0", "     ", "=", " ", 
         RowBox[{
          RowBox[{"p", "/", 
           RowBox[{"(", 
            RowBox[{"r", " ", "t"}], ")"}]}], "/", "10"}]}], ";", "  ", 
        RowBox[{"(*", " ", 
         RowBox[{"minimum", " ", "molar", " ", "density"}], " ", "*)"}], 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"m", "=", 
         RowBox[{"Apply", "[", 
          RowBox[{"Plus", ",", 
           RowBox[{"x", " ", 
            RowBox[{
            "pa", "\[LeftDoubleBracket]", "5", "\[RightDoubleBracket]"}]}]}], 
          "]"}]}], ";", " ", 
        RowBox[{"(*", " ", 
         RowBox[{"averrage", " ", "molar", " ", "mass"}], " ", "*)"}], 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{"function", " ", "to", " ", "determine", " ", "increment"}], 
         " ", "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"\[CapitalDelta]\[Rho]", "[", "\[Rho]_", "]"}], ":=", 
         RowBox[{"\[Rho]", "*", "\[Delta]"}]}], ";", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{"function", ":", " ", 
          RowBox[{
          "look", " ", "for", " ", "pressure", " ", "and", " ", "its", " ", 
           "derivatives"}]}], " ", "*)"}], "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"f", "[", "\[Rho]_", "]"}], ":=", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"\[Rho]", "^", "2"}], ")"}], 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"AEOSCGint", "[", 
                 RowBox[{
                  RowBox[{"\[Rho]", "+", 
                   RowBox[{"\[CapitalDelta]\[Rho]", "[", "\[Rho]", "]"}]}], 
                  ",", " ", "t", ",", " ", "pa", ",", " ", "x", ",", 
                  RowBox[{"Speed", "->", "modus"}]}], "]"}], 
                "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], " ", 
               "-", " ", 
               RowBox[{
                RowBox[{"AEOSCGint", "[", 
                 RowBox[{
                  RowBox[{"\[Rho]", "-", 
                   RowBox[{"\[CapitalDelta]\[Rho]", "[", "\[Rho]", "]"}]}], 
                  ",", " ", "t", ",", " ", "pa", ",", " ", "x", ",", 
                  RowBox[{"Speed", "->", "modus"}]}], "]"}], 
                "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]}], 
              ")"}], " ", "/", 
             RowBox[{"(", 
              RowBox[{"2", "  ", 
               RowBox[{"\[CapitalDelta]\[Rho]", "[", "\[Rho]", "]"}]}], 
              ")"}]}]}], ")"}], " ", "-", "  ", "p"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"f\.b4", "[", "\[Rho]_", "]"}], ":=", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"f", "[", 
             RowBox[{"\[Rho]", "+", 
              RowBox[{"\[CapitalDelta]\[Rho]", "[", "\[Rho]", "]"}]}], "]"}], 
            "-", 
            RowBox[{"f", "[", 
             RowBox[{"\[Rho]", "-", 
              RowBox[{"\[CapitalDelta]\[Rho]", "[", "\[Rho]", "]"}]}], 
             "]"}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"2", "  ", 
            RowBox[{"\[CapitalDelta]\[Rho]", "[", "\[Rho]", "]"}]}], 
           ")"}]}]}], ";", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"f\.b4\.b4", "[", "\[Rho]_", "]"}], ":=", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"f\.b4", "[", 
             RowBox[{"\[Rho]", "+", 
              RowBox[{"\[CapitalDelta]\[Rho]", "[", "\[Rho]", "]"}]}], "]"}], 
            "-", 
            RowBox[{"f\.b4", "[", 
             RowBox[{"\[Rho]", "-", 
              RowBox[{"\[CapitalDelta]\[Rho]", "[", "\[Rho]", "]"}]}], 
             "]"}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"2", "  ", 
            RowBox[{"\[CapitalDelta]\[Rho]", "[", "\[Rho]", "]"}]}], 
           ")"}]}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{"determine", " ", "\[Rho]max"}], " ", "*)"}], 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"m", ">", "6.5"}], ",", 
          RowBox[{"facm", "=", "2"}], ",", 
          RowBox[{"facm", "=", "10"}]}], "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"Do", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Rho]p", "=", 
            RowBox[{"f", "[", "\[Rho]\[Rho]", "]"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"\[Rho]p", "<", 
              RowBox[{"p", "/", "10"}]}], ",", ",", 
             RowBox[{
              RowBox[{"\[Rho]max", "=", "\[Rho]\[Rho]"}], ";", 
              RowBox[{"Break", "[", "]"}]}]}], "  ", "]"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"\[Rho]\[Rho]", ",", 
            RowBox[{
             RowBox[{"1", "/", "m"}], "/", "facm"}], ",", "0.1", ",", 
            RowBox[{
             RowBox[{"1", "/", "m"}], "/", "20"}]}], "}"}]}], "]"}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{
         "plot", " ", "whole", " ", "range", " ", "of", " ", "densities", " ",
           "and", " ", "derivatives"}], " ", "*)"}], "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{"debugp1", ",", " ", 
          RowBox[{"plot1", "=", 
           RowBox[{"Plot", "[", 
            RowBox[{
             RowBox[{"f", "[", "\[Rho]", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"\[Rho]", ",", "0.000001", ",", " ", ".1"}], "}"}], " ",
              ",", " ", 
             RowBox[{"PlotRange", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "1"}], ",", "1"}], "}"}]}]}], "]"}]}]}], "]"}], 
        ";", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{"debugp2", ",", " ", 
          RowBox[{"plot2", "=", 
           RowBox[{"Plot", "[", 
            RowBox[{
             RowBox[{"f\.b4", "[", "\[Rho]", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"\[Rho]", ",", "0.000001", ",", " ", ".1"}], "}"}]}], 
            " ", "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{"debugp2", ",", " ", 
          RowBox[{"plot2", "=", 
           RowBox[{"Plot", "[", 
            RowBox[{
             RowBox[{"f\.b4\.b4", "[", "\[Rho]", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"\[Rho]", ",", "0.000001", ",", " ", ".1"}], "}"}]}], 
            " ", "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{"debug", ",", 
          RowBox[{"Print", "[", "\"\<L\>\"", "]"}]}], "]"}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"j", "=", "0"}], ";", "\[IndentingNewLine]", 
        RowBox[{"i", "=", "0"}], ";", "\[IndentingNewLine]", 
        RowBox[{"\[Rho]a", "   ", "=", " ", "\[Rho]max"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"f1\.b4", "=", 
         RowBox[{"f\.b4", "[", "\[Rho]a", "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"d\[Rho]", "=", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            RowBox[{"f", "[", "\[Rho]a", "]"}]}], "/", "f1\.b4"}], "/", 
          "100"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"\[Rho]", "=", 
         RowBox[{"\[Rho]a", "+", "d\[Rho]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"\[Rho]a", "=", "\[Rho]"}], ";", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{"While", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Abs", "[", 
            RowBox[{"d\[Rho]", "/", "\[Rho]"}], "]"}], ">", 
           SuperscriptBox["10", 
            RowBox[{"-", "5"}]]}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"j", "=", 
            RowBox[{"j", "+", "1"}]}], ";", "\[IndentingNewLine]", 
           RowBox[{"f2\.b4", "=", 
            RowBox[{"f\.b4", "[", "\[Rho]a", "]"}]}], ";", 
           "\[IndentingNewLine]", "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"f1\.b4", "*", "f2\.b4"}], "<", "0"}], ",", 
             RowBox[{
              RowBox[{"If", "[", 
               RowBox[{"debug", ",", 
                RowBox[{
                "Print", "[", "\"\<extremum, no solution from this side\>\"", 
                 "]"}]}], "]"}], ";", 
              RowBox[{"\[Rho]", "=", "0"}], ";", 
              RowBox[{"Break", "[", "]"}]}]}], "]"}], ";", 
           "\[IndentingNewLine]", "\[IndentingNewLine]", 
           RowBox[{"d\[Rho]", "=", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               RowBox[{"f", "[", "\[Rho]a", "]"}]}], "/", "f2\.b4"}], "/", 
             "2"}]}], ";", "\[IndentingNewLine]", 
           RowBox[{"\[Rho]", "=", 
            RowBox[{"\[Rho]a", "+", "d\[Rho]"}]}], ";", "\[IndentingNewLine]",
            "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"\[Rho]", "<", "0"}], ",", " ", 
             RowBox[{
              RowBox[{"\[Rho]", "=", 
               RowBox[{
                RowBox[{"p", "/", 
                 RowBox[{"(", 
                  RowBox[{"r", " ", "t"}], ")"}]}], "/", "10"}]}], ";", 
              RowBox[{"i", "=", 
               RowBox[{"i", "+", "1"}]}]}]}], "]"}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"\[Rho]a", "=", "\[Rho]"}], ";", "\[IndentingNewLine]", 
           RowBox[{"f1\.b4", "=", "f2\.b4"}], ";", "\[IndentingNewLine]", 
           "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{"debug", ",", 
             RowBox[{"Print", "[", 
              RowBox[{"{", 
               RowBox[{"d\[Rho]", ",", "\[Rho]"}], "}"}], "]"}]}], "]"}], ";",
            "\[IndentingNewLine]", "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"\[Rho]", ">", "\[Rho]max"}], ",", " ", 
             RowBox[{
              RowBox[{"If", "[", 
               RowBox[{"debug", ",", 
                RowBox[{"Print", "[", 
                 RowBox[{
                 "\"\<error: molar density seems to be larger than \>\"", ",",
                   "\[Rho]max"}], "]"}]}], "]"}], ";", 
              RowBox[{"\[Rho]", "=", "0"}], ";", 
              RowBox[{"Break", "[", "]"}]}]}], "]"}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"j", ">", "maxi"}], ",", 
             RowBox[{
              RowBox[{"If", "[", 
               RowBox[{"debug", ",", " ", 
                RowBox[{
                "Print", "[", "\"\<error: no convergence for liquid\>\"", 
                 "]"}]}], "]"}], ";", " ", 
              RowBox[{"Break", "[", "]"}]}]}], "]"}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"i", ">", "3"}], ",", 
             RowBox[{
              RowBox[{"If", "[", 
               RowBox[{"debug", ",", " ", 
                RowBox[{
                "Print", "[", 
                 "\"\<molar density negativ, no solution from this side\>\"", 
                 "]"}]}], "]"}], ";", " ", 
              RowBox[{"\[Rho]", "=", "0"}], ";", 
              RowBox[{"Break", "[", "]"}]}]}], "]"}], ";"}]}], 
         "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"\[Rho]", ">", "\[Rho]max"}], ",", 
          RowBox[{
           RowBox[{"If", "[", 
            RowBox[{"debug", ",", " ", 
             RowBox[{"Print", "[", 
              RowBox[{
              "\"\<error: molar density seems to be larger than \>\"", ",", 
               "\[Rho]max"}], "]"}]}], "]"}], ";", 
           RowBox[{"\[Rho]", "=", "0"}]}]}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"\[Rho]1", "=", "\[Rho]"}], ";", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{"debug", ",", 
          RowBox[{"Print", "[", "\"\<V\>\"", "]"}]}], "]"}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"j", "=", "0"}], ";", "\[IndentingNewLine]", 
        RowBox[{"i", "=", "0"}], ";", "\[IndentingNewLine]", 
        RowBox[{"\[Rho]a", "   ", "=", " ", "\[Rho]0"}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"f1\.b4", "=", 
         RowBox[{"f\.b4", "[", "\[Rho]a", "]"}]}], ";", "\[IndentingNewLine]",
         "\[IndentingNewLine]", 
        RowBox[{"d\[Rho]", "=", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            RowBox[{"f", "[", "\[Rho]a", "]"}]}], "/", "f1\.b4"}], "/", 
          "100"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"\[Rho]", "=", 
         RowBox[{"\[Rho]a", "+", "d\[Rho]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"\[Rho]a", "=", "\[Rho]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"\[Rho]a", "<", "0."}], ",", 
          RowBox[{"\[Rho]a", "=", 
           RowBox[{"\[Rho]0", "/", "100."}]}]}], "]"}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"While", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Abs", "[", 
            RowBox[{"d\[Rho]", "/", "\[Rho]"}], "]"}], ">", 
           SuperscriptBox["10", 
            RowBox[{"-", "5"}]]}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"j", "=", 
            RowBox[{"j", "+", "1"}]}], ";", "\[IndentingNewLine]", 
           RowBox[{"f2\.b4", "=", 
            RowBox[{"f\.b4", "[", "\[Rho]a", "]"}]}], ";", 
           "\[IndentingNewLine]", "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"f1\.b4", "*", "f2\.b4"}], "<", "0"}], ",", 
             RowBox[{
              RowBox[{"If", "[", 
               RowBox[{"debug", ",", 
                RowBox[{
                "Print", "[", "\"\<extremum, no solution from this side\>\"", 
                 "]"}]}], "]"}], ";", 
              RowBox[{"\[Rho]", "=", "0"}], ";", 
              RowBox[{"Break", "[", "]"}]}]}], "]"}], ";", 
           "\[IndentingNewLine]", "\[IndentingNewLine]", 
           RowBox[{"d\[Rho]", "=", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               RowBox[{"f", "[", "\[Rho]a", "]"}]}], "/", "f2\.b4"}], "/", 
             "2"}]}], ";", "\[IndentingNewLine]", 
           RowBox[{"\[Rho]", "=", 
            RowBox[{"\[Rho]a", "+", "d\[Rho]"}]}], ";", "\[IndentingNewLine]",
            "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"\[Rho]", "<", "0"}], ",", " ", 
             RowBox[{
              RowBox[{"\[Rho]", "=", 
               RowBox[{
                RowBox[{"p", "/", 
                 RowBox[{"(", 
                  RowBox[{"r", " ", "t"}], ")"}]}], "/", "10"}]}], ";", 
              RowBox[{"i", "=", 
               RowBox[{"i", "+", "1"}]}]}]}], "]"}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"\[Rho]a", "=", "\[Rho]"}], ";", "\[IndentingNewLine]", 
           "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{"debug", ",", 
             RowBox[{"Print", "[", 
              RowBox[{"{", 
               RowBox[{"d\[Rho]", ",", "\[Rho]"}], "}"}], "]"}]}], "]"}], ";",
            "\[IndentingNewLine]", "\[IndentingNewLine]", 
           RowBox[{"f1\.b4", "=", "f2\.b4"}], ";", "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"\[Rho]", ">", "\[Rho]max"}], ",", 
             RowBox[{
              RowBox[{"If", "[", 
               RowBox[{"debug", ",", " ", 
                RowBox[{"Print", "[", 
                 RowBox[{
                 "\"\<error: molar density seems to be larger than \>\"", ",",
                   "\[Rho]max"}], "]"}]}], "]"}], ";", 
              RowBox[{"\[Rho]", "=", "0"}], ";", 
              RowBox[{"Break", "[", "]"}]}]}], "]"}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"j", ">", "maxi"}], ",", " ", 
             RowBox[{
              RowBox[{"If", "[", 
               RowBox[{"debug", ",", 
                RowBox[{
                "Print", "[", "\"\<error: no convergence for vapor\>\"", 
                 "]"}]}], "]"}], ";", 
              RowBox[{"Break", "[", "]"}]}]}], "]"}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"i", ">", "3"}], ",", 
             RowBox[{
              RowBox[{"If", "[", 
               RowBox[{"debug", ",", " ", 
                RowBox[{
                "Print", "[", 
                 "\"\<molar density negativ, no solution from this side\>\"", 
                 "]"}]}], "]"}], ";", 
              RowBox[{"\[Rho]", "=", "0"}], ";", " ", 
              RowBox[{"Break", "[", "]"}]}]}], "]"}], ";"}]}], 
         "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"\[Rho]", ">", "\[Rho]max"}], ",", 
          RowBox[{
           RowBox[{"If", "[", 
            RowBox[{"debug", ",", " ", 
             RowBox[{"Print", "[", 
              RowBox[{
              "\"\<error: molar density seems to be larger than \>\"", ",", 
               "\[Rho]max"}], "]"}]}], "]"}], ";", 
           RowBox[{"\[Rho]", "=", "0"}]}]}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"\[Rho]2", "=", "\[Rho]"}], ";", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{"if", " ", "no", " ", "solution", " ", "was", " ", "found"}],
          " ", "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Rho]1", "\[Equal]", "0"}], "\[And]", 
           RowBox[{"\[Rho]2", "\[Equal]", "0"}]}], ",", " ", 
          RowBox[{
           RowBox[{
           "Print", "[", "\"\<fatal error: no solution detected\>\"", "]"}], 
           ";", 
           RowBox[{"Return", "[", "]"}]}]}], "]"}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{
         "put", " ", "valid", " ", "result", " ", "on", " ", "first", " ", 
          "place"}], " ", "*)"}], "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"\[Rho]1", "\[Equal]", "0"}], ",", 
          RowBox[{
           RowBox[{"\[Rho]1", "=", "\[Rho]2"}], ";", 
           RowBox[{"\[Rho]2", "=", "0"}]}]}], "]"}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{
          RowBox[{"if", " ", "identical"}], ",", " ", 
          RowBox[{"eliminate", " ", "one", " ", "result"}]}], " ", "*)"}], 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Abs", "[", 
            RowBox[{"\[Rho]1", "-", "\[Rho]2"}], "]"}], "<", " ", 
           RowBox[{"\[Rho]1", "/", "1000."}]}], ",", " ", 
          RowBox[{"\[Rho]2", "=", "0."}]}], "]"}], ";", "\[IndentingNewLine]",
         "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{"formulate", " ", "result"}], " ", "*)"}], 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"\[Rho]2", ">", "0."}], ",", 
          RowBox[{"erg", "=", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"\[Rho]1", ",", 
               FractionBox["p", 
                RowBox[{"\[Rho]1", " ", "r", " ", "t"}]]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"\[Rho]2", ",", 
               FractionBox["p", 
                RowBox[{"\[Rho]2", " ", "r", " ", "t"}]]}], "}"}]}], "}"}]}], 
          ",", 
          RowBox[{"erg", "=", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"\[Rho]1", ",", 
               FractionBox["p", 
                RowBox[{"\[Rho]1", " ", "r", " ", "t"}]]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"0.", ",", "0."}], "}"}]}], "}"}]}]}], "]"}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{"find", " ", "stable", " ", "phase"}], " ", "*)"}], 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"\[Rho]2", ">", "0."}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"g", "=", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"AEOSCGint", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                   "erg", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
                   "\[RightDoubleBracket]"}], ",", "t", ",", "pa", ",", "x", 
                  ",", 
                  RowBox[{"Speed", "->", "modus"}]}], "]"}], 
                "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], "+", 
               FractionBox["p", 
                RowBox[{
                 RowBox[{
                 "erg", "\[LeftDoubleBracket]", "1", 
                  "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
                 "\[RightDoubleBracket]"}]]}], ",", 
              RowBox[{
               RowBox[{
                RowBox[{"AEOSCGint", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                   "erg", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
                   "\[RightDoubleBracket]"}], ",", "t", ",", "pa", ",", "x", 
                  ",", 
                  RowBox[{"Speed", "->", "modus"}]}], "]"}], 
                "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], "+", 
               FractionBox["p", 
                RowBox[{
                 RowBox[{
                 "erg", "\[LeftDoubleBracket]", "2", 
                  "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
                 "\[RightDoubleBracket]"}]]}]}], "}"}]}], ";", 
           "\[IndentingNewLine]", "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{"debug", ",", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                "g", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
                "<", 
                RowBox[{
                "g", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}],
                ",", 
               RowBox[{"Print", "[", 
                RowBox[{"\"\<stable g: \>\"", ",", 
                 RowBox[{
                 "g", "\[LeftDoubleBracket]", "1", 
                  "\[RightDoubleBracket]"}]}], "]"}], ",", 
               RowBox[{"Print", "[", 
                RowBox[{"\"\<stable g: \>\"", ",", 
                 RowBox[{
                 "g", "\[LeftDoubleBracket]", "2", 
                  "\[RightDoubleBracket]"}]}], "]"}]}], "]"}]}], "]"}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{"debug", ",", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                "g", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
                "<", 
                RowBox[{
                "g", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}],
                ",", 
               RowBox[{"Print", "[", 
                RowBox[{"\"\<stable \[Rho],z: \>\"", ",", 
                 RowBox[{
                 "erg", "\[LeftDoubleBracket]", "1", 
                  "\[RightDoubleBracket]"}]}], "]"}], ",", 
               RowBox[{"Print", "[", 
                RowBox[{"\"\<stable \[Rho],z: \>\"", ",", 
                 RowBox[{
                 "erg", "\[LeftDoubleBracket]", "2", 
                  "\[RightDoubleBracket]"}]}], "]"}]}], "]"}]}], "]"}], ";", 
           "\[IndentingNewLine]", "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
              "g", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
              "<", 
              RowBox[{
              "g", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
             ",", 
             RowBox[{"erg", "=", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                "erg", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}],
                 ",", 
                RowBox[{
                "erg", "\[LeftDoubleBracket]", "2", 
                 "\[RightDoubleBracket]"}]}], "}"}]}], ",", 
             RowBox[{"erg", "=", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                "erg", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}],
                 ",", 
                RowBox[{
                "erg", "\[LeftDoubleBracket]", "1", 
                 "\[RightDoubleBracket]"}]}], "}"}]}]}], "]"}]}], ",", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"If", "[", 
            RowBox[{"debug", ",", 
             RowBox[{"Print", "[", 
              RowBox[{"\"\<stable g: \>\"", ",", 
               RowBox[{
                RowBox[{
                 RowBox[{"AEOSCGint", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    "erg", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], ",", "t", ",", "pa", ",", "x", 
                   ",", 
                   RowBox[{"Speed", "->", "modus"}]}], "]"}], 
                 "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], "+", 
                
                FractionBox["p", 
                 RowBox[{
                  RowBox[{
                  "erg", "\[LeftDoubleBracket]", "1", 
                   "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "1", 
                  "\[RightDoubleBracket]"}]]}]}], "]"}]}], "]"}], ";", 
           RowBox[{"If", "[", 
            RowBox[{"debug", ",", 
             RowBox[{"Print", "[", 
              RowBox[{"\"\<stable \[Rho],z: \>\"", ",", 
               RowBox[{
               "erg", "\[LeftDoubleBracket]", "1", 
                "\[RightDoubleBracket]"}]}], "]"}]}], "]"}]}]}], 
         "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{"debug", ",", 
          RowBox[{"Print", "[", "erg", "]"}]}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{"debugt", ",", 
          RowBox[{"Print", "[", 
           RowBox[{"\"\<timing : \>\"", ",", 
            RowBox[{
             RowBox[{"TimeUsed", "[", "]"}], "-", "tu"}]}], "]"}]}], "]"}], 
        ";", "\[IndentingNewLine]", "\[IndentingNewLine]", "erg"}]}], 
      "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"AEOSCGint", "[", 
      RowBox[{
      "\[Rho]_", ",", " ", "t_", ",", " ", "pa_", ",", " ", "x_", ",", " ", 
       "opts___"}], "]"}], "  ", ":=", "\[IndentingNewLine]", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"a", ",", "modus", ",", "newsp"}], "}"}], ",", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"modus", "=", 
         RowBox[{
          RowBox[{"Speed", "/.", 
           RowBox[{"{", "opts", "}"}]}], "/.", 
          RowBox[{"Options", "[", "AEOSCGint", "]"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"newsp", "=", 
         RowBox[{
          RowBox[{"NewSpecies", "/.", 
           RowBox[{"{", "opts", "}"}]}], "/.", 
          RowBox[{"Options", "[", "AEOSCGint", "]"}]}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"modus", " ", "\[Equal]", " ", "\"\<slow\>\""}], ",", " ", 
          RowBox[{"a", " ", "=", " ", 
           RowBox[{"AEOSCGslow", "[", 
            RowBox[{"\[Rho]", ",", " ", "t", ",", " ", "pa", ",", " ", "x"}], 
            "]"}]}], ",", "  ", 
          RowBox[{"a", " ", "=", " ", 
           RowBox[{"AEOSCGfast", "[", 
            RowBox[{"\[Rho]", ",", " ", "t", ",", 
             RowBox[{
             "pa", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
             ",", 
             RowBox[{
             "pa", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
             ",", 
             RowBox[{
             "pa", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
             ",", 
             RowBox[{
             "pa", "\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}], 
             ",", " ", "x"}], "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", "a"}]}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"AEOSCGslow", "[", 
      RowBox[{"\[Rho]_", ",", " ", "t_", ",", " ", "pa_", ",", " ", "x_"}], 
      "]"}], " ", ":=", "\[IndentingNewLine]", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "i", ",", "j", ",", "m", ",", "lsp", ",", "\[Epsilon]", ",", 
         "\[Sigma]", ",", "\[Mu]", ",", "\[Mu]2", ",", "\[Alpha]", ",", " ", 
         "\[Epsilon]ij", ",", "\[Sigma]ij", ",", "\[Sigma]3mix", ",", " ", 
         "\[Epsilon]mix", ",", " ", "sx", ",", " ", "\[Beta]", ",", 
         "\[Rho]\.b4", ",", "\[Rho]SI", ",", "\[Rho]ij\.b4", ",", 
         "\[Beta]ij\.b4", ",", "A0", ",", " ", "A1", ",", "A2", ",", "A3", 
         ",", " ", "Ares", ",", " ", "Aideal"}], "}"}], ",", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"\[Rho]SI", " ", "=", " ", 
         RowBox[{
          SuperscriptBox["10", "6"], " ", "\[Rho]"}]}], ";", "   ", 
        RowBox[{"(*", " ", 
         RowBox[{"Umrechnung", " ", 
          RowBox[{"von", " ", "[", 
           RowBox[{"MPa", "/", "J"}], "]"}], " ", 
          RowBox[{"auf", " ", "[", 
           RowBox[{"Pa", "/", "J"}], "]"}]}], " ", "*)"}], 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"lsp", " ", "=", " ", 
         RowBox[{"Length", "[", "x", "]"}]}], ";", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{"\[Epsilon]", "    ", "=", " ", 
         RowBox[{
         "pa", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"\[Sigma]", "    ", "=", " ", 
         RowBox[{
         "pa", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"\[Mu]2", " ", "=", " ", 
         RowBox[{
         "pa", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"\[Alpha]", "    ", "=", " ", 
         RowBox[{
         "pa", "\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"\[Sigma]ij", " ", "=", " ", 
         RowBox[{"Table", "[", " ", 
          RowBox[{
           FractionBox[
            RowBox[{
             RowBox[{
             "\[Sigma]", "\[LeftDoubleBracket]", "i", 
              "\[RightDoubleBracket]"}], "+", " ", 
             RowBox[{
             "\[Sigma]", "\[LeftDoubleBracket]", "j", 
              "\[RightDoubleBracket]"}]}], "2"], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "lsp"}], "}"}], ",", " ", 
           RowBox[{"{", 
            RowBox[{"j", ",", "lsp"}], "}"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"\[Epsilon]ij", " ", "=", " ", 
         RowBox[{"Table", "[", " ", 
          RowBox[{
           SqrtBox[
            RowBox[{
             RowBox[{
             "\[Epsilon]", "\[LeftDoubleBracket]", "i", 
              "\[RightDoubleBracket]"}], "  ", 
             RowBox[{
             "\[Epsilon]", "\[LeftDoubleBracket]", "j", 
              "\[RightDoubleBracket]"}]}]], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "lsp"}], "}"}], ",", " ", 
           RowBox[{"{", 
            RowBox[{"j", ",", "lsp"}], "}"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"\[Sigma]3mix", " ", "=", " ", 
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
            "x", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], "  ", 
            RowBox[{
            "x", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}], "  ", 
            RowBox[{
             RowBox[{
              RowBox[{
              "\[Sigma]ij", "\[LeftDoubleBracket]", "i", 
               "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "j", 
              "\[RightDoubleBracket]"}], "^", "3"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "lsp"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "lsp"}], "}"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"\[Epsilon]mix", " ", "=", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "/", "\[Sigma]3mix"}], ")"}], " ", 
          RowBox[{"Sum", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
             "x", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], "  ", 
             RowBox[{
             "x", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}], " ", 
             RowBox[{
              RowBox[{
              "\[Epsilon]ij", "\[LeftDoubleBracket]", "i", 
               "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "j", 
              "\[RightDoubleBracket]"}], 
             RowBox[{
              RowBox[{
               RowBox[{
               "\[Sigma]ij", "\[LeftDoubleBracket]", "i", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "j", 
               "\[RightDoubleBracket]"}], "^", "3"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "lsp"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"j", ",", "lsp"}], "}"}]}], "]"}]}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"\[Beta]", "   ", "=", 
         RowBox[{"\[Epsilon]mix", "/", 
          RowBox[{"(", 
           RowBox[{"k", " ", "t"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"\[Rho]\.b4", " ", "=", "  ", 
         RowBox[{"\[Rho]SI", " ", "na", " ", "\[Sigma]3mix"}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"\[Beta]ij\.b4", " ", "=", 
         RowBox[{"\[Epsilon]ij", "/", 
          RowBox[{"(", 
           RowBox[{"k", " ", "t"}], ")"}]}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"\[Rho]ij\.b4", " ", "=", "  ", 
         RowBox[{"\[Rho]SI", " ", "na", " ", 
          RowBox[{"\[Sigma]ij", "^", "3"}]}]}], ";", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"A0", " ", "=", "  ", 
         RowBox[{"r", " ", "t", " ", 
          RowBox[{"ALJ", "[", 
           RowBox[{"\[Beta]", ",", "\[Rho]\.b4"}], "]"}]}]}], " ", ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"A1", "=", 
         RowBox[{
          RowBox[{"-", "2"}], " ", "\[Pi]", " ", 
          SuperscriptBox["na", "2"], " ", "\[Rho]SI", " ", 
          RowBox[{
           UnderoverscriptBox["\[Sum]", 
            RowBox[{"i", "=", "1"}], "lsp"], 
           RowBox[{
            UnderoverscriptBox["\[Sum]", 
             RowBox[{"j", "=", "1"}], "lsp"], 
            FractionBox[
             RowBox[{
              RowBox[{
              "x", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
              " ", 
              RowBox[{
              "x", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}], 
              " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{
                 "\[Alpha]", "\[LeftDoubleBracket]", "j", 
                  "\[RightDoubleBracket]"}], " ", 
                 RowBox[{
                 "\[Mu]2", "\[LeftDoubleBracket]", "i", 
                  "\[RightDoubleBracket]"}]}], "+", 
                RowBox[{
                 RowBox[{
                 "\[Alpha]", "\[LeftDoubleBracket]", "i", 
                  "\[RightDoubleBracket]"}], " ", 
                 RowBox[{
                 "\[Mu]2", "\[LeftDoubleBracket]", "j", 
                  "\[RightDoubleBracket]"}]}]}], ")"}], " ", 
              RowBox[{"Jij", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{
                 "\[Beta]ij\.b4", "\[LeftDoubleBracket]", "i", 
                  "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "j", 
                 "\[RightDoubleBracket]"}], ",", 
                RowBox[{
                 RowBox[{
                 "\[Rho]ij\.b4", "\[LeftDoubleBracket]", "i", 
                  "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "j", 
                 "\[RightDoubleBracket]"}]}], "]"}]}], 
             SuperscriptBox[
              RowBox[{
               RowBox[{
               "\[Sigma]ij", "\[LeftDoubleBracket]", "i", 
                "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "j", 
               "\[RightDoubleBracket]"}], "3"]]}]}]}]}], ";", "\n", 
        "\[IndentingNewLine]", 
        RowBox[{"A2", "=", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"2", " ", "\[Pi]", " ", 
             SuperscriptBox["na", "2"], " ", "\[Rho]SI", " ", 
             RowBox[{
              UnderoverscriptBox["\[Sum]", 
               RowBox[{"i", "=", "1"}], "lsp"], 
              RowBox[{
               UnderoverscriptBox["\[Sum]", 
                RowBox[{"j", "=", "1"}], "lsp"], 
               FractionBox[
                RowBox[{
                 RowBox[{
                 "x", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
                 " ", 
                 RowBox[{
                 "x", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}], 
                 " ", 
                 RowBox[{
                 "\[Mu]2", "\[LeftDoubleBracket]", "i", 
                  "\[RightDoubleBracket]"}], " ", 
                 RowBox[{
                 "\[Mu]2", "\[LeftDoubleBracket]", "j", 
                  "\[RightDoubleBracket]"}], " ", 
                 RowBox[{"Jij", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    "\[Beta]ij\.b4", "\[LeftDoubleBracket]", "i", 
                    "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "j", 
                    "\[RightDoubleBracket]"}], ",", 
                   RowBox[{
                    RowBox[{
                    "\[Rho]ij\.b4", "\[LeftDoubleBracket]", "i", 
                    "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "j", 
                    "\[RightDoubleBracket]"}]}], "]"}]}], 
                SuperscriptBox[
                 RowBox[{
                  RowBox[{
                  "\[Sigma]ij", "\[LeftDoubleBracket]", "i", 
                   "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "j", 
                  "\[RightDoubleBracket]"}], "3"]]}]}]}], ")"}]}], "/", 
          RowBox[{"(", 
           RowBox[{"3", " ", "k", " ", "t"}], ")"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"A3", "=", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"32", " ", 
            SuperscriptBox["\[Pi]", "3"], " ", 
            SuperscriptBox["na", "3"], " ", 
            SuperscriptBox["\[Rho]SI", "2"], " ", 
            SqrtBox[
             FractionBox[
              RowBox[{"14", " ", "\[Pi]"}], "5"]], " ", 
            RowBox[{
             UnderoverscriptBox["\[Sum]", 
              RowBox[{"i", "=", "1"}], "lsp"], 
             RowBox[{
              UnderoverscriptBox["\[Sum]", 
               RowBox[{"j", "=", "1"}], "lsp"], 
              RowBox[{
               UnderoverscriptBox["\[Sum]", 
                RowBox[{"m", "=", "1"}], "lsp"], 
               FractionBox[
                RowBox[{
                 RowBox[{
                 "x", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
                 " ", 
                 RowBox[{
                 "x", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}], 
                 " ", 
                 RowBox[{
                 "x", "\[LeftDoubleBracket]", "m", "\[RightDoubleBracket]"}], 
                 " ", 
                 RowBox[{
                 "\[Mu]2", "\[LeftDoubleBracket]", "i", 
                  "\[RightDoubleBracket]"}], " ", 
                 RowBox[{
                 "\[Mu]2", "\[LeftDoubleBracket]", "j", 
                  "\[RightDoubleBracket]"}], " ", 
                 RowBox[{
                 "\[Mu]2", "\[LeftDoubleBracket]", "m", 
                  "\[RightDoubleBracket]"}], " ", 
                 RowBox[{"Kijm", "[", 
                  RowBox[{
                  "i", ",", "j", ",", "m", ",", "\[Beta]ij\.b4", ",", 
                   "\[Rho]ij\.b4"}], "]"}]}], 
                RowBox[{
                 RowBox[{
                  RowBox[{
                  "\[Sigma]ij", "\[LeftDoubleBracket]", "i", 
                   "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "j", 
                  "\[RightDoubleBracket]"}], " ", 
                 RowBox[{
                  RowBox[{
                  "\[Sigma]ij", "\[LeftDoubleBracket]", "i", 
                   "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "m", 
                  "\[RightDoubleBracket]"}], " ", 
                 RowBox[{
                  RowBox[{
                  "\[Sigma]ij", "\[LeftDoubleBracket]", "j", 
                   "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "m", 
                  "\[RightDoubleBracket]"}]}]]}]}]}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"135", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"k", " ", "t"}], ")"}], "2"]}], ")"}]}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"A2", " ", "!=", "0"}], ",", " ", 
          RowBox[{"Ares", " ", "=", " ", 
           RowBox[{"A0", " ", "+", " ", "A1", " ", "+", " ", 
            RowBox[{"A2", "*", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"1", " ", "-", " ", 
                RowBox[{"A3", "/", "A2"}]}], ")"}], 
              RowBox[{"-", "1"}]]}]}]}], ",", 
          RowBox[{"Ares", " ", "=", " ", 
           RowBox[{"A0", " ", "+", " ", "A1"}]}]}], "]"}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{
          RowBox[{"Dichte", " ", "Einheit", " ", "hier", " ", 
           RowBox[{"aber", " ", "[", 
            RowBox[{"MPa", "/", "J"}], "]"}]}], ",", " ", 
          RowBox[{"Standarddruck", " ", "0.1", " ", "MPa"}]}], " ", "*)"}], 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"Aideal", " ", "=", " ", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"r", " ", "t"}], ")"}]}], " ", 
          RowBox[{
           UnderoverscriptBox["\[Sum]", 
            RowBox[{"i", "=", "1"}], "lsp"], 
           RowBox[{
            RowBox[{
            "x", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], " ", 
            
            RowBox[{"Log", "[", 
             RowBox[{"0.1", "/", 
              RowBox[{"(", " ", 
               RowBox[{
                RowBox[{
                "x", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
                " ", "\[Rho]", " ", "r", " ", "t"}], ")"}]}], "]"}]}]}]}]}], 
        ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"{", " ", 
         RowBox[{"Aideal", ",", " ", "Ares", ",", 
          RowBox[{"Aideal", "+", "Ares"}]}], "}"}]}]}], "\[IndentingNewLine]",
       "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ALJ", "[", 
      RowBox[{"\[Beta]_", ",", "\[Rho]\.b4_"}], "]"}], ":=", 
     "\[IndentingNewLine]", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "P1", ",", "P2", ",", "P3", ",", "P4", ",", "P5", ",", "P6", ",", 
         "P7", ",", "P8", ",", "P9", ",", "P10", ",", "C1", ",", "C2", ",", 
         "\[IndentingNewLine]", "\t    ", "A1", ",", "A2", ",", "A3", ",", 
         "A4", ",", "A5", ",", "A6", ",", "B1", ",", "B2", ",", "B3", ",", 
         "B4", ",", "B5", ",", "B6", ",", "\[IndentingNewLine]", "\t   ", 
         "A00", ",", "A01", ",", "A10", ",", " ", "A11", ",", "A12", ",", 
         "A21", ",", "A22", ",", "A23", ",", "A31", ",", "A32", ",", "A33", 
         ",", "A34", ",", "\[IndentingNewLine]", "\t   ", "\[Eta]", ",", "d", 
         ",", "\[Sigma]0", ",", "\[Sigma]1", ",", "dB", ",", "\[Delta]", ",", 
         "eq", ",", "erg", ",", "\[Eta]w", ",", "\[IndentingNewLine]", 
         "\t   ", "f1", ",", "f2", ",", "I12", ",", "I6", ",", "dw", ",", 
         "rm", ",", "\[Xi]", ",", "\[IndentingNewLine]", "\t   ", "a0", ",", 
         "a1", ",", "a2", ",", "a3", ",", "I2", ",", "\[IndentingNewLine]", 
         "\t  ", "ARPA", ",", "AHTA", ",", "AHS"}], "}"}], ",", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"P1", "=", "1.186892378996"}], ";", "\[IndentingNewLine]", 
        RowBox[{"P2", "=", 
         RowBox[{"-", "0.4721963005527"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"P3", "=", "3.259515855283"}], ";", "\[IndentingNewLine]", 
        RowBox[{"P4", "=", "3.055229342609"}], ";", "\[IndentingNewLine]", 
        RowBox[{"P5", "=", "1.095409321023"}], ";", "\[IndentingNewLine]", 
        RowBox[{"P6", "=", 
         FractionBox["1.282306659774", 
          SuperscriptBox["10", "2"]]}], ";", "\[IndentingNewLine]", 
        RowBox[{"P7", "=", 
         FractionBox["9.55712461425", 
          SuperscriptBox["10", "2"]]}], ";", "\[IndentingNewLine]", 
        RowBox[{"P8", "=", "13.67807693107"}], ";", "\[IndentingNewLine]", 
        RowBox[{"P9", "=", "35.75464856619"}], ";", "\[IndentingNewLine]", 
        RowBox[{"P10", "=", "16.04724381643"}], ";", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{"C1", "=", 
         RowBox[{"{", 
          RowBox[{"1.2011", ",", "0.06489", ",", 
           RowBox[{"-", "76.86"}], ",", "562.686", ",", 
           RowBox[{"-", "2280.09"}], ",", "6266.84", ",", 
           RowBox[{"-", "11753.4"}], ",", "14053.8", ",", 
           RowBox[{"-", "9491.49"}], ",", "2731.03"}], "}"}]}], ";", 
        RowBox[{"C2", "=", 
         RowBox[{"{", 
          RowBox[{"0.58889", ",", 
           RowBox[{"-", "7.45536"}], ",", "40.5759", ",", 
           RowBox[{"-", "104.897"}], ",", "60.2547", ",", "390.631", ",", 
           RowBox[{"-", "1193.08"}], ",", "1576.35", ",", 
           RowBox[{"-", "1045.91"}], ",", "283.758"}], "}"}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"A1", "=", 
         RowBox[{"-", "0.120078459237"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"A2", "=", 
         RowBox[{"-", "0.808712488307"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"A3", "=", "0.321543801337"}], ";", "\[IndentingNewLine]", 
        RowBox[{"A4", "=", "1.16965477132"}], ";", "\[IndentingNewLine]", 
        RowBox[{"A5", "=", 
         RowBox[{"-", "0.410564939543"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"A6", "=", 
         RowBox[{"-", "0.516834310691"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"B1", "=", 
         RowBox[{"-", "2.18839961483"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"B2", "=", "1.59897428009"}], ";", "\[IndentingNewLine]", 
        RowBox[{"B3", "=", 
         RowBox[{"-", "0.392578806128"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"B4", "=", 
         RowBox[{"-", "0.189396607904"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"B5", "=", 
         RowBox[{"-", "0.576898496254"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"B6", "=", 
         RowBox[{"-", "0.0185167641359"}]}], ";", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{"A00", "=", "0.9985937977069455"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"A01", "=", "0.5079834224407451"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"A10", "=", "1.021887697885469"}], ";", "\[IndentingNewLine]", 
        RowBox[{"A11", "=", 
         RowBox[{"-", "5.136619463333883"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"A12", "=", 
         RowBox[{"-", "5.196188074016755"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"A21", "=", 
         RowBox[{"-", "6.049240839050804"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"A22", "=", "18.67848155616692"}], ";", "\[IndentingNewLine]", 
        RowBox[{"A23", "=", "20.10652684217768"}], ";", "\[IndentingNewLine]", 
        RowBox[{"A31", "=", "9.896491419756988"}], ";", "\[IndentingNewLine]", 
        RowBox[{"A32", "=", "14.6738380473899"}], ";", "\[IndentingNewLine]", 
        
        RowBox[{"A33", "=", 
         RowBox[{"-", "77.44825116542995"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"A34", "=", 
         RowBox[{"-", "4.82871082941229"}]}], ";", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{"\[Eta]", "=", 
         RowBox[{
          FractionBox["1", "6"], " ", "\[Pi]", " ", 
          SuperscriptBox["d", "3"], " ", "\[Rho]\.b4"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"\[Sigma]0", "=", 
         FractionBox[
          RowBox[{"1", "-", 
           FractionBox["\[Eta]", "2"]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "-", "\[Eta]"}], ")"}], "3"]]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"\[Sigma]1", "=", 
         FractionBox[
          RowBox[{
           RowBox[{
            RowBox[{"-", "1.51"}], " ", 
            SuperscriptBox["\[Eta]", "4"]}], "-", 
           RowBox[{"5.7865", " ", 
            SuperscriptBox["\[Eta]", "3"]}], "+", 
           FractionBox[
            SuperscriptBox["\[Eta]", "2"], "2"], "-", 
           FractionBox[
            RowBox[{"15", " ", "\[Eta]"}], "2"], "+", "2"}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "-", "\[Eta]"}], ")"}], "4"]]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"dB", "=", 
         FractionBox[
          RowBox[{
           RowBox[{"P1", " ", 
            SuperscriptBox["\[Beta]", 
             RowBox[{"1", "/", "12"}]]}], "+", 
           RowBox[{"P2", " ", 
            SuperscriptBox["\[Beta]", 
             RowBox[{"7", "/", "12"}]]}], "+", 
           RowBox[{"P5", " ", 
            SuperscriptBox["\[Beta]", "3"]}], "+", 
           RowBox[{"P4", " ", 
            SuperscriptBox["\[Beta]", "2"]}], "+", 
           RowBox[{"P3", " ", "\[Beta]"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"\[Beta]", "+", "1"}], ")"}], "3"]]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"\[Delta]", "=", 
         FractionBox[
          RowBox[{"P6", "+", 
           RowBox[{"P7", " ", 
            SuperscriptBox["\[Beta]", 
             RowBox[{"1", "/", "2"}]]}]}], 
          RowBox[{"1", "+", 
           RowBox[{"P8", " ", 
            SuperscriptBox["\[Beta]", 
             RowBox[{"1", "/", "2"}]]}], "+", 
           RowBox[{"P10", " ", 
            SuperscriptBox["\[Beta]", 
             RowBox[{"3", "/", "2"}]]}], "+", 
           RowBox[{"P9", " ", "\[Beta]"}]}]]}], ";", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{"eq", "=", 
         RowBox[{"N", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"dB", " ", 
             RowBox[{"(", 
              RowBox[{
               FractionBox[
                RowBox[{"\[Delta]", " ", "\[Sigma]1"}], 
                RowBox[{"2", " ", "\[Sigma]0"}]], "+", "1."}], ")"}]}], "-", 
            "d"}], "==", "0."}], "]"}]}], ";", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{"erg", "=", 
         RowBox[{"FindRoot", "[", 
          RowBox[{"eq", ",", 
           RowBox[{"{", 
            RowBox[{"d", ",", "dB"}], "}"}], ",", " ", 
           RowBox[{"MaxIterations", " ", "\[Rule]", " ", "1000"}]}], 
          RowBox[{"(*", 
           RowBox[{",", " ", 
            RowBox[{"AccuracyGoal", "\[Rule]", "14"}]}], "*)"}], "]"}]}], ";",
         "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"d", "=", 
         RowBox[{"d", "/.", "\[InvisibleSpace]", "erg"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"\[Eta]w", "=", 
         RowBox[{"\[Eta]", "-", 
          FractionBox[
           SuperscriptBox["\[Eta]", "2"], "16"]}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"f1", "=", 
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
            "C1", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], " ", 
            SuperscriptBox["\[Eta]w", "i"]}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "10"}], "}"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"f2", "=", 
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
            "C2", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], " ", 
            SuperscriptBox["\[Eta]w", 
             RowBox[{"i", "+", "1"}]]}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "10"}], "}"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"ARPA", "=", 
         RowBox[{
          FractionBox[
           RowBox[{"192", " ", 
            SuperscriptBox["\[Beta]", "3"], " ", "f2"}], "\[Pi]"], "-", 
          FractionBox[
           RowBox[{"12", " ", 
            SuperscriptBox["\[Beta]", "2"], " ", "f1"}], "\[Pi]"]}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"I12", "=", 
         FractionBox[
          RowBox[{
           RowBox[{"B6", " ", 
            SuperscriptBox["\[Eta]w", "3"]}], "+", 
           RowBox[{"B5", " ", 
            SuperscriptBox["\[Eta]w", "2"]}], "+", 
           RowBox[{"B4", " ", "\[Eta]w"}], "+", "1"}], 
          RowBox[{"9", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"B3", " ", 
              SuperscriptBox["\[Eta]w", "3"]}], "+", 
             RowBox[{"B2", " ", 
              SuperscriptBox["\[Eta]w", "2"]}], "+", 
             RowBox[{"B1", " ", "\[Eta]w"}], "+", "1"}], ")"}]}]]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"I6", "=", 
         FractionBox[
          RowBox[{
           RowBox[{"A6", " ", 
            SuperscriptBox["\[Eta]w", "3"]}], "+", 
           RowBox[{"A5", " ", 
            SuperscriptBox["\[Eta]w", "2"]}], "+", 
           RowBox[{"A4", " ", "\[Eta]w"}], "+", "1"}], 
          RowBox[{"3", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"A3", " ", 
              SuperscriptBox["\[Eta]w", "3"]}], "+", 
             RowBox[{"A2", " ", 
              SuperscriptBox["\[Eta]w", "2"]}], "+", 
             RowBox[{"A1", " ", "\[Eta]w"}], "+", "1"}], ")"}]}]]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"dw", "=", 
         RowBox[{"d", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "-", 
             FractionBox["\[Eta]", "16"]}], ")"}], 
           RowBox[{"1", "/", "3"}]]}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"rm", "=", 
         SuperscriptBox["2", 
          RowBox[{"1", "/", "6"}]]}], ";", "\[IndentingNewLine]", 
        RowBox[{"\[Xi]", "=", 
         FractionBox["rm", "dw"]}], ";", "\[IndentingNewLine]", 
        RowBox[{"a0", "=", 
         FractionBox[
          RowBox[{"A00", "+", 
           RowBox[{"A01", " ", "\[Eta]w"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "-", "\[Eta]w"}], ")"}], "2"]]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"a1", "=", 
         FractionBox[
          RowBox[{
           RowBox[{"A12", " ", 
            SuperscriptBox["\[Eta]w", "2"]}], "+", 
           RowBox[{"A11", " ", "\[Eta]w"}], "+", "A10"}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "-", "\[Eta]w"}], ")"}], "3"]]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"a2", "=", 
         FractionBox[
          RowBox[{
           RowBox[{"A23", " ", 
            SuperscriptBox["\[Eta]w", "3"]}], "+", 
           RowBox[{"A22", " ", 
            SuperscriptBox["\[Eta]w", "2"]}], "+", 
           RowBox[{"A21", " ", "\[Eta]w"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "-", "\[Eta]w"}], ")"}], "4"]]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"a3", "=", 
         FractionBox[
          RowBox[{
           RowBox[{"A34", " ", 
            SuperscriptBox["\[Eta]w", "4"]}], "+", 
           RowBox[{"A33", " ", 
            SuperscriptBox["\[Eta]w", "3"]}], "+", 
           RowBox[{"A32", " ", 
            SuperscriptBox["\[Eta]w", "2"]}], "+", 
           RowBox[{"A31", " ", "\[Eta]w"}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "-", "\[Eta]w"}], ")"}], "5"]]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"I2", "=", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             FractionBox["1", "35"]}], " ", "3", " ", "a3", " ", 
            SuperscriptBox["\[Xi]", "5"]}], "-", 
           RowBox[{
            FractionBox["9", "64"], " ", 
            RowBox[{"(", 
             RowBox[{"a2", "-", "a3"}], ")"}], " ", 
            SuperscriptBox["\[Xi]", "4"]}], "-", 
           RowBox[{
            FractionBox["2", "9"], " ", 
            RowBox[{"(", 
             RowBox[{"a1", "-", "a2", "+", 
              FractionBox["a3", "2"]}], ")"}], " ", 
            SuperscriptBox["\[Xi]", "3"]}], "\[IndentingNewLine]", "   ", "-", 
           RowBox[{
            FractionBox["9", "40"], " ", 
            RowBox[{"(", 
             RowBox[{"a0", "-", "a1", "+", 
              FractionBox["a2", "2"], "-", 
              FractionBox["a3", "6"]}], ")"}], " ", 
            SuperscriptBox["\[Xi]", "2"]}], "+", 
           RowBox[{
            FractionBox["1", "8"], " ", 
            RowBox[{"(", 
             RowBox[{"a0", "-", 
              FractionBox["a1", "3"], "+", 
              FractionBox["a2", "12"], "-", 
              FractionBox["a3", "60"]}], ")"}]}], "\[IndentingNewLine]", 
           "    ", "+", 
           FractionBox[
            RowBox[{
             FractionBox["a0", "4"], "+", 
             FractionBox["a1", "12"], "+", 
             FractionBox["a2", "24"], "+", 
             FractionBox["a3", "24"]}], 
            SuperscriptBox["dw", "6"]], "-", 
           FractionBox[
            RowBox[{
             FractionBox["a0", "10"], "+", 
             FractionBox["a1", "90"], "+", 
             FractionBox["a2", "720"], "+", 
             FractionBox["a3", "5040"]}], 
            SuperscriptBox["dw", "12"]]}], ")"}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"AHTA", "=", 
         RowBox[{"48", " ", "\[Beta]", " ", "\[Eta]w", " ", 
          RowBox[{"(", 
           RowBox[{
            FractionBox["I12", 
             SuperscriptBox["dw", "12"]], "+", "I2", "-", 
            FractionBox["I6", 
             SuperscriptBox["dw", "6"]]}], ")"}]}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"AHS", "=", 
         FractionBox[
          RowBox[{
           RowBox[{"4", " ", "\[Eta]"}], "-", 
           RowBox[{"3", " ", 
            SuperscriptBox["\[Eta]", "2"]}]}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "-", "\[Eta]"}], ")"}], "2"]]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"AHS", "+", "AHTA", "+", "ARPA"}]}]}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"ULJ", "[", 
      RowBox[{"\[Beta]\.b4_", ",", "\[Rho]\.b4_"}], "]"}], ":=", 
     "\[IndentingNewLine]", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", "\[CapitalDelta]\[Beta]\.b4", "}"}], ",", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"\[CapitalDelta]\[Beta]\.b4", "=", 
         FractionBox["\[Beta]\.b4", 
          SuperscriptBox["10", "6"]]}], ";", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        FractionBox[
         RowBox[{
          RowBox[{"ALJ", "[", 
           RowBox[{
            RowBox[{
            "\[Beta]\.b4", " ", "+", " ", "\[CapitalDelta]\[Beta]\.b4"}], " ",
             ",", "\[Rho]\.b4"}], "]"}], " ", "-", " ", 
          RowBox[{"ALJ", "[", 
           RowBox[{
            RowBox[{
            "\[Beta]\.b4", " ", "-", " ", "\[CapitalDelta]\[Beta]\.b4"}], ",",
             "\[Rho]\.b4"}], "]"}], " "}], 
         RowBox[{"2", " ", "\[CapitalDelta]\[Beta]\.b4"}]]}]}], 
      "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"ZLJ", "[", 
      RowBox[{"\[Beta]\.b4_", ",", "\[Rho]\.b4_"}], "]"}], ":=", 
     "\[IndentingNewLine]", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", "\[CapitalDelta]\[Rho]\.b4", "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"\[CapitalDelta]\[Rho]\.b4", "=", 
         FractionBox["\[Rho]\.b4", 
          SuperscriptBox["10", "6"]]}], ";", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{"1", " ", "+", 
         RowBox[{"\[Rho]\.b4", " ", 
          FractionBox[
           RowBox[{" ", 
            RowBox[{
             RowBox[{"ALJ", "[", 
              RowBox[{"\[Beta]\.b4", ",", 
               RowBox[{"\[Rho]\.b4", "+", "\[CapitalDelta]\[Rho]\.b4"}]}], 
              "]"}], "-", 
             RowBox[{"ALJ", "[", 
              RowBox[{"\[Beta]\.b4", ",", 
               RowBox[{"\[Rho]\.b4", "-", "\[CapitalDelta]\[Rho]\.b4"}]}], 
              "]"}]}]}], 
           RowBox[{"2", " ", "\[CapitalDelta]\[Rho]\.b4"}]]}]}]}]}], 
      "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"Jij", "[", 
      RowBox[{"\[Beta]\.b4_", ",", "\[Rho]\.b4_"}], "]"}], ":=", " ", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"4", " ", "\[Beta]\.b4", " ", 
         RowBox[{"ULJ", "[", 
          RowBox[{"\[Beta]\.b4", ",", "\[Rho]\.b4"}], "]"}]}], "-", " ", 
        RowBox[{"ZLJ", "[", 
         RowBox[{"\[Beta]\.b4", ",", "\[Rho]\.b4"}], "]"}], " ", "+", " ", 
        "1"}], 
       RowBox[{
       "16", " ", "\[Pi]", " ", "\[Rho]\.b4", " ", "\[Beta]\.b4"}]]}]}], 
    ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"K\.b4", "[", 
      RowBox[{"\[Beta]\.b4_", ",", "\[Rho]\.b4_"}], "]"}], ":=", 
     "\[IndentingNewLine]", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", " ", 
        RowBox[{
        "M1", ",", " ", "M2", ",", " ", "M3", ",", " ", "M4", ",", " ", "M5", 
         ",", " ", "M6"}], "}"}], ",", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"M1", "=", 
         RowBox[{"-", "1.050534"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"M2", "=", "  ", "1.747476"}], ";", "\[IndentingNewLine]", 
        RowBox[{"M3", "=", "  ", "1.749366"}], ";", "\[IndentingNewLine]", 
        RowBox[{"M4", "=", 
         RowBox[{"-", "1.999227"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"M5", "=", 
         RowBox[{"-", "0.661046"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"M6", "=", 
         RowBox[{"-", "3.028720"}]}], ";", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{"Exp", "[", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"-", " ", "M1"}], " ", 
           RowBox[{"Log", "[", "\[Beta]\.b4", "]"}], " ", 
           SuperscriptBox["\[Rho]\.b4", "2"]}], "+", " ", 
          RowBox[{"M2", " ", 
           SuperscriptBox["\[Rho]\.b4", "2"]}], " ", "-", " ", 
          RowBox[{"M3", " ", 
           RowBox[{"Log", "[", "\[Beta]\.b4", "]"}], " ", "\[Rho]\.b4"}], "+",
           " ", 
          RowBox[{"M4", " ", "\[Rho]\.b4"}], "-", " ", 
          RowBox[{"M5", " ", 
           RowBox[{"Log", "[", "\[Beta]\.b4", "]"}]}], " ", "+", " ", "M6"}], 
         "]"}]}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}]}], 
    ";"}], "\[IndentingNewLine]", "\n", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Kijm", "[", 
      RowBox[{
      "i_", ",", "j_", ",", "m_", ",", "\[Beta]ij\.b4_", ",", 
       "\[Rho]ij\.b4_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"K\.b4", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
           "\[Beta]ij\.b4", "\[LeftDoubleBracket]", "i", 
            "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "j", 
           "\[RightDoubleBracket]"}], ",", 
          RowBox[{
           RowBox[{
           "\[Rho]ij\.b4", "\[LeftDoubleBracket]", "i", 
            "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "j", 
           "\[RightDoubleBracket]"}]}], "]"}], "*", " ", 
        RowBox[{"K\.b4", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
           "\[Beta]ij\.b4", "\[LeftDoubleBracket]", "i", 
            "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "m", 
           "\[RightDoubleBracket]"}], ",", 
          RowBox[{
           RowBox[{
           "\[Rho]ij\.b4", "\[LeftDoubleBracket]", "i", 
            "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "m", 
           "\[RightDoubleBracket]"}]}], "]"}], " ", "*", " ", 
        RowBox[{"K\.b4", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
           "\[Beta]ij\.b4", "\[LeftDoubleBracket]", "j", 
            "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "m", 
           "\[RightDoubleBracket]"}], ",", 
          RowBox[{
           RowBox[{
           "\[Rho]ij\.b4", "\[LeftDoubleBracket]", "j", 
            "\[RightDoubleBracket]"}], "\[LeftDoubleBracket]", "m", 
           "\[RightDoubleBracket]"}]}], "]"}]}], ")"}], "^", 
      RowBox[{"(", 
       RowBox[{"1", "/", "3"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
     "Further", " ", "functions", " ", "to", " ", "calculate", " ", "gas"}], 
     "-", 
     RowBox[{"liquid", " ", "equilibria"}]}], "*)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"flist", "[", 
      RowBox[{
      "p_", ",", "t_", ",", "species_", ",", "from_", ",", "to_", ",", 
       "nincr_", ",", "opts___"}], "]"}], ":=", "\[IndentingNewLine]", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "cc", ",", "erg", ",", "i", ",", "x", ",", "compl", ",", "f", ",", 
         "incr", ",", " ", "debug", ",", "modus", ",", "newsp"}], "}"}], ",", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"modus", "=", 
         RowBox[{
          RowBox[{"Speed", "/.", 
           RowBox[{"{", "opts", "}"}]}], "/.", 
          RowBox[{"Options", "[", "flist", "]"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"newsp", "=", 
         RowBox[{
          RowBox[{"NewSpecies", "/.", 
           RowBox[{"{", "opts", "}"}]}], "/.", 
          RowBox[{"Options", "[", "flist", "]"}]}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"debug", "=", "False"}], ";", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{"incr", "=", 
         FractionBox[
          RowBox[{"to", "-", "from"}], "nincr"]}], ";", "\[IndentingNewLine]",
         "\[IndentingNewLine]", 
        RowBox[{"cc", "=", 
         RowBox[{"Table", "[", 
          RowBox[{"i", ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "from", ",", "to", ",", "incr"}], "}"}]}], 
          "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"erg", "=", 
         RowBox[{"Table", "[", 
          RowBox[{"0", ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", 
             RowBox[{"Length", "[", "cc", "]"}]}], "}"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"Do", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"x", "=", 
            RowBox[{
            "cc", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}]}], 
           ";", "\[IndentingNewLine]", 
           RowBox[{"compl", "=", 
            RowBox[{"{", 
             RowBox[{"x", ",", 
              RowBox[{"1", "-", "x"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
           
           RowBox[{"f", "=", 
            RowBox[{"FEOSCG", "[", 
             RowBox[{"p", ",", "t", ",", "species", ",", "compl", ",", 
              RowBox[{"Speed", "->", "modus"}]}], "]"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"f", "=", 
            RowBox[{"f", " ", "compl"}]}], ";", "\[IndentingNewLine]", 
           "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{"debug", ",", 
             RowBox[{"Print", "[", 
              RowBox[{"{", 
               RowBox[{"p", ",", "t", ",", "x", ",", "f"}], "}"}], "]"}]}], 
            "]"}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
            "erg", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], 
            "=", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"x", ",", 
                RowBox[{
                "f", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}],
                "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"x", ",", 
                RowBox[{
                "f", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}],
                "}"}]}], "}"}]}]}], ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "cc", "]"}]}], "}"}]}], 
         "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", "erg"}]}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"miscgap", "[", 
      RowBox[{"p_", ",", "t_", ",", "species_", ",", 
       RowBox[{"increments_:", "25"}], " ", ",", "opts___"}], "]"}], " ", ":=",
      "\[IndentingNewLine]", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "debug", ",", "erg", ",", "f1data", ",", "f2data", ",", "f1", ",", 
         "f2", ",", "x", ",", "xl", ",", "xg", ",", "compl", ",", "compg", 
         ",", "fl", ",", "fg", ",", "modus", ",", "newsp"}], "}"}], ",", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"modus", "=", 
         RowBox[{
          RowBox[{"Speed", "/.", 
           RowBox[{"{", "opts", "}"}]}], "/.", 
          RowBox[{"Options", "[", "miscgap", "]"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"newsp", "=", 
         RowBox[{
          RowBox[{"NewSpecies", "/.", 
           RowBox[{"{", "opts", "}"}]}], "/.", 
          RowBox[{"Options", "[", "miscgap", "]"}]}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"debug", "=", "False"}], ";", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{"erg", "=", 
         RowBox[{"flist", "[", 
          RowBox[{"p", ",", "t", ",", "species", ",", 
           FractionBox["1", 
            SuperscriptBox["10.", "10"]], ",", 
           RowBox[{"1.", "-", 
            FractionBox["1", 
             SuperscriptBox["10", "10"]]}], ",", "increments"}], "]"}]}], ";",
         "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{"f1data", "=", 
         RowBox[{
          RowBox[{"Transpose", "[", "erg", "]"}], "\[LeftDoubleBracket]", "1",
           "\[RightDoubleBracket]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"f2data", "=", 
         RowBox[{
          RowBox[{"Transpose", "[", "erg", "]"}], "\[LeftDoubleBracket]", "2",
           "\[RightDoubleBracket]"}]}], ";", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{"debug", ",", 
          RowBox[{"ListPlot", "[", "f1data", "]"}]}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{"debug", ",", 
          RowBox[{"ListPlot", "[", "f2data", "]"}]}], "]"}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"f1", "=", 
         RowBox[{"Interpolation", "[", "f1data", "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"f2", "=", 
         RowBox[{"Interpolation", "[", "f2data", "]"}]}], ";", "\n", 
        "\[IndentingNewLine]", 
        RowBox[{"x", "=", 
         RowBox[{"FindRoot", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"f1", "[", "xl", "]"}], "==", 
              RowBox[{"f1", "[", "xg", "]"}]}], ",", 
             RowBox[{
              RowBox[{"f2", "[", "xl", "]"}], "==", 
              RowBox[{"f2", "[", "xg", "]"}]}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"xl", ",", "0.99"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"xg", ",", "0.01"}], "}"}], ",", 
           RowBox[{"MaxIterations", "\[Rule]", "1000"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"xl", "=", 
         RowBox[{"xl", "/.", "\[InvisibleSpace]", "x"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"xg", "=", 
         RowBox[{"xg", "/.", "\[InvisibleSpace]", "x"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"compl", "=", 
         RowBox[{"{", 
          RowBox[{"xl", ",", 
           RowBox[{"1", "-", "xl"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"compg", "=", 
         RowBox[{"{", 
          RowBox[{"xg", ",", 
           RowBox[{"1", "-", "xg"}]}], "}"}]}], ";", "\n", 
        "\[IndentingNewLine]", 
        RowBox[{"fl", "=", 
         RowBox[{
          RowBox[{"FEOSCG", "[", 
           RowBox[{"p", ",", "t", ",", "species", ",", "compl", ",", 
            RowBox[{"Speed", "->", "modus"}]}], "]"}], " ", "compl"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"fg", "=", 
         RowBox[{
          RowBox[{"FEOSCG", "[", 
           RowBox[{"p", ",", "t", ",", "species", ",", "compg", ",", 
            RowBox[{"Speed", "->", "modus"}]}], "]"}], " ", "compg"}]}], ";", 
        "\n", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{"debug", ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Print", "[", 
            RowBox[{"TableForm", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                "\"\<P [MPa]\>\"", ",", "\"\<T [K]\>\"", ",", 
                 "\"\<T [\[Degree]C]\>\""}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"p", ",", "t", ",", 
                 RowBox[{"t", "-", "273.15"}]}], "}"}], ",", 
               RowBox[{"{", "}"}], ",", 
               RowBox[{"{", 
                RowBox[{
                "\"\<\>\"", ",", "\"\<x_l\>\"", ",", "\"\<x_g\>\"", ",", 
                 "\"\<f_l\>\"", ",", "\"\<f_g\>\"", ",", "\"\<ln f_l\>\"", 
                 ",", "\"\<ln f_g\>\"", ",", "\"\<RT ln f_l\>\"", ",", 
                 "\"\<RT ln f_g\>\"", ",", "\"\<\[CapitalDelta]G\>\""}], 
                "}"}], ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{
                 "species", "\[LeftDoubleBracket]", "1", 
                  "\[RightDoubleBracket]"}], ",", "xl", ",", "xg", ",", 
                 RowBox[{
                 "fl", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}],
                  ",", 
                 RowBox[{
                 "fg", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}],
                  ",", 
                 RowBox[{"Log", "[", 
                  RowBox[{
                  "fl", "\[LeftDoubleBracket]", "1", 
                   "\[RightDoubleBracket]"}], "]"}], ",", 
                 RowBox[{"Log", "[", 
                  RowBox[{
                  "fg", "\[LeftDoubleBracket]", "1", 
                   "\[RightDoubleBracket]"}], "]"}], ",", 
                 RowBox[{"r", " ", "t", " ", 
                  RowBox[{"Log", "[", 
                   RowBox[{
                   "fl", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], "]"}]}], ",", 
                 RowBox[{"r", " ", "t", " ", 
                  RowBox[{"Log", "[", 
                   RowBox[{
                   "fg", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], "]"}]}], ",", 
                 RowBox[{
                  RowBox[{"r", " ", "t", " ", 
                   RowBox[{"Log", "[", 
                    RowBox[{
                    "fl", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], "]"}]}], "-", 
                  RowBox[{"r", " ", "t", " ", 
                   RowBox[{"Log", "[", 
                    RowBox[{
                    "fg", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], "]"}]}]}]}], "}"}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{
                 "species", "\[LeftDoubleBracket]", "2", 
                  "\[RightDoubleBracket]"}], ",", 
                 RowBox[{"1", "-", "xl"}], ",", 
                 RowBox[{"1", "-", "xg"}], ",", 
                 RowBox[{
                 "fl", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}],
                  ",", 
                 RowBox[{
                 "fg", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}],
                  ",", 
                 RowBox[{"Log", "[", 
                  RowBox[{
                  "fl", "\[LeftDoubleBracket]", "2", 
                   "\[RightDoubleBracket]"}], "]"}], ",", 
                 RowBox[{"Log", "[", 
                  RowBox[{
                  "fg", "\[LeftDoubleBracket]", "2", 
                   "\[RightDoubleBracket]"}], "]"}], ",", 
                 RowBox[{"r", " ", "t", " ", 
                  RowBox[{"Log", "[", 
                   RowBox[{
                   "fl", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}], "]"}]}], ",", 
                 RowBox[{"r", " ", "t", " ", 
                  RowBox[{"Log", "[", 
                   RowBox[{
                   "fg", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}], "]"}]}], ",", 
                 RowBox[{
                  RowBox[{"r", " ", "t", " ", 
                   RowBox[{"Log", "[", 
                    RowBox[{
                    "fl", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}], "]"}]}], "-", 
                  RowBox[{"r", " ", "t", " ", 
                   RowBox[{"Log", "[", 
                    RowBox[{
                    "fg", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}], "]"}]}]}]}], "}"}]}], "}"}], 
             "]"}], "]"}], ";"}]}], "\[IndentingNewLine]", "]"}], ";", "\n", 
        "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"xl", ",", 
            RowBox[{
            "fl", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",",
             "  ", 
            RowBox[{
            "fg", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
            RowBox[{"r", " ", "t", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Log", "[", 
                RowBox[{
                "fl", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
                "]"}], "-", " ", 
               RowBox[{"Log", "[", 
                RowBox[{
                "fg", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
                "]"}]}], ")"}]}]}], " ", "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"xg", ",", 
            RowBox[{
            "fl", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], ",",
             "  ", 
            RowBox[{
            "fg", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], ",", 
            RowBox[{"r", " ", "t", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Log", "[", 
                RowBox[{
                "fl", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
                "]"}], "-", " ", 
               RowBox[{"Log", "[", 
                RowBox[{
                "fg", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
                "]"}]}], ")"}]}]}], "}"}]}], "}"}]}]}], "\[IndentingNewLine]",
       "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"miscgapNewton", "[", 
      RowBox[{"p_", ",", "t_", ",", "species_", ",", 
       RowBox[{"xx_:", "0.9999"}], ",", " ", 
       RowBox[{"yy_:", "0.0001"}], " ", ",", "opts___"}], "]"}], " ", ":=", 
     "\[IndentingNewLine]", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "debug", ",", " ", "h", ",", "k", ",", "x", ",", "y", ",", " ", 
         "delta", ",", "xp", ",", "xm", ",", "yp", ",", "ym", ",", "fug", ",",
          "fl", ",", "flp", ",", "flm", ",", "gl", ",", "glp", ",", "glm", 
         ",", "fg", ",", "fgp", ",", "fgm", ",", "gg", ",", "ggp", ",", "ggm",
          ",", "f", ",", "g", ",", "fx", ",", "fy", ",", "gx", ",", "gy", ",",
          "modus", ",", "newsp"}], "}"}], ",", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"modus", "=", 
         RowBox[{
          RowBox[{"Speed", "/.", 
           RowBox[{"{", "opts", "}"}]}], "/.", 
          RowBox[{"Options", "[", "miscgapNewton", "]"}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"newsp", "=", 
         RowBox[{
          RowBox[{"NewSpecies", "/.", 
           RowBox[{"{", "opts", "}"}]}], "/.", 
          RowBox[{"Options", "[", "miscgapNewton", "]"}]}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"debug", "=", "False"}], ";", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{"k", "=", "1"}], ";", "\[IndentingNewLine]", 
        RowBox[{"h", "=", "1"}], ";", "\[IndentingNewLine]", 
        RowBox[{"j", " ", "=", " ", "0"}], ";", "\[IndentingNewLine]", 
        RowBox[{"x", " ", "=", "xx"}], ";", "\[IndentingNewLine]", 
        RowBox[{"y", " ", "=", "yy"}], ";", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{"While", "[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"Abs", "[", "k", "]"}], ">", ".0005"}], "\[Or]", 
            RowBox[{
             RowBox[{"Abs", "[", "h", "]"}], ">", ".0005"}]}], ")"}], ",", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"delta", "=", ".0001"}], ";", "\[IndentingNewLine]", 
           RowBox[{"xp", "=", 
            RowBox[{"x", "+", "delta"}]}], ";", "\[IndentingNewLine]", 
           RowBox[{"xm", "=", 
            RowBox[{"x", "-", "delta"}]}], ";", "\[IndentingNewLine]", 
           RowBox[{"yp", "=", 
            RowBox[{"x", "+", "delta"}]}], ";", "\[IndentingNewLine]", 
           RowBox[{"ym", "=", 
            RowBox[{"x", "-", "delta"}]}], ";", "\[IndentingNewLine]", 
           "\[IndentingNewLine]", "\[IndentingNewLine]", 
           "\[IndentingNewLine]", 
           RowBox[{"fug", "=", 
            RowBox[{
             RowBox[{"FEOSCG", "[", 
              RowBox[{"p", ",", "t", ",", " ", "species", ",", " ", 
               RowBox[{"{", 
                RowBox[{"x", ",", " ", 
                 RowBox[{"1", "-", "x"}]}], "}"}], ",", 
               RowBox[{"Speed", "->", "modus"}]}], "]"}], " ", 
             RowBox[{"{", 
              RowBox[{"x", ",", " ", 
               RowBox[{"1", "-", "x"}]}], "}"}]}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"fl", " ", "=", 
            RowBox[{
            "fug", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
           ";", "\[IndentingNewLine]", 
           RowBox[{"gl", " ", "=", 
            RowBox[{
            "fug", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
           ";", "\[IndentingNewLine]", 
           RowBox[{"fug", "=", 
            RowBox[{
             RowBox[{"FEOSCG", "[", 
              RowBox[{"p", ",", "t", ",", " ", "species", ",", " ", 
               RowBox[{"{", 
                RowBox[{"y", ",", " ", 
                 RowBox[{"1", "-", "y"}]}], "}"}], ",", 
               RowBox[{"Speed", "->", "modus"}]}], "]"}], " ", 
             RowBox[{"{", 
              RowBox[{"y", ",", " ", 
               RowBox[{"1", "-", "y"}]}], "}"}]}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"fg", " ", "=", 
            RowBox[{
            "fug", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
           ";", "\[IndentingNewLine]", 
           RowBox[{"gg", " ", "=", 
            RowBox[{
            "fug", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
           ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
           RowBox[{"fug", "=", 
            RowBox[{
             RowBox[{"FEOSCG", "[", 
              RowBox[{"p", ",", "t", ",", " ", "species", ",", " ", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"x", "+", "delta"}], ",", " ", 
                 RowBox[{"1", "-", 
                  RowBox[{"(", 
                   RowBox[{"x", "+", "delta"}], ")"}]}]}], "}"}], ",", 
               RowBox[{"Speed", "->", "modus"}]}], "]"}], " ", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"x", "+", "delta"}], ",", " ", 
               RowBox[{"1", "-", 
                RowBox[{"(", 
                 RowBox[{"x", "+", "delta"}], ")"}]}]}], "}"}]}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"flp", " ", "=", 
            RowBox[{
            "fug", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
           ";", "\[IndentingNewLine]", 
           RowBox[{"glp", " ", "=", 
            RowBox[{
            "fug", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
           ";", "\[IndentingNewLine]", 
           RowBox[{"fug", "=", 
            RowBox[{
             RowBox[{"FEOSCG", "[", 
              RowBox[{"p", ",", "t", ",", " ", "species", ",", " ", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"y", "+", "delta"}], ",", " ", 
                 RowBox[{"1", "-", 
                  RowBox[{"(", 
                   RowBox[{"y", "+", "delta"}], ")"}]}]}], "}"}], ",", 
               RowBox[{"Speed", "->", "modus"}]}], "]"}], " ", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"y", "+", "delta"}], ",", " ", 
               RowBox[{"1", "-", 
                RowBox[{"(", 
                 RowBox[{"y", "+", "delta"}], ")"}]}]}], "}"}]}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"fgp", " ", "=", 
            RowBox[{
            "fug", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
           ";", "\[IndentingNewLine]", 
           RowBox[{"ggp", " ", "=", 
            RowBox[{
            "fug", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
           ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
           RowBox[{"fug", "=", 
            RowBox[{
             RowBox[{"FEOSCG", "[", 
              RowBox[{"p", ",", "t", ",", " ", "species", ",", " ", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"x", "-", "delta"}], ",", " ", 
                 RowBox[{"1", "-", 
                  RowBox[{"(", 
                   RowBox[{"x", "-", "delta"}], ")"}]}]}], "}"}], ",", 
               RowBox[{"Speed", "->", "modus"}]}], "]"}], " ", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"x", "-", "delta"}], ",", " ", 
               RowBox[{"1", "-", 
                RowBox[{"(", 
                 RowBox[{"x", "-", "delta"}], ")"}]}]}], "}"}]}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"flm", " ", "=", 
            RowBox[{
            "fug", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
           ";", "\[IndentingNewLine]", 
           RowBox[{"glm", " ", "=", 
            RowBox[{
            "fug", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
           ";", "\[IndentingNewLine]", 
           RowBox[{"fug", "=", 
            RowBox[{
             RowBox[{"FEOSCG", "[", 
              RowBox[{"p", ",", "t", ",", " ", "species", ",", " ", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"y", "-", "delta"}], ",", " ", 
                 RowBox[{"1", "-", 
                  RowBox[{"(", 
                   RowBox[{"y", "-", "delta"}], ")"}]}]}], "}"}], ",", 
               RowBox[{"Speed", "->", "modus"}]}], "]"}], " ", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"y", "-", "delta"}], ",", " ", 
               RowBox[{"1", "-", 
                RowBox[{"(", 
                 RowBox[{"y", "-", "delta"}], ")"}]}]}], "}"}]}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"fgm", " ", "=", 
            RowBox[{
            "fug", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
           ";", "\[IndentingNewLine]", 
           RowBox[{"ggm", " ", "=", 
            RowBox[{
            "fug", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
           ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
           "\[IndentingNewLine]", 
           RowBox[{"f", " ", "=", " ", 
            RowBox[{"fl", "-", "fg"}]}], ";", "\[IndentingNewLine]", 
           RowBox[{"g", " ", "=", " ", 
            RowBox[{"gl", "-", "gg"}]}], ";", "\[IndentingNewLine]", 
           "\[IndentingNewLine]", 
           RowBox[{"fx", " ", "=", " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"flp", "-", "flm"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", " ", "delta"}], ")"}]}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"fy", " ", "=", " ", 
            RowBox[{
             RowBox[{"-", 
              RowBox[{"(", 
               RowBox[{"fgp", "-", "fgm"}], ")"}]}], "/", 
             RowBox[{"(", 
              RowBox[{"2", " ", "delta"}], ")"}]}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"gx", " ", "=", " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"glp", "-", "glm"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", " ", "delta"}], ")"}]}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"gy", " ", "=", " ", 
            RowBox[{
             RowBox[{"-", 
              RowBox[{"(", 
               RowBox[{"ggp", "-", "ggm"}], ")"}]}], "/", 
             RowBox[{"(", 
              RowBox[{"2", " ", "delta"}], ")"}]}]}], ";", 
           "\[IndentingNewLine]", "\[IndentingNewLine]", 
           RowBox[{"k", "=", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"g", " ", "fx"}], "-", 
               RowBox[{"f", " ", "gx"}]}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"fy", " ", "gx"}], "-", 
               RowBox[{"gy", " ", "fx"}]}], ")"}]}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"h", "=", 
            RowBox[{
             RowBox[{"-", 
              RowBox[{"(", 
               RowBox[{"f", "+", 
                RowBox[{"k", " ", "fy"}]}], ")"}]}], "/", "fx"}]}], ";", 
           "\[IndentingNewLine]", "\[IndentingNewLine]", 
           "\[IndentingNewLine]", 
           RowBox[{"If", "[", " ", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"Abs", "[", "h", "]"}], ">", "0.05"}], "\[Or]", 
               RowBox[{
                RowBox[{"Abs", "[", "k", "]"}], ">", "0.05"}]}], ")"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"x", "=", 
               RowBox[{"x", "+", 
                RowBox[{"h", "/", "5"}]}]}], ";", "\[IndentingNewLine]", 
              RowBox[{"y", "=", 
               RowBox[{"y", "+", 
                RowBox[{"k", "/", "5"}]}]}]}], ",", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"x", "=", 
               RowBox[{"x", "+", "h"}]}], ";", "\[IndentingNewLine]", 
              RowBox[{"y", "=", 
               RowBox[{"y", "+", "k"}]}]}]}], "\[IndentingNewLine]", "]"}], 
           ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{"debug", ",", "\[IndentingNewLine]", 
             RowBox[{"Print", "[", 
              RowBox[{"TableForm", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{
                  "\"\<P [MPa]\>\"", ",", " ", "\"\<T [K]\>\"", ",", " ", 
                   "\"\<T [\[Degree]C]\>\""}], "}"}], ",", " ", 
                 RowBox[{"{", 
                  RowBox[{"p", ",", "t", ",", 
                   RowBox[{"t", "-", "273.15"}]}], "}"}], ",", " ", 
                 RowBox[{"{", "}"}], ",", " ", 
                 RowBox[{"{", 
                  RowBox[{
                  "\"\<\>\"", ",", "\"\<x_l\>\"", ",", "\"\<x_g\>\"", ",", 
                   "\"\<f_l\>\"", ",", "\"\<f_g\>\"", ",", " ", 
                   "\"\<ln f_l\>\"", ",", "\"\<ln f_g\>\"", ",", " ", 
                   "\"\<RT ln f_l\>\"", ",", "\"\<RT ln f_g\>\"", ",", " ", 
                   "\"\<\[CapitalDelta]G\>\""}], "}"}], ",", 
                 "\[IndentingNewLine]", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{
                   "species", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], ",", "x", ",", "y", ",", "fl", 
                   " ", ",", "fg", " ", ",", " ", 
                   RowBox[{"Log", "[", "fl", "]"}], ",", " ", 
                   RowBox[{"Log", "[", "fg", "]"}], ",", " ", 
                   RowBox[{"r", " ", "t", " ", 
                    RowBox[{"Log", "[", "fl", "]"}]}], ",", " ", 
                   RowBox[{"r", " ", "t", " ", 
                    RowBox[{"Log", "[", "fg", "]"}]}], ",", "  ", 
                   RowBox[{"r", " ", "t", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{"fl", "/", "fg"}], "]"}]}]}], "}"}], ",", " ", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{
                   "species", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}], ",", 
                   RowBox[{"1", "-", "x"}], ",", 
                   RowBox[{"1", "-", "y"}], ",", "gl", " ", ",", "gg", " ", 
                   ",", " ", 
                   RowBox[{"Log", "[", "gl", "]"}], ",", " ", 
                   RowBox[{"Log", "[", "gg", "]"}], ",", " ", 
                   RowBox[{"r", " ", "t", " ", 
                    RowBox[{"Log", "[", "gl", "]"}]}], ",", " ", 
                   RowBox[{"r", " ", "t", " ", 
                    RowBox[{"Log", "[", "gg", "]"}]}], ",", 
                   RowBox[{"r", " ", "t", " ", 
                    RowBox[{"Log", "[", 
                    RowBox[{"gl", "/", "gg"}], "]"}]}]}], "}"}]}], "}"}], 
               "]"}], "]"}]}], "\[IndentingNewLine]", "]"}], ";"}]}], 
         "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
         "]"}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"fl", "=", 
         RowBox[{
          RowBox[{"FEOSCG", "[", 
           RowBox[{"p", ",", "t", ",", " ", "species", ",", " ", 
            RowBox[{"{", 
             RowBox[{"x", ",", " ", 
              RowBox[{"1", "-", "x"}]}], "}"}], ",", 
            RowBox[{"Speed", "->", "modus"}]}], "]"}], " ", 
          RowBox[{"{", 
           RowBox[{"x", ",", " ", 
            RowBox[{"1", "-", "x"}]}], "}"}]}]}], ";", "\[IndentingNewLine]", 
        
        RowBox[{"fg", "=", 
         RowBox[{
          RowBox[{"FEOSCG", "[", 
           RowBox[{"p", ",", "t", ",", " ", "species", ",", " ", 
            RowBox[{"{", 
             RowBox[{"y", ",", " ", 
              RowBox[{"1", "-", "y"}]}], "}"}], ",", 
            RowBox[{"Speed", "->", "modus"}]}], "]"}], " ", 
          RowBox[{"{", 
           RowBox[{"y", ",", " ", 
            RowBox[{"1", "-", "y"}]}], "}"}]}]}], ";", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{"debug", ",", 
          RowBox[{"Print", "[", 
           RowBox[{"TableForm", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
               "\"\<P [MPa]\>\"", ",", " ", "\"\<T [K]\>\"", ",", " ", 
                "\"\<T [\[Degree]C]\>\""}], "}"}], ",", " ", 
              RowBox[{"{", 
               RowBox[{"p", ",", "t", ",", 
                RowBox[{"t", "-", "273.15"}]}], "}"}], ",", " ", 
              RowBox[{"{", "}"}], ",", " ", 
              RowBox[{"{", 
               RowBox[{
               "\"\<\>\"", ",", "\"\<x_l\>\"", ",", "\"\<x_g\>\"", ",", 
                "\"\<f_l\>\"", ",", "\"\<f_g\>\"", ",", " ", "\"\<ln f_l\>\"",
                 ",", "\"\<ln f_g\>\"", ",", " ", "\"\<RT ln f_l\>\"", ",", 
                "\"\<RT ln f_g\>\"", ",", " ", "\"\<\[CapitalDelta]G\>\""}], 
               "}"}], ",", "\[IndentingNewLine]", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                "species", "\[LeftDoubleBracket]", "1", 
                 "\[RightDoubleBracket]"}], ",", "x", ",", "y", ",", 
                RowBox[{
                "fl", " ", "\[LeftDoubleBracket]", "1", 
                 "\[RightDoubleBracket]"}], ",", 
                RowBox[{
                "fg", " ", "\[LeftDoubleBracket]", "1", 
                 "\[RightDoubleBracket]"}], ",", " ", 
                RowBox[{"Log", "[", 
                 RowBox[{
                 "fl", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}],
                  "]"}], ",", " ", 
                RowBox[{"Log", "[", 
                 RowBox[{
                 "fg", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}],
                  "]"}], ",", " ", 
                RowBox[{"r", " ", "t", " ", 
                 RowBox[{"Log", "[", 
                  RowBox[{
                  "fl", "\[LeftDoubleBracket]", "1", 
                   "\[RightDoubleBracket]"}], "]"}]}], ",", " ", 
                RowBox[{"r", " ", "t", " ", 
                 RowBox[{"Log", "[", 
                  RowBox[{
                  "fg", "\[LeftDoubleBracket]", "1", 
                   "\[RightDoubleBracket]"}], "]"}]}], ",", "  ", 
                RowBox[{"r", " ", "t", " ", 
                 RowBox[{"Log", "[", 
                  RowBox[{
                   RowBox[{
                   "fl", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], "/", 
                   RowBox[{
                   "fg", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}]}], "]"}]}]}], "}"}], ",", 
              "\[IndentingNewLine]", " ", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                "species", "\[LeftDoubleBracket]", "2", 
                 "\[RightDoubleBracket]"}], ",", 
                RowBox[{"1", "-", "x"}], ",", 
                RowBox[{"1", "-", "y"}], ",", 
                RowBox[{
                "fl", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
                " ", ",", 
                RowBox[{
                "fg", " ", "\[LeftDoubleBracket]", "2", 
                 "\[RightDoubleBracket]"}], ",", " ", 
                RowBox[{"Log", "[", 
                 RowBox[{
                 "fl", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}],
                  "]"}], ",", " ", 
                RowBox[{"Log", "[", 
                 RowBox[{
                 "fg", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}],
                  "]"}], ",", " ", 
                RowBox[{"r", " ", "t", " ", 
                 RowBox[{"Log", "[", 
                  RowBox[{
                  "fl", "\[LeftDoubleBracket]", "2", 
                   "\[RightDoubleBracket]"}], "]"}]}], ",", " ", 
                RowBox[{"r", " ", "t", " ", 
                 RowBox[{"Log", "[", 
                  RowBox[{
                  "fg", "\[LeftDoubleBracket]", "2", 
                   "\[RightDoubleBracket]"}], "]"}]}], ",", 
                RowBox[{"r", " ", "t", " ", 
                 RowBox[{"Log", "[", 
                  RowBox[{
                   RowBox[{
                   "fl", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}], "/", 
                   RowBox[{
                   "fg", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}]}], "]"}]}]}], "}"}]}], "}"}], 
            "]"}], "]"}]}], "\[IndentingNewLine]", "]"}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"x", ",", 
            RowBox[{
            "fl", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",",
             "  ", 
            RowBox[{
            "fg", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
            RowBox[{"r", " ", "t", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Log", "[", 
                RowBox[{
                "fl", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
                "]"}], "-", " ", 
               RowBox[{"Log", "[", 
                RowBox[{
                "fg", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
                "]"}]}], ")"}]}]}], " ", "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"y", ",", 
            RowBox[{
            "fl", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], ",",
             "  ", 
            RowBox[{
            "fg", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], ",", 
            RowBox[{"r", " ", "t", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"Log", "[", 
                RowBox[{
                "fl", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
                "]"}], "-", " ", 
               RowBox[{"Log", "[", 
                RowBox[{
                "fg", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
                "]"}]}], ")"}]}]}], "}"}]}], "}"}]}]}], "\[IndentingNewLine]",
       "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"End", "[", "]"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"EndPackage", "[", "]"}]}]}]], "Input",
 CellChangeTimes->{3.437451085223178*^9}],

Cell[BoxData["\<\"Fluids`EOSCG`\"\>"], "Output"],

Cell[BoxData["\<\"The following species are available: N2O, NO, H2S, SO2, \
COS, CO, PH3, HCN, CCl2O (phosgene), CH4O (methanol), C2H6O (ethanol), C3H8O \
(n-propanol), C3H8O (2-propanol), C4H10O (n-butanol), C4H10O (2-butanol), \
C4H10O (2-methyl-1-propanol), C4H10O (2-methyl-2-propanol), C6H6O (phenol), \
C3H6O (acetone), C4H8O (2-butaone), C5H10O (2-pentanone), C5H10O \
(3-pentanone), C5H10O (3-methyl-2-butanone), CH2O (formaldehyde), C2H4O \
(aceteldehyde), C3H6O (propionaldehyde), C2H4O2 (acetic acid), C2H4O2 (methyl \
Formate), C3H6O2 (ethyl formate), C4H8O2 (n-propyl formate), C3H6O2 (Mmethyl \
acetate), C4H8O2 (ethyl acetate), C2H6O (dimethyl ether), C3H8O (methyl ethyl \
ether), C4H10O (diethyl ether), C2H4O (ethylene ether), C4H8O \
(tetrahydrofuran), CH5N (methylamine), C2H7N (dimethylainine), C3H9N \
(trimethylamine), C2H7N (ethylamine), C4H11N (diethylamine), C6H15N \
(trimetylamine), CH3NO2 (nitromethane), C2H3N (acetonitrile), C3H3N \
(acrylonitrile), C5H5N (pyridine), CH4S (methyl mercaptan), C2H6S (dimethyl \
sulphide), C2H6S (ethyl mercaptan), CH3F (fluoromethane), CH2F2 \
(difluoromethane), CHF3 (trifluoromethane), C2H5F (fluoroethane), C2H4F2 \
(1,1-difluoroethane), C2H3F3 (1,1,1-trifluoroethane), CH3CI (chloromethane), \
CHCI3 (trichloromethane), C2H4Cl2 (l,l-dicliloroethane), C6H5CI \
(chlorobenzene), C2H5Br (bromoethane), HBr, HF, NO2, HCl, HI, C3H6 (propene), \
C4H8 (Isobutene), SiClF3, SiCl2F2, SiCl3F, He, Ne, Ar, Kr, Xe, F2, Br2, I2, \
Cl2, O2, S, N2, H2, CS2, CH4, C2H6 (ethane), C3H8 (propane), C2H4 (ethylene), \
C4H10 (butane), BF3, BCl3, SiF4, SiH4, SiCl4, H2O, CO2, NH3\"\>"], "Output"],

Cell[BoxData["\<\"FEOSCG[p,t,sp,x, options] calculates the normalized \
fugacities for the stable phase ( (f at p) / (0.1 MPa) ) according to \
Churakov & Gottschalk (2003) using the pressure p[MPa],the temperature t[K], \
sp the list of species names as strings and x the list of their mole \
fractions. For fluid mixtures the function returns a list of fugacities in \
the same order as x. This list does not include the configurational term but \
only ( (f at p) / (0.1 MPa) ). To get the complete term, the result of  \
FEOSCG must be multiplied by x. Optional parameters are Speed (either -> slow \
(internal Mathematica) or -> fast (external Fortran routine which is only \
available for MacOS X) and NewSpecies -> \
{{name1,\[Epsilon]1,\[Sigma]1,\[Mu]1,\[Alpha]1,molecularweight1}, {name2,\
\[Epsilon]2,\[Sigma]2,\[Mu]2,\[Alpha]2,molecularweight2}, ...} for external \
species (default NewSpecies -> {}).\"\>"], "Output"],

Cell[BoxData["\<\"AEOSCG[\[Rho],t,sp,x, options] calculates the molar \
Helmholtz free energy according to Churakov & Gottschalk (2003) using the \
molar density \[Rho][MPa*mol/J],the temperature t[K], sp the list of species \
names as strings and x the list of their mole fractions. AEOSCG returns a \
list containing the Helmoltz free energy values {Aideal, Aresidual and Aideal \
+ Aresidual} [J/mol], respectively. AEOSCG does not include the temperature \
dependent term involving the heat capacities of the fluid at standard \
conditions ( (A at t and (R t)/(0.1 MPa) - (A at 273.15 and (R 273.15)/(0.1 \
MPa), ideal gas). Optional parameters are Speed (either -> slow (internal \
Mathematica) or -> fast (external Fortran routine which is only available for \
MacOS X) and NewSpecies -> \
{{name1,\[Epsilon]1,\[Sigma]1,\[Mu]1,\[Alpha]1,molecularweight1}, {name2,\
\[Epsilon]2,\[Sigma]2,\[Mu]2,\[Alpha]2,molecularweight2}, ...} for external \
species (default NewSpecies -> {}).\"\>"], "Output"],

Cell[BoxData["\<\"GEOSCG[p,t,sp,x, options] calculates the molar Gibbs free \
energy according to Churakov & Gottschalk (2003) using the pressure \
p[MPa],the temperature t[K], sp the list of species names of species as \
strings and x the list of their mole fractions. GEOSCG returns a list of two \
elements containing the molar density [MPa*mol/J] and its Gibbs free energy \
[J/mol] for the liquid and the vapor phase, respectively. The first element \
contains the results for the stable phase, the second the result for a \
possible metastable phase. A result of {0,0} in the second element signals a \
single solution for the molar density and therefore supercritical conditions. \
GEOSCG does not include the temperature dependent term involving the heat \
capacities of the fluid at standard conditions ( (G at t and 0.1 MPa) - (G at \
273.15 and 0.1 MPa), ideal gas). Optional parameters are Speed (either -> \
slow (internal Mathematica) or -> fast (external Fortran routine which is \
only available for MacOS X) and NewSpecies -> {{name1,\[Epsilon]1,\[Sigma]1,\
\[Mu]1,\[Alpha]1,molecularweight1}, {name2,\[Epsilon]2,\[Sigma]2,\[Mu]2,\
\[Alpha]2,molecularweight2}, ...} for external species (default NewSpecies -> \
{}).\"\>"], "Output"],

Cell[BoxData["\<\"\[Rho]EOSCG[p,t,sp,x, options] calculates the molar \
densities according to Churakov & Gottschalk (2003) using the pressure \
p[MPa],the temperature t[K], sp the list of species names as strings and x \
the list of their mole fractions. \[Rho]EOSCG returns a list of two elements \
containing the molar densities [MPa*mol/J] for liquid and vapor phase, \
respectively. The first element contains the results for the stable phase, \
the second the result for a possible metastable phase. A result of 0 in the \
second element signals a single solution for the molar density and therefore \
supercritical conditions. Optional parameters are Speed (either -> slow \
(internal Mathematica) or -> fast (external Fortran routine which is only \
available for MacOS X) and NewSpecies -> \
{{name1,\[Epsilon]1,\[Sigma]1,\[Mu]1,\[Alpha]1,molecularweight1}, {name2,\
\[Epsilon]2,\[Sigma]2,\[Mu]2,\[Alpha]2,molecularweight2}, ...} for external \
species (default NewSpecies -> {}).\"\>"], "Output"],

Cell[BoxData["\<\"VEOSCG[p,t,sp,x, options] calculates the molar volumes \
according to Churakov & Gottschalk (2003) using the pressure p[MPa],the \
temperature t[K], sp the list of species names as strings and x the list of \
their mole fractions. VEOSCG returns a list of two elements containing the \
molar volume [J/MPa/mol] for liquid and vapor phase, respectively. The first \
element contains the results for the stable phase, the second the result for \
a possible metastable phase. A result of 0 in the second element signals a \
single solution for the molar volume and therefore supercritical conditions. \
Optional parameters are Speed (either -> slow (internal Mathematica) or -> \
fast (external Fortran routine which is only available for MacOS X) and \
NewSpecies -> \
{{name1,\[Epsilon]1,\[Sigma]1,\[Mu]1,\[Alpha]1,molecularweight1}, {name2,\
\[Epsilon]2,\[Sigma]2,\[Mu]2,\[Alpha]2,molecularweight2}, ...} for external \
species (default NewSpecies -> {}).\"\>"], "Output"],

Cell[BoxData["\<\"miscgap[p,t,species,increments, options] calculates the \
compositions of the coexisting phases (liquid and gas) with an \
InterpolatingFunction using the pressure p[MPa],the temperature t[K], sp the \
list of species names as strings and the number of increments (optional, \
default 25). Optional parameters are Speed (either -> slow (internal \
Mathematica) or -> fast (external Fortran routine which is only available for \
MacOS X) and NewSpecies -> \
{{name1,\[Epsilon]1,\[Sigma]1,\[Mu]1,\[Alpha]1,molecularweight1}, {name2,\
\[Epsilon]2,\[Sigma]2,\[Mu]2,\[Alpha]2,molecularweight2}, ...} for external \
species (default NewSpecies -> {}).\"\>"], "Output"],

Cell[BoxData["\<\"miscgapNewton[p,t,species,increments,xl,xg, options] \
calculates the compositions of the coexisting phases (liquid and gas) with \
the Newton method using the pressure p[MPa],the temperature t[K], sp the list \
of species names as strings, xl the starting composition of the liquid \
(optional, default .9999) and xg the starting composition of the gas \
(optional, default .0001). Optional parameters are Speed (either -> slow \
(internal Mathematica) or -> fast (external Fortran routine which is only \
available for MacOS X) and NewSpecies -> \
{{name1,\[Epsilon]1,\[Sigma]1,\[Mu]1,\[Alpha]1,molecularweight1}, {name2,\
\[Epsilon]2,\[Sigma]2,\[Mu]2,\[Alpha]2,molecularweight2}, ...} for external \
species (default NewSpecies -> {}).\"\>"], "Output"],

Cell[BoxData["\<\"AEOSCGpara[\[Rho],t,pa, options] calculates the molar \
Helmholtz free energy according to Churakov & Gottschalk (2003) using the \
density \[Rho] [J*mol/MPa],the temperature t[K]  and pa the list of the \
required parameters {\[Epsilon]/k,\[Sigma],\[Mu],\[Alpha]}. Units as listet \
in the tables of the paper. Optional parameters are Speed (either -> slow \
(internal Mathematica) or -> fast (external Fortran routine which is only \
available for MacOS X).\"\>"], "Output"],

Cell[BoxData["\<\"GEOSCGpara[p,t,pa, options] calculates the molar Gibbs free \
energy according to Churakov & Gottschalk (2003) using the pressure p \
[MPa],the temperature t[K]  and pa the list of the required parameters {\
\[Epsilon]/k,\[Sigma],\[Mu],\[Alpha]}. Units as listet in the tables of the \
paper. Optional parameters are Speed (either -> slow (internal Mathematica) \
or -> fast (external Fortran routine which is only available for MacOS \
X).\"\>"], "Output"],

Cell[BoxData["\<\"\"\>"], "Output"],

Cell[BoxData["\<\"Fluids`EOSCG`Private`\"\>"], "Output"],

Cell[BoxData["\<\"Fluids`EOSCG`Private`\"\>"], "Output"]
}, Open  ]]
},
ScreenStyleEnvironment->"Working",
CellGrouping->Manual,
WindowSize->{948, 1107},
WindowMargins->{{Automatic, 301}, {Automatic, 0}},
DockedCells->FEPrivate`FrontEndResource[
 "FEExpressions", "CompatibilityToolbar"],
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
FrontEndVersion->"7.0 for Mac OS X x86 (32-bit) (November 11, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 181378, 4191, 16157, "Input"],
Cell[181948, 4215, 48, 0, 27, "Output"],
Cell[181999, 4217, 1642, 21, 238, "Output"],
Cell[183644, 4240, 928, 12, 133, "Output"],
Cell[184575, 4254, 1001, 13, 148, "Output"],
Cell[185579, 4269, 1250, 16, 178, "Output"],
Cell[186832, 4287, 1006, 13, 148, "Output"],
Cell[187841, 4302, 990, 13, 148, "Output"],
Cell[188834, 4317, 680, 9, 107, "Output"],
Cell[189517, 4328, 773, 10, 107, "Output"],
Cell[190293, 4340, 494, 6, 75, "Output"],
Cell[190790, 4348, 475, 6, 75, "Output"],
Cell[191268, 4356, 35, 0, 27, "Output"],
Cell[191306, 4358, 56, 0, 27, "Output"],
Cell[191365, 4360, 56, 0, 27, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

